(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('西藏', {"type":"FeatureCollection","features":[{"id":"540100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@EII_OcEEICGACEEcBI`iLGDKDSIW@OFM@CGGOKEMBMHOX_AKCKcMMCUASGGBIPGFC@CGGQGGIGICOQOIAI@A@UGIOB]NIIQ]KEQEqLQ@MDSJ[MKKOCSIIOSKIKCAQDS@ILIFKFIBI@KCICQGQDMLI\\M@UDWCKDMFU\\IFQFKISBWHW@KDSCIMIIQBCPMJiJB]OQFIGCMKWEKQJOBKEWSQEUDcDEKAKAMcEcCGZKHWHSBWaUBMFENGRJTFZBRUDQGQ@QBQMOCO@OLOJQAMGOMQSeUWIYGYAQWSEiKOKaeSGSBOFaTMFYCQFQJUZeJMBÃMKNQIOGMGoQOMMaOO]QSAOCOBQK]iMGSNQ@EGH[CMSAUCeYOKaSYIYE[C_AKOGMSI_EUIsC}QG{KWAGHIFMFCDmHOAMAQKQEECIMODUIGCEAAE@KKQKCOAEAI[WEEIIGUAELKDUO]OmCiSI@CFIBCAKEM@MJM@GAIEyUI@IBULCJIJGLWRklED]HMJONEBUB_FmT_DMFUHEQNcRU@aCmPWGDgBQ@MKSE@_ISHcE@oJIJ]JCLMPMJiXWBOLMTSHsLOJKLAHF`@PEnSNONATJNrAJDDF@VBBJ@HCDBDPKPYLOJMJKLKPGREHMLMFAHPPHBJ@RTFJXVJRBLHJ@DHD@HBBP@HJALABGFAFBJ@HCHABM@CBEBBDF@`RLDD@HEL@RFRBbPAFELBLPLJPDNLLJDDFENGFG@KFKJO^IHGFW^@HJJBFAPDFJJDFADGFCFBFJF@DShETQLHLDLOPALJVEhBVHXFLLJNHjFJ@JAHCFAF@FDfEhQRQXCVRLAHGRQJCVBNCPIbAXJrTLJHNJhEVARDVPDLCVCVDDlFLh~XZJRAPDVHRNPHLLJRHPBHP@NKTLPfTFTAP@^HpFPNNLHBRHNLLRFT@lHdPXFT@V@RALGPQNKVB\\DJNJ`IlAPFRRJXDVBRHLLANBRFPP@LEHKZCTHJFNLHLXXPFT@LIPEPDLHHNJJjVNLbXLJJPJFTHPBLFGLKJOTM^YhCLKP@HCJINQNADBLFJºƘÖLb\\¨PjFHDJHJTHDNFPTARLPFbXLC\\G`CJCHGjOLIHKFAJEBBDLJLTNNHHFDRTAPKZELEHGNWXMPOJKDM@EAEGG@EHcDAJETADJPDTNFAAEKUMM@C`QmjQPBNLDBPBFFHPAHAFJFTT@HKLYDADH@RLLDJ@jJHFFJLJ@B@DGD]HEFCFAHYFCRBF@BCFSXCRCFLX@JBFjTBQZKHAND\\GLSPGFCB@BFNF`fDTGBCF@DDDDBFENJD@LÊ]IQHQASHODQfUCMA]HQ@^aIXwDUPOPWTGPKJ}HUCSCaIOB_PGVDZAlINKHQB[HMPKhGrCrJ`LhL^NtRFTAZBZFPJ^bVBDKFOFUIgDWFSRQ\\OXIRIrSTIZ_ROhmCIAGbOPU@IDCHCDAL_JKAEKAEE]IUBQEMOMEOC_BKIB]KQEBIDC@WE@QDQPMFGFCBGDBJLHD\\DHABGDC^EDIAGUM@EDWNQDUKSCQ@SDQFMAgHkHUNERBJF\\JjONBPGCMDKI[ZQ`SJWBUCQ@WHKZGTFFL\\TVD~OZVTJPFPL\\ClQRCRGRCDLTPP@JITHFLFT@LBRN\\LTHb^TDL@NFLLH`@VK\\IXMZiRSZGvIPK\\CFLDLJHhKRFTD|OLGWLFNGRFNARINCNFXCPHVD\\@PGhGLGLMZKJIHYMQKCEKBKiWMGCKCOFIGUKDQCGKE]@UEKOES@OCQIUAMN_JSGiWcSAI@KMGOCKMBOJIRAVIEQKMW@WCMGKOWAUIMMAMEKQ@ORYJUCeW]YaWSGQOQEqAiPUNQBKGBQCWMICOLSAOMMBQVMXCpMV@lKVS^YFMLKFKJQBSJSLGP@`TPPBNH\\RFZ@RE|C"],"encodeOffsets":[[94612,30539]]},"properties":{"cp":[91.132212,29.660361],"name":"拉萨市","childNum":1}},{"id":"540200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@ZBfAxGtIjMdM^MRDbDFDD@D@FCHUCA@CHADC@CACEEAAFCPCJEEQ@c@CCAAAI@QFE@ICA@EPGD@PABK@_NCJGPUTQHMLIHOBILMBEGEBI@CCCIGAOACGA[HHWF[HF^BHANCNSlWhY^_`EFIPMdEn"],["@@LADBLTXTFLbZRLJHZPFHDBJPNBJFNLNHHPDFFHJHFLLJAFGFAD@NHFBHDFEVALDFHBFDDPJJBH@BGDEHAFBJCD@DEFALN@DCH@LEF@FBnzDFAF@BD@HCFOV@HAHCLOFK@IDApETDVLJDJ@G[@AJGCGIG@GFCDEBI@MTEBGBBBHCLFVFH@FJ@LCJILCDCH@JLFBLJHR@BGB@D@VADBJCFGD@B@JDBJCJILC@EAG@EFALFH@RCNElIPEFEJKVGJOTGDEHUBALABCRAJDPAFFDHFDFBPCXD@FAL@DFDN@AJGFADGDCNL@BBDDLFVAHB@THT[fO\\ONIREF@BBZ]xAJIN@FDFJJLXRPBD@REH@DFLNJLFDPRVBDAFU\\MFERDTHTF@@DPFDDBHCJAFFRCJEHCL@HHNAHIFCH@HQBCFFFHP@LDD^JLAJBPFFBABMJ@FBBVBNHFAJFLLD@HH@BIHADBHFLDDXIJABAAI@CVKPDPLJ@JHZJFEV]dULQ@GIMFG@EHIFMBKAKBaFGJE^CXBbCLIFQXUDELGbIIJG@MIGMGUMKQFQE]DSHOL_P[HGPAPBLBTH\\JVBLALMHcLKLGR@XQTCNDJP`lHXHLRLHNBPXJCJBJ@JDLHDBDNHRD@LDPNVJTDLDZJXDNJPHNBL@JCJIDUVArDZI|KVIJ_@SAYDcVYCUG[ASBMHOJU\\B\\GPSHUBMHKJFLBVKLGFaHELGLAXCHGNKLUAQG_OOQE@MNEJKHUVGPIZWVULELEJINaXGHILBNAP@FKREVBJDZLTBH@NDPBDBHHJHZLPABBHDFDP@JtP\\BLCJDRA`ETHXTJNDBJ@PELBFHH@JCDEHCHCF@DFCTCFKLCLFJTVLHBHCHEBKBCB@DJT@HBF^LLHQNMxJCXOTIlELKLQnALFvH\\LZPP@LCFc^sNgHQFWRQZMLKHCCUEI@MDEBENAHGJGVCRCJBHHAHELBLFDL@JBH`]NEF@NDL@^KJEpH`DLFN@dMLAFBPJAHUH]JST@^BPEFG@KGIEIIICGD@JNTGDUABJhPTBHBFDNBRFH@JEVMDC`FHDHAXQNEEKKGEGDCZBNALEFER@FLEFORBHFJLJXLHBLHLDTKFB^LPHLZJHNHLLrLRDNAHCL@NILYFGFONSTCjHP@LDD@B@FfKfMPBDJABBAFFFBDFBFFfB@LYH]FG\\Mj_XKAQM[JALYBKFCPCPIPYDCPAX@PA^QjGZAHBHJLDLATIZChIHnBhCVI\\SH@HBTLhLXPNAV@FA`QRKHKFC^GN@FDXHp\\HAHINKNCNHJLRNHDLBhCnId@NB^PNDN@`EVBXTJRNLRDPFNLX^V@P@ZSIE@CBAVAF@B@@GJGXEJBFCFIDAPJFBBDBFJAdDHFHJHBBDCJARER@BLFB@@HHLLFHCNANEVBRHNJFBF@JKN@NCB@DKFAH@LFJBDBHADCFAVBFFH@FAFIJY@IDGDiBEBADANFPCPBDHBLDPVVNDHCJBF@ZEHQTYFCF@THBFADSNEHAFBJHLAPJ^AFGJCLENOPMJ@LGJBHCLAJIR@BIEAB@HBF@DIPCJALDVAJZ\\HDLNJFHBJCT@NGPEFEJAFKPKNCLGDABGAGCEBGFOZYJOAOMG@YHGPIZEX@jCl@TGFKNAf@JBR@RChQJ@NDPMfSLMVGAICCA@UHM@GAIGEA]BGE@EHE@EACICAOEAI@GE@ADEDKBMqaWSS[IMGU@CHEDEEK@SYMGESUAKGGkOuPWTc@EB[@IDG@ACCGSMC@ML[@GAMGCKBIKMCKWMYACA@M§KCMQ]AAWCWKSCGCWAGCKBWJCKHAC@AVKNCP@DEH@TFLEJ@FEHCHBFDFAHILCDCD@JBL@HAHCBAHAJGFCDCNEDEJGBIHALGHBNAXDlENC\\ALBVNH@D@FC´RHEAE@CGKBCFOBAJ@FAFCCCBALBBEFALGJAlSMHCJWFAFE@KAGQEACDCJAAK@GJGKWCC@iHQj_ImOeBUNCPKFC[_EICQBIRGTSVBC@MBALAFIZULGDEBICKBIBE@AKcCEQC@SBCJGJADBJJH@D@HGPIDIDAj_VIVCFEHENMBEAIQM@ADCBEIQKCMBIDAHCBEBSAyWQIIIAMQOKWUGOBMKKQEiSSKEMGEEEF]AG]QOCGECMGEQC@CLOGMMOIMWKIKIQAQBSAYCU@EIC@ADIIIaIE@IE[EAC@EXGHKCA_@CACCA]BAJ@HERKPANEFCDMDCJEGEUE@ELCAOACUGK@CEICMIAC@CFG@IBCBAXKDCBAWUIEMSUIGS@IHQAKBEheFCBCEEICCCAEDEDCTAHBPJDDZAVFPE^OPCHBNHN@RAJCNQBMDI@UDEFGDGPCBC@GEGCEBGPODETO@CIKJQDG@MLOXUBCLMJQHIH@NBFBLCRDFAJ@XGJCDCCOBICOEO@S`WNGPMVc@UEaEMSOPYCOFIDU@SCWHQBOHQESMIGQNKBQEQ`MLGNCZPP@LGDKLMPAN@dBrHLEFQM]@SPEXYTG^AXUFUbiPMHSPQPC`cTKTG`Y^SPMTIJIFQLGVK\\INFN@LIVcTQVEdORKDKASJQRITBjLPJLDV@LFPFTBlK`SRSNKRCNF`PLNT\\NATFXBNDbRFTBPK`SRCL@NDLCNF`VXJRLPJVPFPVRGJMJQ\\eL@NBFCH@DDNBPCD@JLF@JKFETGBYJEBCCE@CBEFCNS@EJJLFFBT@XIVAFBBD@NFLNPADKTKBiRWRaLEhNPCLbLAJdBjLjPXAb@XCfDhL@N@^ATKVS`]VBFZPBLPLVHTLnJlCVBTDRHHPBJCPH@HH@DEF@FNDLNEJIDCDALWCGBA@CPEJ@DDP@PDPAPEJ@PDXANBFHDLBHC@GBETMBADWDCNAP@NINAHGD@LBLLDN@RBDJLOTCHALqÎCDOAGBQPWNKJOFIBEBEFBDA@@VRAzAZNTLJPJbLFZBHLRP@PCV@RBFHDHDCJ@BBBD@FIHCDIPIFGDCPA^K`IDBDJ@RGFMDCDFP@DEHMHKCGBGPQNGLCLAJBXCVBPF`DJCLDPHNALHTAPDD]KpAXEFEFADJNIVADKIE@[NCASGC@IFIBWAOEM@IFKNO@EBCDAJGAEIAA[DCDED@JADYPOCK@EB@PCJEF@FFJHFLPDHHH@D@JDDNJLBxBNGDENKNCNGLT^GJWFY^SRMRMVCHbnVpJCVSNONCHGHCFEJCB@BBJRPFbBNDHFDBLEXBJAbBEKCEBGGMJETEH@JFFFLBFBHHFEBELAB@DCB@BJLJJLBFHDDB@FDDBHFDH@BFDBFB@HELALDJ@DENAFBLRXLHHA`KL@FJXT@FANBJ@JVHDDCNQNKPIFCHBBFFNDVCTFHDBXFNd²~`Nm¢mMEG@GDEAOHQHGJOJeB[EQDuPmHOIMD]HILGN@JODMHQT[VAPGFSBWJKh_ISEEMWCKFw@QdsOMKMAMHIXENOHKBM@OGUS_AKDMXY@KU[HILE\\E`@RDNBBZAHADEE_BKdkDC@IBGTSPaJOHGHB`ZVJCBCFEFcDM@EDOfEBODEHKFMN@BbUìcDJ@ZLPFNLHF@vWTA^DRA@DofCHBJ@HCLOFI`IRDR\\TPHPNV@TFTQHiBFLFPANBLVGXWD@FHJDn^JLNDJNPBHINgJC`BPCTQVcJEXEFFC`BJI@NAJGLEjEFAFCBC@UUYM@GCECGeGWBWHGD@DFRHDXFHDNRDHDJ@PCLCZBFPFFAJ@DDHLBN@JFxOEB¿T]iDOAMBSCQ@KBQLQJUHMJSPCD@H@DNBbB\\DD@BLFH@HOVIHAF@FFP@T@FCHSNBFDD@FMXIDSCW\\CHCTILKJGJALBBFDADEHìÄB¨F@BB¼SEME@YJWWKQAEJKAKHGIUQEGAGAKEIagCCCAGBICQIOMKCI@EG@EEIDGTKVOL^B@LAP@^BRFVLVFRNLJNZHHPH\\HRHBDANBLHLANBPLXAPBRHV@^TNRGRNVdDNNLVHR@XCXMNMJaBeAkFcEQIQW_IUCQPcLWXYV_\\YXOLMD³BQDKAMEIKMGOAa@WDEJIRMHGDIDKCIBAZLNNVHLCJGRGNBRSKh@LDdDVGZCNMDGHfJJRHTE^OZEPLPHH@LKJEbPH@DCLSJKNCX@CK@I@CSKEGCIPK\\OHCRALKHGEMCYCO_g^CRALKQUCM@QHSRKR@XFTWNIRHJTRBPCP@XEt]XWPCRBdLPIJKPEXMVCN@dlVFtrNHNSLI|fTHLGT[LGbAR@PEXCZDVJVT\\AvEFMDK\\GPIP@ndTD^@NILICOFSTaHUBM@ODkJSPAVBTCTGPA`KPKPaNa\\IRBvXPENMPCRRTdZZ`Bn@zGTGV@\\IPGBUJSBMTCP@LCRQdINQDKJSBOAMBKEKSOCIBODSOFQPOXIPMTG\\ETJVVFPZVDNJD\\ANBNvX\\BHHJVNNX\\TvTLjDdBEdG\\@XAX@TC\\WRCRDjGJMPDHHAV@RLPP@`UTDXFPI^STQLIPFHVBTJPTFRBPDNRFRPVjATKV@TBnEPB\\AF^``L@TPRCTMPZdVTJRBLQDSAMROTGLORGNANDdHZAbX`EP[XOJKJMZORGRCn@ZbJTRDLHX@`A\\EVGZFNEVCjYJMJURETFVPFVFDXG\\cPI\\EhMZD`XVL`EAeFQT_JGGOJKlD^HNFLRTPPIR[RKVGJYJKPMAWIOIICMFU@QFON[TIXIdGNKFOASD_HYJQLOHCECE@EBGDIBI@iEMGKIEKGWAUFgIUBKPOCKGKRKFSTg@CIEAEDEHEBCCEIICEBOAEII@GX]HEJGP]LILEH@HEFMCEICKKCMIOOKAKFKBEaOQAQEK@GFC@KC_QE@ACFADAN@BADG@GAIBEHEBABKGIO@AA@GGC@CGIAKIQWUEIQSI@GAOOBGNENKFGHQLOLKNIPIZKLOCOCAGDI@AA@UCEICqBIMBSPMTMFm@OE_BGLKPItKTGNSPKXAjWNINODK^IJIpI@dFTG`J@TFNLR@hACXHnObDV@dQRMFVGNE`CnS`EVAHCE@EECI@IEIDMCOMKKEMESCIGJSAOGKGS@SESccIOOKkEMOESGMIiAQDUdqDSBQCQOIOICGBEKMeKBG@KJMFGBCEKMO@CFEAGAECASBWWBM@SKO@O@IFCXEFCBCAKEMBKGKAIDCFMJEFGBMNWAOPUFEAMN]BEEQGIEC@GKOQEDMAIIDG@EDIJMKCEGAAEEKAIDEHABCHSAMDGACMGCE@KACECE@OBIAKQiSMKCWQEQIKKOCMGQSEO@QCQHG\\FNCLC\\WJMPcBSOENWJUCWCSNS@MGOMKUCUM_OCKFOJKFQA_HSAUE]DMNSVKfNHGASG[TYB@JBL@FNDDNCTALGJHVFJBRAt@CCBGCEFI@CEGBMCEFA@ENOAOAIIKCQKGAO@MACEGECACECAK@KCQCSAKAEGKGMG_CaALEHURMHSDcB]@AC@_AIQ]UWEAGDMPIFUDSEOGGGKOEASBGDIPO`GHQHa\\WJWCgBMGBMLOXclOJe@SHKNKHUAQJO@IGAGBI@E]GAEDGLCFEBGMWMKKC_EKA_]EAK@yPI@KDIIGKCAw@KOOMSQSQQGIMCIGQUQaICOASDOAECGIECIKESqoOM@ETSDMCE_KEMAS[wQ[mqGKScIIKQMOMMICeGOEMMIC]BSCKEMWMGQMS_OIUGKIIMOYCYAQDUBMFMCKMEU@KIGYIMGKKY@KIIaS]MOQAIGEICCU@W@Ah]HWVQS[SSUMQG_EGECOBqOUAiZQLQL[DAVDDAFGBG^URQDK@ODOb[BGkcIsGWeGYGoIIAOFeCQIMUKeIkOYCaUE@QP]bINGTKPIFaP[HFTDlNZBNGDeDUTMPCLIPONAVAJIFM@OMKAGDQZEXE@O@IBCDB^CFQFCD@L@NU\\ERBXDRLD@BEFALBPPfAPCDUBEFCVIZEJ@HFF\\@JDDHBNFHXTHTB^CVHRLJRDRHXhANAJ@FDPCR@R`ZJR@VSRC`F`B\\AVBHh^Lh@PKTDRCbOTK`GNKDYCE@@FDLBpAhARB^CTOL]JQBKHUbQNILGF[\\IDOBoG_F[BMCQCMBEVOPMHIJGLCPEFIAIE]aSIAIBMFG@EAGWK}@OAKGAaDKD_RODM@UGOGEKC[IGuISEKESUCOSGI@eLYHY@GEMCIGKEWE]OW@MIKE[OaQGVMVALQCGGIGUNQeCESByTQHO@ICKQB[USMIAEV]Lc@IIAOKYMWDGVIPKHMBQEOAq`MCWIoQOCI@SHYVYLQFaFO@kC]@SDQL@NHVGJIFOH[DGCGEAGDK@ICGmg]WIEACC[BQEKMKGCISEIOEIEIOG]KEGEI@YFUBgAQCED@HBTDPAJKBO@cEECCMIKIGYCMDMFEJ@VIdGLILMFKBSAMMIKQQG@CQCOEUMYMG@QDO@iFYJBDHF\\DLCDBDBDLCFGFCNEBE@AFCEQGIII@MEC@QIMIYUMCKDMEM@QBUHi\\MFSD]@MASIQOQ_GEWBcF_@QBYLWPIBYBKBIFGFGRCHAXELCFEFOLS^I\\GNGD_LMRUTIFmHUCm@NGDAHB\\CNGH_D]HUJ]hKLSB]MYGMDKHUD_@ULWFQHMP@JLTFLDFNH@B[LGHAF@JAFQHeLUDS@UAwOAECMGKOMQGc@MDEDIRCPGXCD_F]@EMAyE[GMUCSAGGAI@WCKU]MMDWBIFKBICQGKGCaEcIGGCGCSY_KESCqCKDahOLKHQFSCM@MDMJAdEFEMMSMCKBIHSdWP[ByO]LKVGVDfAbGTQfEPCRDPNLVDANILORQdCLC`ETGHKDMGEEBWCOaSWUKMQcEUHGG@MDOJ]CcIkBOJOPKLODIBMJ_DURQLIDG@GCE@CAAI@cGUG]C@EDQCWFG@QNSEI@GFGBSJEFKFCFIFIDMHGBEDHNFPDDDPBHFDFJDDDDLJFH@FCF@DEHIAWJ[^CN@PH`@VGNQNQFKLGRIdOVCNEXGJWJoNoNYN[VW^OfG`EXGITCZA\\MlGPGBYEW@IEA]EK[ASAMSw[a[QSKOAGF@`DtEFyJSDYLGFKFCDULMDMBEBIBYCG@EDS@[FSAW@EAIGQAGCE@CGBMAGCGMMMGAGIKEACESMCJIFS@QBEBCFBH@NABUBYGGK]EYAWEU@K\\YAGHEVEJMFEBEDEBIHMHGHGLECWO[K[@YByPOJGPBNT^JVUhCPEjAPAREP@XFNFJPLPFdBXTLhB\\HFRHPNFJD`Ox@HBJNNFLBR@NIPKLIHcAMFW`ORSPOHU@iUOBSJKBMCmmUOmsKMEQAMGKKGiIMBOH[FYB[CUAeQ_SIAÝMDYAM@y\\gNMHCPJXB\\EJgNUDKPYvSTYLQD}DUFYHQLWGiAU@MDMGKMG@ODebMPYJELF\\ETMNERHTCJ[F_BADDLHJFJ@FGLkNODeCODMHK@SOOF_PWFQJMPILMHWC[IOBOPER@jHpP\\PfDTBPHdC\\KRMNWF{IGDCRFrBJFFXEHYDKFMHEFEfKb@XDRDJLJjVHNDVAXDYEU@UBMNKRBNFR@PIPWLSDWIOGGBYTM@uQO@MFQBGHAHBFLVCD_TMDWAICUSEAiTWDKAQI{Um[MAOLUCIEEGgeDGFCFSKMYEcEU@WDU@SAOGEEIC]YIMIIKG[OCKEGC[IQOIQ@IDMHINIBkCWHMRBX@JIDG@OGMAMBWNW\\DTARMXQNSLKJ@JEJOBOCKDMJSXCLILBXDJBNGXIN[LIHEXPjGfQRKBaESFW\\GP_hENBdQT_NSIMCCAOB]HQLCPATENKNCNBJbHDFMRQLiNWBOJQbOFSDICIIUOM@IDEHHXEHKJUFgHMAYQOE[KKBUXaRKLITEHGHODOREJEDI@aCSCUGMAQDMJCNBRCpCHYGMUQQCM@BGFIXBTEFEDkL_DKDGFGbENKRQHQ@SAwIODEH@JFJNR`TLD^TBHEPIPulODOAcOaMYCeFCHBFDFPBDFRZBPQPiJKJUrabYbOXOFcDQCMGSMKAKBEFGDGHYd{RQFKHen}XI@GOCCG@GDUVQZKJIBmSOHKJINSLoRKHMDKAQIOASBw@QDGN@N^lBLMZHP^NLPDNGJQFM@CBBvEBMBSAgPMJ"]],"encodeOffsets":[[[87819,31695]],[[84115,30925]]]},"properties":{"cp":[88.885148,29.267519],"name":"日喀则市","childNum":2}},{"id":"540300","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BEFCHAV@FFCDJBDJF@HCD@HELAF@FDD@DGBCJEHBBCDBFAFGBBAHLNBCDCNCDAFBJAD@NIJBHHL@FAF@|K\\\\FAVKXA`BLFP@PFVBHAHGDIDEJATHLAHBHAHGBEAKFKDAJAJBN@DAJBFDHDNEFCPBTABA@IHC\\KZFNCJFdEFETBFEHMDABEDATCFBH@HBF@HAJIV@JMDAF@FEHEN@RDBABGAEHILEDODCZBNMBEXCLBDABAKGBKHGHAJCNBFFB@LOJGJBLHJJF@BECKFENAFG@IXIHARDBCDANARIHOHAJFFADIBGFGPEL@DCEM@EMMAKVLSJMBGECKECC@EFIAMEORKH@J@HADEHEHMDCLCDCRYBGDOBAD@FEDOHEDKDCFKDCFG@KHM@IFQDCNHB@BACQBI\\AFC@AACDGNBHEHEBECEBEZ@DCFIFGHCJEPQpcBECECMBKDEF@TEBEBCTELIBIAEMG@CDAFKACECAG@EDADEAOFKAAOIAE@CD@@EGAAEHEJAJA@GAC@ICGE@GCKIOCOEAIGM@EJGNMDSBCAGDGDCBEBAHAHCCGKGEI@EDCBAAEEEBCDAJBN@FCRBFC@AGKAE@CHKJITEHCDEACGCCE@CHMNAVBFE@CAIDCNCJ@BAXWFGBIAGDADMDAHCDGCMCC@CBAXALCJHDBF@DCBE@ECECE@GDEVOBA@CEAKAAC@CHEHAFEAEGU@GJKLG^SJCDCDCAILKJIBERMJAFCBMDIHARDFABC@C`Q@EJMREZWH@FC@CDCNIHIAE@IBAHCJKLK@EFGJ@HAHGHCTQVGHEJALIDEDCRBRELIDO@C@CF@RKHEDE\\KJALCHGFEDG@GEGBGNKNENINQNSPKBCIMKEGKIEGIEOKCCCSCKKKOWIACACCAEGEKAcEO_[MKACEKGEEBABDFAFEDOAGDGFMBGDCHAFIN@HCNCBGHGFADIDGF@FOTEJKJADGH]DUHC@EGE@EFMBK@MCGGIMCEAIS[@WIYCE@ICGGWBCAMBO@EFODAT@DCFIEcIMKEOCACBEFEVIL@N@V@JIACBE^GNOPCDCLUFGHCDGHCFELEDEJGBCCEAE@EDADKDYAC@EHKTOPEDE@CEIFMlaD@F@L@NEDODCPGJEHAFIBKNMBC@IAQMWEgAEGOUWEWEK@ADCDE@KDGb[ZKVEDIHGnWDCHSDQNCR@LIBIAKFWDAFBHCDEJGJMFCJCT@nQVCDCFEFkDIDMAGAEKEICO@GAEEBKEIGCUAMEKAEI@EBON_FaPWD]@CIKDORONAHGBKCIIMMKEEDKBQLEFEAOEI@EEKBKDGDEDKLKDG@IEIDQj{@C@c@CCC@KF]PQBOAUCCEACCBKAOLS@EGKCMBETOHGC]AGDKAIBGJKBECIGGEKOIAKJIBECI@GDOFEHETODEAOKOI]@GDGLEBE@EGKAEFKLCVAJIHKBEIO@KHIPSHCN[XWCYKY@GJYIQCK@EBCPEBABGAE@M@EFGFCFEGG@E@EBAJgG_BEFGRGHABGEGOCAWGG@C@USQCCI[@ICE@EAEQMAC@SCOEGACII@KJYBOCMGICEG{MU@WCE@CBC@EAKCEAAFGCOBGAIGK@GFG@CGK@EDILABCGIBEBCNKFKFEDOAG@EFMb]HKDMFEFKLEFGAEEG@CFEBGAEI]@KCIJIFQAOCO@KHBBANKDEAKGK@IAEBC@AHEBCBGAEEE@CFKDA@EDC@ICAKCAEFGFkDE@GEE@GBIFWAOFOAMDSFIFMGMIG@GDELENCJCRYBCCI@ILIHMJGLQBG@I@QCEkDCGECMAKKU@aCSAICIIACESCAEBIJGFSDGF]FK@CI@eECQG@AAIBiBMFKBOHCF@DCJ[DCRGHIHQDCJW@KJQHU@SEMEIGCI@QEGEEGEAKA]WGQGKAGCCIAYBMMAEBSAEGOAEFSCKCO@QCGKKHODO@KBANEHCNE`QHBVFLMDEAICGKIFK@CHQ@GCCMCIJG@ECEEO@GBGFE@OODMCQAAIAGGCAGBKCG@GJ[FMBOCIKMCWJADBNEDKFIJBPAHDJ@LADCDMDA@RPAFGJ@P@HBDJDELIFELBhBDFD@BOHEDADBJHV@JQTAJCLIFGH@FIHGDAD@BFBBDAHCDBBCBYBGLCBSCQWECQAIKSEIGAKICACECIAGBOBEFEAKDI@GBC@IHMBABECM@ICGBMABGACMCACBGRCFA@ABIII@CDEJBFAHOFENBFAAEEEKO@CBCL@DAAGGMKEAAAEDK@EBCBGFK@KBKDGHMTMBAGCII@OAAGEAECKBIDKB@JDDA@GCAACDIBMFCHABABIHADCDC@CEOAMBCJADC@CAIDIEC@G@EBACCMUMKMESKWE@@GWGEYGEASDU@@CDMCIBGJKPICMDKFMHEBCDGDCBC@EAGKGHIBKLKBCAAGI@ADGDILKDIEKEC@ADCTGIIAKBEBC@EACKMCOKK@G@GJUFIfCVGPGTBAKHSZiACGG@ClOJIBM@aGKDWRQTCRDRLPNJBDBFADWTEPGDIVEFMHWHIJCFDLAHIHEJGVKJQfCR@JFXETIRKLHLLLDPH\\O\\KFELKVGTUZI@GEQKUIgIUAUCE@ALGJQT_HUCGHEJKPAT@XITEBEHAPFLE^QLMPKFiPcfEJCDGAEEBE@CACGEYWEECGGaIOKBaD[FKAUIGCCLDJBhCLCDSDGDILGTSfgnKT@JBBB@LKD@LT@DEDADBHJHRFHH@DEFEBIJaXBB@DABSLA@GE[GW@EDADGBCFBXCXAFEHDJ@NDHAHMJOFOJQLQRSdENsLKBOKGQ@]QOBgAmGaJadITDZWRIB[XIdWZSH[XGVCPYTY@ILOP[CUTMNGF[GW@[LURSLUIGGOEUDIHYBKEOA@A@GBIFEBI@CCG@AHGLEXCFCDCBIDEPMVURMNADEGECEYQUQAIA@GBML[PC@MEUGIIAKCCCKCCBADG@IMEAAAQEO@GDGNERCLKBGJO@EGMC@OFE@MAKDSQ[@GECIEAI@UA[GwIWCICG@EbEN@NEVANDT@NBDFVL^H\\DVCHMRGLIjGT@RBTC\\BjEBI@kGIBEBCFB\\ABULURAB@DDFLLFLAFMDEDAFFRNDPJPBURORqs\\SNAFBFNHLBDFFF@BYDIDMAQFWAEAEEIEKAGDINEDAFEBIAOBCEECAKQ@AIAA]AqDGF³¦ILCFEbJbGFIFCLGOE@IGWoCOFMNGFEAGKQGA]HaRIBkEICMICEKiBSFQHORGUIGYAGAIMSO@EDc@GHGHCTSJAVAFEB[E]EOIMEIDKLOBSAeE_BKCGOIQCKBMJYTE@e]CGE[B]A]FeAQOGO@UDOFGL@NBNLR@FCB]CQDgbeDSFSLQ@MMQES@MFE@{OSJIHCJ[jAD_nKtOfEJQJ]JCFMJ]XQBA@AL@PBHAFKDQCM@_XIBiXGL@DPJDFJH^LJHLTDBF@R@RCJ@NPPNNAFBHFD@NK\\IXILAH@LB^RHR@TIRMN@DFL@BABE@MCYJKLY\\SNCJUJYFGBONGNEFFDZ@TBJHJbLJHLBTPRATM\\INQxAJG^GLMJ[TKBI@[FKZAXG^OVULUBMAWBWN]XMLERBV@PS^@XL^VVfJLNB\\TZNXA^NVRXbNVRHPAZUfARJVtVXNTTX^LTJ`@PKP@RXjdnD^UX_HIGDGBCB@BFFTB`RBBDHHH@DAB@JBDBFQxBPFNFF@DAJCHCBKC]B@FFFBDEBQHQPODBJFBDB@HKDMJGHMFOT@LGBQ@KDGDADEBUYAWCECAE@GHSDECEGCCS@AIAACAEAEBKFSTGXGNKLIDFDPDFDAFCDKFCDM@SHEEMAIGOEKDO@CCOEIDgJSDSBUEYGKGOE[@QEKIQIMEO@OBQEKOIyGS@QAUWSUGuJQCOCEQKMU@[FOVGRAjINMBUWOAIHGTOPQDUCUKOOOGSAKEuZO@UC[@SJOTANBPMLmPUJOLONGNBTRN\\JHHCLeVLOLKHS^WHORKbMFMP@RERCNGLSBWNGNMFeFKJFdRTRnGVMRQJcDgB[J{NSASBGLSF_H]\\KHM@WISKQEMFOPQLOHJeCAQFcCMSCeLOHWCAKFOEOMMMGSJGNELcRQNENBPZXLJFJQBeJQRSHWBKLYPOCUIWEQBIK@cKIQAeRINYNQRWRULWL[ESEOMUaESDSGGAKhsEQUENMC[KIOUEQNKDENKLMDMJM@KKWIYEYBOBKNGROHiFaHSPOF[CMCOIKIIESGUC[JSJWDUBUF[\\MFQ@UCOI_UUEkFUCQEK]UC@EDEFMAKN_AAmEMESF[D]@CJMBgMW@WLGLW^UAUECWDOGOQCuB_@YBOLCPBNB`APWJKCMH[FY@UKY[MKWMY@OOO_MKMEYCWIUeKKcDUAMOQKgLgRYFCFC@@DBNHHGDMDW@MDGDKFAPGJSGS@MNKVQV]LSGWEa\\OHQPMIgCeBQFFLENijYVYDWGK@MLBlGJcZgROLGRKRYPMAaFSJGLCTFJNPLLXLBRILSdERBLIRsLSGA[PCRFPJHPDXPPFLJFRN\\JDx@RJRFXSVGTCLFPQLGLCKfATLRDNGTC\\JLG@KFKNC\\ARI`gXaRCXCVEXBFJHHTDNN@\\LTNI`ET@XDTCd@TEIRIjIVInHRJ\\VPBPER@dJV@d_ZClM\\@THHNBVDRLXBRJPHXKLcRKPKZEZAZMNQNOVONMTOAZCTKPWLeFKRNpTvNVHTFXHVZN\\HRHNFHLCTMVCZBXBRHTJXNHAJ@JELBFPANIlMHCPChJHZJN`@RPGNIHDTRBfANGXEXCVBVHVLLTRnJRTDhbLCXLPTNLVJTDRARSHI@OkiEIEKDIRSTM@WFUDKP[PGVAPAXBRATFTF`PNRTNXJhTNPNCNEJIDIHIBIEIWUSGKQDQAUISAKIKKUM]BUEQCBY@WDSNkHMH_LKPGJMJO`WVFVBbUFDFHENFTHDRADDAdBFlIPPNHP@VDPAX@jV@HIRFLTB^ELHVECO@IHATB`PDPCJFDHBJFNHDBDBRKJEBIHSZMNGLAJ@FBHCFFHCLIPCBCJSLCHEDEDBDHFCPKHNZFTEXILOJFPEPGL_XGJKHUFKEIQULSPgXKRST@PHTJRddPLHLFVBTMVGRGdKTOJSD_PWH}JCOBMFGHStAR@H@HNJFFGHG\\GNSDYH[BaU[FERBPCNDNHRJFXFVARDP\\PRR@PAVHJJFPC`GTG`@PE\\GNGLQHoTSF[@[NmNOJINFLCjEVBLFJTFLDNJFVARArEXMLGVHPCD@DK@MLIDTBTN@DDDFFFFBPDFBHHDDHHFDD@JFLCHMDCBIAMJK@CB@BFVB`AFCD[TCFFpANDLALBVNHDD@FEZBLVHHDDHEACBIJ@HHHBTJHHJHB`VNPHDJAFDNFLHJBHHLJDH@NDJENBLFPDLCDDLLPFLBJ@H@HDH@DCBEBCBO@OTcVIPMJEJEDSZIHGL@JJNBHAFINBTAFGFX^DLDTBFBN@HBB@D@FTLbJLHDFBLATILIBZDLALHJPD@DJDDFDETE^BDEAGFEJACK@CJECE@CRMFILBF@NGFID@JBTGTYD@LDHFLDHCTDNDDADMHCBGJMAK@EFGFG@O@CFC@IBELGHCbADCBEFBJLFDHAJGF@HAJDN@BFNLEJF@DAHAFCNCNKJCJAHDFDBELKJCL@HEJAHC@GDCPIFIJENPPHX@HEDAFBDDLBDEXB@DCNDHRCF@JFNDEIAEDMDAVCFBBJHFNBL@DIFCXBJ@FDFFCJHCFBBEACJEAGBIJEBE@GAEBIJFTEHCHGTQGBGCACEAECGDEAEDGCKDEEE@GEEBOCMIE@EA_BYAAAGBA@K@QEQKQBQCIBCAEBKCABI@BECKKIGAHEECEIE@AAAMDC@CCMLINGNIPMPBLJT@DAFLHHJBJDRBJFL@TBHFDFJDFHRBDBHBBD@TLDBBBHANBBH@PIRBJDBYAKJEBKAAGCCG@EDEHCBCJS@IJO@CECFI@CDECIBE@EHEAGFGBO\\GFMI@GCAEAAVWBKJKD@FCJADEHCL@FK@EDG@CF@HFDBTGLHNDNEFKF@HDD@HHCFIVDD@DBDFJHHNDN@LHRMFAFBFFBC^YBKBCXBFCBACI@MBEDG@CCEIS@CBCLAJCJQBMCIBEDECMAOFMDM@AC@GAIEC@MFA@BCCE@CACGAI@AGCAIB@AJEBSFGLKTKLERMACEEOAECG@IAAJGFIBA@EM]DMCCGEACGC@K@GAACBKDACIW_IC@ATOBE@GSEAC@CFCJMHELBFCVFAIDELCTB@CCGAQBOBCTKJM@GEKLQBAAE@@HCAIHCBA@IHG@EFI@CDCF@JEXUBGACGCCC@CDEHERGJ@HDBADGJGJSBAREBIBCLIDWDAXC\\MFAJ@RLFCHEFANLNFBJAJBJBHBBJBJCN@PDHJBJDHHBRCLBLATCNALEN@PED@JFDBFCLIZC^ITDNARGRCPERCRGFIRSDGBODIJIDSBEHGJGDEFEPIJFLDHLCNJFH@HDFN@FCVIXBDNBHFDVJXFHBHFD@DFDHJFDRVLVBHDH@DFBBABBDAD@DAFDF@@BJBF@FALBD@B@@AHBJ@ACHCLBFAFBFADBBAHDBBHCT@DED@BCFADMGaHUHEH@FGd_RMX[JCL@LDFGDIDIB@JBFCJ@RIHC\\@DCAQFC`CNBHFBEHCNMBGBaFKAMBEBC@EAE@MEMAAHO@WJQHCV@XHVBFADEPELDBF@FHDGJ@DFBBJLDDB@HCHBN@JCH@DBHFDhDFFBLC\\FJ@LFFABELKLCHMLENSTBLBFLLBDABYPUPIBYJUHCD@FJ\\BLARKX@HPVVHJ@HBFRBDHFED@FNJAFEBABDFFD@FEBKBGFCFAHGHAHIN@DNBLBJE\\DPNRHDDHPRFD@JETELA^E¾EL@RLHD`@FCDCVuAaDIPQAcJSDEXMFEFMAGDQ@IFEVOZMPOBEBA`Gp[VEJGFMFEJEZKPMTMFAJAFDDDFJXFRN^NLIJOXULEZIJ@RLCZ@DJDF@`KHEHGLSBCLEHGFIHIXOVGRA\\@N@HBDHDPPXJFNDPEX@FJZTDFBHAPKREDMBIFAHAHKPBLMFEFCRAXCFIHUJCHSJGLA\\ENCd@HDHHFzDLXTX@H@BOL]NEDIRCLCPADIFaHAVCPSXAD@PDLDJ@JADSPMDEDCF@HFFRHLMJIHCZDFAJEDAJ@FDLAHJJDJ@TM`EPMBARERUCIBIHIH@DAHCJIDBDD@FEHG\\AD@NB@JBRANHHBDTFDBBHEVQVELGLAFAFCDGDAD@DFDDH@JDBFBHRP@J@BEHGDQBKFQZAFAF@FDFLHPPLDrF`ANFHBLGHOZO^@NBLEJAR@LHTITKLCLDHFHBRBN@LCRANEPQNGFA@B@PBBTVPVHBJCHCZSD@\\BHDBDFPERSPYNSZBHBDNAHDFFBNDBXGDUFEFKDAPAFOHEDANBRCZFHBL@JCHBF@@FKNENKNBFNXFNHJJJBDABKDQ@IAI@MHODCDABFHAHFNEDGJCN@NELBFFLDNJLDJAL@HNfANFL@FLfATLTFH\\FNLF@TCTEFABC@EGM@GBCFBJFF@DCBEDAJCHCHADBPNTDFHFHDFHBZBFL@LERDFDDLD@BUHIFAFHFDFBFARFJ@HIRBN@BKFBLGFCJARKPKD@FFJAFILM@GBMLI@OEOBGHEH@DLL@LBNDFPJRHBB@JHDHBDBFRDFNLEBQBGDGD@HUDMJICI@IAE@KHBFDDDD@JCH@HBJR^FBDHTDDAFCAADKHEHCDCFALDNBTRHBBDHDL@ANDLXHHFHAXJHBHIDCJI@CACNAAC@GCGFCAGFCFCFCBIXCDIN@DENGFBDDF@FC"],"encodeOffsets":[[99854,33313]]},"properties":{"cp":[97.178452,31.136875],"name":"昌都市","childNum":1}},{"id":"540500","type":"Feature","geometry":{"type":"Polygon","coordinates":[],"encodeOffsets":[]},"properties":{"cp":[91.766529,29.236023],"name":"山南市","childNum":0}},{"id":"542400","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@cEMAWGCSEUDMCGGDGJELORMDMCCUG@IAIBMAGUQEIK@_LGBKGQWAKBEFM@CCIBKFK@GEACAAEG@ECAGCC@ECAGCAEIKKIAIA@CDA@KBAFEFGGEAKAEEIEG@SFIFHNAHDFFLaAIBWAKFCAGEMCaAOEIQAAA@IDEFGDGHMDMPUTIDL`\\GXEG\\GHBBDBPJHDD@DAJHFAFKNAJGPKJGNSROVIHMD`L@BA@OHCFOB@JDF@REJ@BBDB@D@dFRIFODEDBBFFBD@DCDGB@DDBGVEDC@C@ECaCQC]NcNiNsJwHeBYA@D@PHdJbFZ\\ZRDFHXJNFF@JCDFDLH@VCHBFLCH@LDLFHDJHAPCJAHFH@HDTFXEFDNLD@\\@BCJAFED@PHD@HCD@JFBAHEFCT@JG`@LCfEJBJ@P@HCJIJCD@FDJAPRDBRCPGPADCDODIBYVP}"],["@@N@FBBLFDF@VGF@JLFDBABG@CBEHGHEF@THJBFE@KHEJAZDdXLPDNNRBLBDDBH@JAJETQP@HGXBD@DABIJEJDDAB@BBFAFIPKLGHGJBJEFCBBJJLFRDZAJEXSLELCHCXYFAP@AJBLDFD@LETLFA`ODBBLNAJ@BD@HFFD@JBRKTFJEDBHDFDVFDDAJBBPJHHHDHAFDB@FENADEDWDC@GDMEODAJAFCXCDA@CKYAIBCNE@CCIDUDANCAIBADCBQDGHEHANBLFFJFDf@LBBDDJDDPCNEHBRAPFN@BFBHDFBTVLD@HCTGHBLITIJBNCL@HDNJH@VMAEEI@CJIFSHGREH@VBDA@CBCJALBJCBCEG@EFCJAHCBI@QCIGIBGFANBhKBCBCXKJKPKHINKBOLIFABBDLHF@JBBRFL@DBDRADBFTCLDRALFDDD@LCLAJEBA@IBONQHGB[BWHGHCLBVHHOJOFQFEJABCB@BBL@FBALFLB@HD`EBBFFJFBB@DAD@FLAFD@HBDLCPFFFdNBBBHT@FTJHFL@DINBBLAL@FDJPHH@HBDDDbFFCDGHCLFRDNFXBVBF@JEN@NCDCFKBCD@NJJBPMTIHAJ@FDD@FANCbMHGBMDEDI@ECKTMPALEAEDKAKDEFCDADGISBCHCGE@EFCFDHLFDPANCTDJAPMLED@@LLHTJRBTHXFFEJG@CDEFCBODEHAZHJ@BEBIJEPMVDJAFBDBBFEJ@FPAFBJJHJDBD@PALBJIRAV@DCLUFGRGVCJEVILDJJJZBDFARBRCND@RNLGDMVBHHZZVDLTEZCZAF@LJHDL@JCDEDAREVA\\IBDAJBTrZHIB@HHDBDCFCLHJBLBFA@GFEBIJALDHF@NBFNFFJBPEJENBHFDLT@JPXCTD@HGLAFKBI@CAEDCJ@LIHGJCJOF@XJL@NFDD@NDFAJ@LADCBCFDDBHVHH@DCBABGFC@EDCFHF@FEBDDHFBFBL@BADGAADCT@JDP@FBPLBDBBJDLTJLFFVD\\ALB@BCJGHBFBDPL@ZHJLJBBFATSROJSPM^UPGTKFCPABABCGIACBCNALGHANBHHFBFADCBMDCRCHE@CCG@EDABGLGBCCE@EDAHEZET@BAGEG@EACCECCMDE@EDGCEIC@COCGIBKCKAYKJSJKBEAGCIKKaESC@A@GAM@EASAKC]CWHEBEASJMBEAGIM@IHKJGTYFCFINIJOdUPSP@DAFADA@CCG@G@GAIEKKOCKDCCKEOAKFMCI@MCGKIGGIAKGMEECIBGCMO_UGAGIIGASGG@GJIDAFBCGGCUGAKFY@ECCMGAUBKCKBMEoDE\\SDCBEA_EU@ADAL@NIJBDANCDGEK@ICCGECGGCAGCEAOEEEECC@CSMSAJCNKL@@CDCGOHUNKFWBqBQEUMIKCSEEIAKFUDiEKJMPInM\\M\\@TEpSRGHKHMF[@OH_HSD_EOIIUGOBQ@OQO[QCUBWEIEGQCMDMAOFQ\\EbV\\AZGTCHMH[HGEEMI@G@GBQTsHGNEPAD~IXG`OTCPILSHcHQNUASEUGKOKccIQGS@OTSLQhWTOVKJRLFVELGHI`WHKFOEOPIJKFWESMYLGDOGEACFCFCDGTKDIDAJODKEGDEAG@EBIHKNMTYJGFALIAQACGCEMCOAAIEODOC_SAGB@JDPUFKG]FSAEKJQ@GiUW@OBUCO@MGOOkJAEBcCCQBGCESFMEGECaVUAUE_XIPINOHKLG`GNMlCT@XAZDFRAVN^LVJLBLJTBVCRLRTHXVFJAJGJCJIJMFMDMOgSWISMMQ_OSESEQBWAOBUBOHO\\CLEV@XSNQTCJFLFJlj@PGJQTQBSCUIMKOSWKKDgaSCIQQmKSUKUGUAWDWFMHeBQACSJGHMQO_@IMGYgIODGDkNMJOBAEFK@IBIMGIWGSAQAWDYNUDSGKMEQG[GYMGUEWGSMUSuMoLQfEXKLODSBYPNSPMPURMNMBYFYLYLOdQLKGWIOAQKWCQAUGMSG[@kNYDc`U@cIQ@OFOA[UQImGUJiJQJJSFc@SDWCS@_FMJKS@[MMSCGGEIWAUFWDQDWb_hQJ[BMDEL@LKH[ISDMHQCSKeBLKDKHORKESDUHWTQEQIw@ICM[EQKIOEWOOCIGEODQ\\OBTHtKJQAKFQTcJKAQWKKKSYDSHKTIbENBZOLQHQPKhQdYHIAkNKL@XHZCZUjiFMEKREfAhDNJROPGb[XFTH^KRULUNMT@THHIBOLEHCNCX@NCHCGGAM@CD@DEZEhQhKEMWIQIoOMMFSJSFYAqESQMSEU@]A[WQAQFMACYKSGQCSFiOKKEQ@YFW@SA£fOPmNgCEQ@SIMGKWA_JWFUE[MCOKKQG_FULQNc@[IqEMCWJEPIPQ@SGIIAIKGOCqAUHUAUFUVQFW@QCcP]JcDUFaNURSHSRE\\AZFNXFLHHRBVKXQLWN[VSRQTWRqBSC[@[TWTWP]JYMA[EMQGOEMKEQOGQEIIUGSQMOe_SDQL]rGXSJONDJBRENUT[JaDaJWRERAVFdCNBNJNDLKTYJSBMFM@GKQQSJQNkLaX]BMCMKEIBwCSESAOMQMAGNQ@]FQCkSeCQQGOSiMG@OBMLCb[JOFQQeDKO[UAKOEOMOGYIKJmBQMG[JSDUJSAGMNMPKFUISSAMHO@SKYDiZ[BOKDSJSAUEKAQDY@cMMYLKNKHgHOH[@UCOGWDMEMDQJMBQEMHKEXKH{PSCQEgLIGCKEK[DOLuJYHQTYjWN[JUL_@KGEK@MCK]SGaKSM[AQ@KESEKSGIJO@SOCKQDQHQDkR[DOKOESIYU}PUC[SEKSEYHGL@XDRAVIX_TYRJ\\CLDNOHMAiP[IIEQAMFGVGlBhENCR@TDRLTCVMRCX@FVNBHCJ]FCDAHGB[CGCIKCAAHEDEHONCR@RXFD@JCFALRA^LJ`APDNFNPRFVA^JFFLBBFILK`CBGDCD@JGLGJaPBHDJgnQPY`SJqTQJWJ[PQRETCXJhEVEPCLUA]aOIYEYASBQEs]MgK_KqIqDgHOLGNA\\GRMLkJYBUCOHA`JPDbDTGVI~OLSHOXOPCVWxJ]b@GRB^DNeVCRGPBTGRJRÉ^@KICFMAECCCCE@ADSHeC_MEAEA@EDOHKT[HMCGBYLARiSAE@IKWDEDQTWDE@AAEDQZEBGDEFE^GHC@C@AKIEIGEiII@KCQKG@BCZCLK@GSSIEBEBGGOEEOACAMKGAG@C@eRn_R@DNNLVBFEBSMOCCISBIFCBGd@FHHBH@FGPEHOPWNMXGHKFYFOLSBCQGEMGSMIKEMIFEBGLKJiPGHID_D[HKDWEaKOBQOSMEGCISIGCEGOi[§KaÕ¹ƗEIAKBCRMJMDI@GLODKZgN]PSLIHKKEOASGIEIOKIaWMKiUIIGMKGOCOFKJS@OEWWGKMKIESGYDGLKFO@EOAQBMKKQGUAWCQIEQBOJkI_IM[CUAMLORKHQBU@S@WEcOkGS@QEKKGMAQKGMMEOGo@]BOESeSKOLS@MGOOAQGKIGKMOGQCUBOIQWYg}EKCkUCUDKDOCCUBQFUIgGMKIqSWIaBOJMDUAIDQRGHKBUQWDQRgRSDYFKPIRGZC`BTEPMLcHWJSJM\\EP@REVDNJJJPBXONILIZUHQLQ\\OJSOKQME]GkCILHPIHS`ERBf_FUK_WYCgN[FOJ[dWHECEUUOSEQFIVINiZUDMFYEUH[F_BW@KGQCISYam@QDQHYPINILWPO\\_FaWYBcGMCMBQHKPSHQPBNCTKRQASIcUOYSNQDSOK@__E][BOAmFSAU@SLiBOUEQMQOCQASEIOASGUOEKJSR]TOJWESC_VO@KO@QBUGGOCINiHQCQD[XSDW@WB[@cHFcAiCSKSuW[MMIUGG[AuWAMBMC[MIUCOYEUUSI[FSHONWJOPERPCTAPDJTPFLALBNAPITCLMRcJQRKDO@SDANITAVOH[JU@SHyHm@_AYYScQQODMNOFuWQA[JMbObOL_LOBSHSDUAOBITCl@PANGVSbETDPKJMJ]@SCmcO@OJ[HCLENuF[BUSUIYCWDOFQ@aBKHS\\KHSG{eKJMTMGsqUEckM@UDWNOFILOJcKQAODWXs^WFO@ODQAISQGMJSXWEQ@QLGT@RDNRVKLQB]D`hDPDZFNGHKLQBGD[POLDJFHTL@D@JDLW@MDILKTCDG@aOIFKLG@OGOKYF]PSFQGIIGeCHMNYDUHcCKCg@LQTMAQHIHKDUGMMYKABDJCLCJGHQNIJCF@XBbHPLNFJBNCLARC´KNWP[ZU`WZKXOdDRJVX`JRFREdBlAfIbMNWNWDQ@UGMKCMUcQMQHSM@]GUAQBOKWAOBMGKAKBMACQG[GOGGGMYKIQMUEUKQE]AO@KBA@K]UPSLCHFJ@FFHJ@LDPNRJJDHADBDDbhFJBLBHFHVRHJGBLILBFLRXXZIF@FN»TAAE@§AëÃFGBCECAABKHILIJKDSDGX[TDJCNW@ECCAETMDG@E@SEO@EBEJGPU@GEGAKC@[CaAMA@C@GDCTONIVGRIRKLAR@TDNAPBjCS^AÀFPEw@IAMGKCCI@EBOEAEDYDK@OCICGMQGCWEGCEQ@CHCXGXAfHDHDF@HZNVVD@DABEFEFiHKBI@MJAID_EEWFIFUdSROD_AIDMhGJOAIMMCIKm]ICEGC@WXUHAKBMEOEKAGjSRSEU@OMOG[SCQJQJ_PEDK@GAIDGpe@CQB]CSBuXE@KGEMKO@YCIëdaV@ANMLEFGPCFAPeFCN@dCFEDEDAUI_YGAGHIPObSTAH@JCDclALF`CFGBYBAACMQ_@[FKFGJV\\@LWZCNBLT`HV@PANGLMPWFGJBNLNPNct@RExDLNXFFJTg`ILAXETOHUBS\\GRCNIPM@KHGJC^JNGPOnCvFRA\\IfIPGHGRBPCF@HFHN¡ns`SNABIh@TBLLPBR@VGLktE\\DVCVDNBXBTAVEPQHIHWHI^KLM@aKyGS@SJiPOBWCqNUEQ@[LONOROFsDKG{TQBGNBNHZONwFBQBMLMNKTOLUE]@OFWDcPMNWDSLQ@KDMJIJYB[AKDOJGHIR@LMPINCRCfGLMPELQPOL@LHVR\\AF_N¡^WEMAAF@VKL_JKFMNALDLCLH\\AJ]FWHWPQBUGIIKUKOQMIAK@OHOPQ@KDKHKJGlMRUDGF@JFXGVMFWHWDWHYXSNw@UEMICCIBIAOKIAMDELaVGNAJNtJ^RjLLBH@FIRETGT@DHBAJBJELBP@BUPLXfhHPVFLLI^SVKFMLETDNFHLLB\\@VMPATI^DTUHKNQ`URgL[RQ\\GZAXCJ@ThnNbtfV`TbR^`bLHdhJTA\\DL@TTZPdVzPZLXBJKLVVJRLCTAVb\\VtLdLpJVPP\\T\\PFPh\\^^PVEhQfCnLhFzVnVpnL`D¼j|RnR^RĀF`DlBjPn\\\\b`\\\\LFNH\\XLpRrNXCd@XTrV`BHEJSHINKJULIHMJEFKR@FFRNVDRDJJLPLDHCRW\\@FFHDHPNDDBHJLNA^@FHXBLCHCFePEDBHR\\TVJdJTJJ^LZVHXGNYHOBcCM@QHOBI@QEcQoEuJ@FKFIJADBP@RDLAJHLBDCJCD@DDDVDDDBPCbPB^JfBjRtPNF¦xxJFFbTJP`B@FHNH@DCZ@JHHVR~^jHTFcPCJQ^ITyAH@HBLPPDJ@HM AreWAk@GBGFWNSXMlCbBhFFNFJZ^bBFB^`|z`j@RFQfia\\PQLEFOLgXIH@`HjALC\\NbDPC\\GZMVU`GF]PGFEJK^GJQNEHAJATHL@HAH@RCP@XEXBVF^FHJJFFBVTTRPHNFFDF@vAJGN@LEHGFMDODOHKLQbGLGFWRQHWRKFQNaJQAOBgP[DKDYPEBoFEDGJEHCT@NH^BXDH\\X`RNPFDZHLJJLDDRDFBDF@JJb`VJL@DIHGJALDH@DGHENGHAJAbFHRZDH@FGLBBFHHFDNDFLHRRXPZbNLNNDH@JBDHTHLFVZlHTBRBdBFHJ@DCJDLCDGBmAIDADBBNN\\lX\\BF@PHLFLCLBPVXFTLZHLdfHNVZDDDNJPBLE\\@NBHDDHFJDLJHPANMXQhINQPCH@NCJAHDRCHBRHVBLDHBHBHAJIRANCFQTUNEH@BPH\\PPDXDZBPFFBHJ@FAHKT@H@DHDJDNA^FZGN@FBFFED]RCHMjGJMVEZIbBVDHBDCXFNBNFN\\bNHHBX@RDDBANABIBQ@MDMHADBDVFJF@FCHElCDGF@DFDBFBBTNJRPDDBBHBPLXAFABUAIBSHEDGT@BDJAFEH@NEFEBIHQXSLCFCJCHCJCBMFIBgAGBEFALBNCJOLSFAFAHGHEDSEeJMHIDGNKFEF]NIFAPCHRP@FIHIDQ@GBEFCJQJIJBFALDL@FADFBH@FDBBAFBDBBBAB@@FLH@DDJ@DFHAFI@ADNHBHEJPP@H@DNJH@DDL@BFJBBB@DCAABHFCDFF@DBF@DDHAFBHADBLABBJBBBJBDJNJF@HDLJHHAJFF@HDN@BDCD@DBB@DDJJNNDXBBBBHCHBJ@HGHKBCDAJCBEF@NCHDFHJBDADELAFBBJABDB@CJ@HAF@FAJDFCFDFAHLFHAHDhDDFFBZ@FBN@B@@JFFXFFDFHTDBD@P@BJCTBjGZBTAjFVRJPHLPVHFHDLBRAhDzZNCJGbOZEJBLEPFP^HJJDdDPCPGAfHVBtJ@BADHFALBDF@DBD@L@FED@R@NHLEH@NL@BEDFHAHDFB@JCJBFAHBJHDJ@JFPVPZDdDHAFCDFF@PA`CJCD@HCF@VDDDRBDFJDTBDCCEHEAE@CPIBOFADAJAFK@EJAN@DDF@HDNBJ@JCN@JRBFNPJDNF`B\\RXTRAZKVE\\ARCJBJFPBLHXLLCPALIRGR@XCRBJARHFPEPHR`PHLZTVFXBdDRC`BTBVFJ@RB\\JPHTRn^DDEJADJDPDBBJNBDCLBBF@L@\\MHALFXDVLNFF@BADEDKFCPAZ@DAFEGkL_PeRChBZCNBjM`EP@R@`NTDpRT@VFTBlHZFXBbP^FJFLANCTCHCN@BEDAHBT@dFDDFH@NHAPKD@FBFDDHBBFCBIPAPBRJPDN@FAHCD@bBPDbDPHDFHFVGD@FBTPTjPNNDJGfE|FP@TA\\BtBMRAtPLJbZNBbKd@HLLTRJPDXBRAZ@TGOLFF@DBLGnABBBHEJCJEDE@@FLFHCXJT@PG^KNBRFZFbB^BPO@QJIXSHILAPBPDzJPHbJPEPGRKLMNEJIFKD[@UDSDIzSNGPEPBPCPGNKPENILQACFMVMIK@IRIH@VGDAAAFMPILGTAN@LJDJFF@FDDGNBNHFLXNBVLN@DDTP`@VILAVFnVnFLIb}`UVATGRATBTB^KHDD@ZOJGDKDAJBF@RMXCbCFECC@EJKFKLGLAFEFABINHHBFDJ@TDPJdCLEDCLJD@DArxRPJAfgJEXSJAGGAC`gRMD@N@XHLHT@F@LEXGP@^CNMXMZKTKRIXQXUnWTSRKPC^K°QfKPADGLKHCJAHEBC^CNBBABCJADEJGNAPLFEBGHADBD@DGFAJBNL`ABEDAAECAG@GBKBK@KKSKCCMGC@EGMAMCCBECFEAKIMQEMFEEGKM@GEMCMBQAID]EWMIDG@OCK@[EI@GFM@KCKBIIMAIDONWEIHM@IJAJADI@MFGCIMGUGK@GDE^ONMFCHIAAIAAGACBUAMFKFCDM@CAGCGEGKECEBSFGJEjKdQJAXDJBXGPKnMTIJAH@HCDC@CACQ@MBO@CEBADATCFADEFMJBFHPCXDVKLAPDHHB@TCP@RIV@RIJATFNBVCZ@TAhHDBDFFBPBDEJCbHRFJBZGDGLEFEEKYQEIACDIAICQCCQGEEHQFOLGDE@ICKACEAIAEBIHIISEEGBEHUBE@KEKOOAEBEFCLBBABACKOEBCNOCG@CBWAUCEECSAKCCEACDELGLOBGFSFGNEJORMAUACKGMEMAM@]HG@KAAAEIC[CKEOCAAE@OHBFGCK@EBIJKKKBCJAN@FIPHPAFDFBLGLWHERG@CEAeCCE@GAEGCGBG@CCHGMUCCSGAICEWE@AFKCCICKQECCFMFSDOFE@KEOAOC_Me]AICEUMOAUDKKKASCMGKEcHS@CAOQ@C@GDEDAREDCDIACBEDKCGMKKSCOIMBIDEFERED@^DJAFC@C@ECCUKKIOCQGYGMKMK[KMOCKBAVIPILKJUBIHMPSXUHWHKBI@GBCJEREJCJCBABIBAP@PARDNAHCH@HC@GRGBIMK@CDCHEDGAYEaOACCACDEHCFICYCMEGSGECAC@ERSAEBIEWM]@EFKBKEEGCAGEEBE@IJMDMBAHEPAHGAMIMBAF@VBb@PCNA@EGKBC^DJAFFJBDCHABHFBXABD@LDBVJNBPJFFHRDBDBD@FAHGJCDAHCFGDAJFF@DAFGRJPLDBTBRJH@RELALGLODAJA@CGGAGDGDEHI@EOECCCGFCJBLAFCZCFIDEAMLW@YBG^GDC@GCCIAG@MGS@_QDKDEAIIIMECEMEAA@CFGEMDKICIGC@QFSBQDGEEM]AAA@EAAO@KCIODGNKCAKCGICEBEDCPGFI@EBG@ECGAICCAAKI@EDALAHCHSHGRCXARGDBBHDBHBDCDOLGLAGQEODM@ECAK@EAAEIC@ABODE@CEI@C^QXSTKBCACCEAEBCLIAAIE@CBCLI@EAGEE@GEEAEDGAC@AHGDI@EACQKBCLEBA@MBCJEDCGMDKEUDK@GCEIEGEACAMQQ@EFCNG^EAG@KCKLKFAXK`HFADEBCAUB@J@FABABCAGEOGIMGEIECMKKCMGECEEAC@IFKAGLMJO@E@CGEIkOU@CHC@CCIDEAIDIMDGAAICGOGDERKDCBGCICCMESMIIGCGAUF]@K[@GDCBOACEAEDGFEBk@SHKGIBOEACAKEECEKMMGOAEGI@E@@IBKAAE@CCBODE@QFKEEECQAIACC@CBIBAVADCDG@MBEJIN@DCBAAGBALKJSNKACEC@EJMFMAUHCV@FAFANKFEPaFGFIDAXK^GFBB@BCBECOBGLILEFAFCBAAIJGPQJCPDPEH@D@LHNDF@TE`YCIBIBCNADE@MBCXINAHCJ[pFTGRIOGEKEEIMGQQOEAIEAEJOCIFIDAH@TFbC`KPERAVGBABIACEEDOAKH@LCLIDADBFCFGBCKGCGEEAGGG@ABCHC@GFABIEGAIMEI_BMCGAIFMDABEACBECYF@LIHIBINWDCDETIfGJ@HCBCDCZGR@PEDKBM@IDW@KNKGU@GFILITGpKvOzKHCDCHCb@PDFAHCFGVEFCFCZgJIªÉPWTSxqDMDAFFB@TGJ@JAJEBILCHCBGBAÚLHBFAFAFIDCLKdQrIbOHE@CBCAELCFGHCD@PEBBJGHALIJKDA@AVMBCHANQ`IPIJIJE`KRKLCFGFEHA`FNAHAJDHFP@XIHAHGHGREFEPAPKLANDL@FBFCNABBJ@BAFADCDA\\NJAFDDBZ@HBBA@CDEFKBWH@DGDCHOPbDTZRNDL@NGRAJFJBJ@H@\\BJAFCJ@HCDHBBHBH@LMLCPKFKFCPFHFNHJDBDPBJCj_PG^M`U\\EDBAFCFBD@DDJABFFNJFD@D@LBFXJJCBEBAPCHJJHCPBFHBHDJ@JCFBPL@DCFBBFDJBF@NBNAJ@FCNBFEFKNGJDNAFEPSFAFGRG^BLEP@XGT@XCZKJK@CHATI\\BNADCDGBGLIF@BFHB^HAFAFHLBJ@BRDHDRRFDLDNBFALOHAD@JHD@HIDADBHDH@BCNGFMDALCDAFGBGKK@KBGBAL@BABA@MHCRCFEBGFClGTIT@FGVGNKTETB@GDGCKNCXORAL@JEN@LETBBABMFGJCJALALBB@FEDIBADAHBD@RMLONEVAB@BNNDJHB@PELINFJ@BCBIHIFIFULCDCBABUACAC@@J@VHJ@TAPDDGFKBEEGEACGBCDBDCLSFCFDJBLGDEHWPKL[NAFEACBCDEBCDEDANDF@HCJBDBBHBBBAXADPDDDBZENEJ@JJ@DCR@HBDZVLAJGH@NFHBR@\\EXDFBLFHFLTPDXLRDFCDGFMFAR@TEPAHAVBLADCAKBGNEVQPEGSDM@CCCUAIIICMKMGBA\\QFEBCAMEGAK@KEMIIHENENWHED@VJDADADGHCFENGFEF@LDLANPHBB@LCF@BBBPBJLFDHHBVBXCFCLQDAJBNFFBJN@JCP@DNERALCVKdEJCJBBFDBbRT@NFHBHABCHKJGXGJGDAPDLGHFD@NELAJMPDN@HBJAHIJ@HB"]],"encodeOffsets":[[[88191,31711]],[[94783,33518]]]},"properties":{"cp":[92.060214,31.476004],"name":"那曲地区","childNum":2}},{"id":"542500","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BC@ECKBKAEHGTKDIFE`CNIBAGIKIDGBOJE^MFELEHMJCNGfITFFCHGBGBETEPKDIAMBKFEHAhBJANEDADIDGDIDETKRWJGFAFE@MFGBECI@AHSFCTGJAVBBABEKWAOAGCAOCIQSMAAAEEC@CHEDCFkDG@EIEUEACBCNGNCR@JABABMCAQCW@GAMG[aEMAMEMDWACCGAUJaFYNUHINiDG^QFCEEEAM@YH]EMBICGC@C@GLSBG@EGIEAOEYAWCOC[OOG@AFGVMRSDEBMJQBIAGAGCGAKGUAQDGCQBGDI@MDGROJMRgNWBMGOKIICGECCAG@MF[AKIOCMCCUYGMceGKKYESUWAODKEKGK@OAEW[[kMMAABCJCnBHADCCKDI@CGIAEAcAQGSYkEUGKGSAC@ICGMMMKYaWOQQKGCECMGEEGAAHK@ECGQYEGBaBIHGFMHG@CCGBKHIJG@CIK_UIa@ICEEAQCCCIKKIYGECMO_Q[WEK@SGa@OFQLMFCpEFAZOLC\\ChOPARBbIRMLEXQRGXQHEHKRaLKPGPCNCHEFG@KHMBI@uCEEEGMQOSSAUEEIIEGE]AUFW@WDO@QBG@GGKBSBIFGRMHIL]FIHE^OHEV_NUHYD[COMaD[BKGi@_JGhWPKFERKOb[jReE@Q_i{y]_AAE]aIYMEEEAgDaNkTWXMHEHAl@XBfBqN@GCIOOAK@GBGzJSR]DIdOSEiG}]UQGG@IDY@CMGEG@_AIOaSEEwI¥wMEsOiQeA]IOADaAOCCUCCC@CDCDIACGKBICK@QAOBCJILE@EvIpFdRRFJ@PARGN@dDPAZGHMGWYU]KIIISIcSUQ[AGFCfODEDGAKGW@E]MBIKAGCCOMCGEG@EX[DQCGOKIKCICQMUEQ@ELQFENIJGVKLIJMTGFIAGU_qWSc@WDqMoQWKG[EM[K_[[am[iOkA_CÿE]QmQ{Q»i_CmKomUyUgEmKeDgRUF]O[]OgOES[O[UOoIcKsK[UaBUDSQKUIKULAIKWOYUyOcSY@SCKB[IScgKG_aQ]SaU_seMagm@SDIBWHYR[\\QhKVQR_LMVGCSJ]BSNO@UA[KKEGCMFSNKLETUJ]KKUEGOegKWVO@AAOFKAIBIGA@CHSFSJQ@EAGKKQiI]MsBIHMbUFKNCJBPLJBJADDNJVFx@TMZWXGXCXGNEHUEW@IHEVCNQHkLILGLCR@POPGL@JBRNLPLVJJVHRAXOXG^EBIG[DKCKBKNMLE`ILK@UBENBXF¢]`MBEQ[GU@KPKROFKNOHKDeDQJMNO@KJQHGPILC\\BZAJINILCR@TKXCNMdOXCPE^@VFPKLSNMNKRAAxEPMGYAMHMRA|SLHtCPEPQPM\\KR@VFrMXDPAjOTIT@zHbLN@LKJ]XGJGRGFOBUASAWCMDUCUF[lsHK@UAQKOAK@SF]FK_M±}O~UAZCJCPEDMBOHODEAOQIBICIDQNY@IAeFKD_@IHS@EDGFABIEC@GDC@OGC@EFIBAD[@C@MKECWFSEGCG@GEIBODGBCIEGCK@KDGEKGAUDG@CKCEIDE@MEWIEGQC[YEYIaGk@WFaJWN[LMRORSX_TaPcDM@UE_EQ[{amDGNUNQTQZ]XEHIS]KMHMDMLCFMHwAKAMICC@I@CGGCGKOGEEI@EFEDI@OFAL@PDZOBC@IFCDC\\CBBFJHBBIDCFAP@LMJEN@PFXBJAJED@THDB\\MF@LJBCJUIMBCFEFEBWLo^CCBOGSBKGMCODKCIE_AODUAWBIDKHKRMHOHALDNGFG@CEODCNCHE@QCICA_J]LOBCDEHOJCJGDEJC@AA@ADIGCGCAE@QDU@OQOGKYAKEIaIOSKYMyBQB@UB@ACFEFAJAPELIXMROHAPBDCrÍBKDGPSIKAC@WEIIIKAC@GHMBMJO@MBCDCXABSNAF@HGDKAGCAEBMCW@OFIBOCO@OCO@CFIDOB@HAXDBKDCJCFIKMMC@EFE@CGGG@DOAIGOQGSCUAkDmISKUGOKAKYOAE^UT_LUBS@]@MgKeCWDa@WBiOiKcABIaKDKMOFgbKXQjQLALSBCQUAE@MACEAO@]LS@EAKEII@FMTEDAF@DDFADIFAZSHEFILE@IKC@ODMACCG@EDMAK@[fIRINQHOUOEIUKOIQUWE_DMCK@MDKTQL_AOESaQMCWASEMBS[KM_OMEQDMLQT_TkLSAOEKEU@KCOIiKSAQJIRBTCLQLcPUFSRUdKJM@ME[JULKHERIJSJON]T_ZSHSL_dODORGTONajEVWV]BSHWZOF@TN^ERKFqGcAM@OBKNCLKHO@YOMDKH_NFRARMLHRNJFTGRAPGRDX@TCVEJDPOZTPFNFb@VUdONMH_X@TFPDPAJDPCDIDWHI@EBQCKDEAMAG@GJIRKNADWVKP@NCHIRJL@DSPCFOPAHDFFH@HADODCHEHCF@VCJANMRIDQBM@MGGAOD]POFUEYBCCEEQESBCDCFBFDDJDFFADEDgfAFBLGR@NHPVJNTJFXVABCDWLABAD@JEH@DBDNJJDDFL@VHBDBPKD@FVFHFIFCDCNEDMFOBQLGFI@ABB^DDDB`@DBGLWH@B@FNFPBJFF@bJJJCJ@BJD@FDVBZATBRJRJLXLJNNPHNKP@DRDHFDNHFPD^RBHE^FFHFFNTLjTRFLLANHPXVPLNRJBJJXRzTBFADABGJCNALDJRAFCD@BRNBJAFMNGFEFUDUJi`CBCJOJGHC@G@IICAIBIHAD@TRDDFLd@BAFAJDLAJCFKHYVEJKBAB@NADUSTQHAJDRFJ\\`EDOLMDAVPfJni`GR@jDDLXIH@HBLIBCDBDRFBH@LEFEBIXGDNkTIBKHEBAFKAABDDEDEBI@ABEPADHL@DBFGF³QEDC@G@UMKA[BMDkFWCMBGAKHGBAJIHCFMFCDEDIHGBABGDGBK@IAC@CDKDGJEBECGAGDEFI@KFSEG@CFO@MDUL@BBDGDLXILAHDXBHDTDXLXDBBR^DN¨L@NDBZBXNDLLNAJDLNHHB\\@NKD@TNDHBDH@JC\\@FAd@XSvOlPHHBLTVHFZN@TFLCFGF@DHVJNT\\XTrbANCLCF@BHFJ@FBBPJDBD@FGF@FHF^AFBJHHBN@VGB@DDBJUHKNeTONMCI@gRQDQ@IAe@MBELSHk@iDW@YFOJGH@ZNHBPIPYZEPAHDFBHAHCBKHMDOLELIBEFOFMHS@IDGAIEKMGCY[BICUBKDIJO@CAE@GBAJF@AJQBIDKAGHI@KNIPOFMDKHIBEI]BOGKAIBEFGTMBCAESGE@EDSZGRYFE@IAGDMCUUCOAKCGOAODMECBABAFCjCH@JIZEJEBG@EEUAEBCDGBCAIAKEG@EBCLA@MDM@ILE@EAMIQGUAMFMBGDKEGK@GA@KE@AFQBQDIACGAGIGEcCIBAEACEAOICBEJEDIAWFIH@HA@E@UBAB@DJFYTO@U@W]MKOEQCMKIQWSUA_FM@MC]OMAc@mJgDKAGCQMIKMGMDMLGJGBo[WGECM@]HEDGLQL_REBU@MBWOgKSKGAG@[TUJgDmAGgJYDSJKBKCGIGAYBiH]ROBW@OBCDOZOJODEDALKZIBN\\BRWLi`[NEHG^KZA@eEEEAACEEBEAAIBACNOLeEeA@C@KCO@iGSDMTEPEHKZMJK@GDMBQCqKKKMGIGKYmSEASLKCKGGAWKKIEIAGPQFEEKQ@EFKFMBYACDFHLHFLMFWRGBGC_ECDUNIFG@QEMAECGASAgOAIVBHCMS@IHCJDJJJFLHH@FEAO@]TS^IVGBGOIEAKBcNM@KE_CoGIF]LK@MCE@MF_^AG@ICKKEKAGFGBAGDIDQDKDIHIBGFMFANCJ@VFDDLGNKRYXQREhGtMd]DE@KOOKYG[EuBKRmLKFKJkPSDWINwRMKG]KAE@GIS@CDALAFADGAGKGSUEIDKLKDEDSCEE@GDGDCFIDG@EGKAOFI@CAIMWSSG_FQBICKD[AsO@ICOCEAGBAKOGYGIAGACCO@MAGKSCYAIBIDKLQ@EBOAMJKHGbWJMFIFKVKXUJYHOVULGFINMF@PR`PRHVBLKHMDGBWHKFKbGHELKAUEKLINGVATGHOA[V[^QTA\\BVHZDdUZCTB`@JILUJ{CYBqVUJCDIAUGMIOCMIWCYCKISMUCO@KQCMGACGCCK@IAIDIWIAOGMQKGKGW_kIOMCSDWRQ@KHKLGdKNKBUA[ISGKAOAOBGHO\\K`GPCTF^ERLRVNNHJH@NIHJaJKHCFWVERKJaDWA]DIFEHAbBLALENGJ@FEHJN@HKRcVU^EFYIIGI@OKOCUL@DBJABIBWJCCEKAGBCJG@AGGC@KKIEEBMGUAAA@ENIBAEAOEIAKB]ICC@KGOEEDERA@GDGJEBGGM@GDKFGDIEQBEDIAGCCOE@CE@GSCSFQNEV[BEACQUCOKEMIEK@CFG@QACQOKWIICE@EJMBI^wAY@AFEJQPMP[\\eGS@SGAUBKECCAAK@DMHCBCHEBIM@EC@CBK@CAAUCODEAECCGEEOBICQBADKBABGVCFSHIPUHILEFOFkJMFQDG@KEEB@FBH@FKDIJIDCA@I@AHCDEAIBC@U@CHA@AGQKIEAIKG@CDKDIJKDI@@EEGEUDKAGAAAHSF@NAJCFED@HJHDHIH@BH\\I@ICUKSCoFCB@JELKPGDGBU@EPGDC@@ABECEmyEAE@KFG@CDM@BKFE@CDCAIBEFGHC@AAGIICOECGACEBKFUCEAGGE@MBCHEBEKIEKIGEGCEGOMGMKIEMAIOCAEGYOIGQKaYEKWSISEAMDCHC^GFS@SJGFENBLPPFLAZ@TFTJRLNKNWrSVYFQHGAIIOQOMG@SLEBQGOLGAQYSIKAMDodCRMNI@[WIBmPmHQTQLcBUAMBcPODQBYAiBUBQFMFIHCHENEDO@y\\YF`WNKCCEJ]COKGMEdQAGQDYIKCQBQBSGIyFcN_Dsf]ZoJQFG@MKIUFMLKTKPKEIIIe@GQDUHQ@IQY@GpMJE@I]SMGCCBERIJI@MKOOOQ[@UDgAGGMkQUWUAMU@ICOL@HABCDE@@@BEACU@uCKGAEBItiFODU@OG]MgIOIMSOICSAAEFGLGFKEMMCQE]CWNIJKB_QB_FQFyzMJAH^@JGTa@G@B\\ARAjERMHMBQbSPAHITIJALNJITSPHheXEBaNQFWBGU@EBAHHNCHSBGREPIFSA]CG@OJKJOHaBQAePifWdIHk`_hYXULKBQCMBKDIPUTUPYLgV[F[HO@[CUESIIGSEGBKJ_bgXaHiFcHEDaj_HOA]B_LUAOGMFSRgYJeBSCeAeRiLQHiM_EQAsaOCWDkVYRK^]DWF]LGXCVITMNINMZa\\wVGHIXX@AbKVURDPLVC^UVQNmPUBODIJALLLRDJFBLELmnMHOAgKiAQDKJYhkx[^CJYZSJMAYBSHQN[\\KHgVEACM@MKSOEqIWIQMCUIGEHCREJULcJQHIFQjSRONeCDSAYDEiQE@AFBVE|ELOFC@MDMGIISYSMIMGCMEmK[IIEEMFOLKFMAUNMBGEMMEGAMBMFSB[GQK_GgAU@MLGLAN@VKTGZILSLQFWEMK[EcBGCOMgCGCCDENo^IPIJsVMBaJGHGVGLGR@VGVSNGLEPDLN^X`FNEXUNkTKPI^IJ_LOvMLUH_\\KNGnW\\G@AEIW@QKEUDiLGJUHWCQNMRUv[ZCPN|`p`hBHaXWjQLs@GHCJ@XDR^tXHTLTBPDRRnXPJPLXBLGZCfCFyMM@OTUyªS^ORAFNnHP\\TpZXJZD\\HBFBPFNrpDRELKL[FQHCF@FABBJKDIHQHCDCJQNUFOBE@SHKBCDK@IFEFQJKBSJIBIA@FE@G@EHEBIBECC@BB@FDDEN@HF@DJDD@DH@DJ@BGNMHG@GCUNQPCHANCJEDSNMDSJC@EFGFAFMLAJCDAF@FDDEBCD@DEHGAOAAEIGKACCGCM@IKUL@DCHDLQDEJHHBB@DGP@JIJHL@FCLWDEDBdBBRDJHHLHF^JPHFHNTH^@NBFPXJJJLFVMRQLWDEH@BHJDP@NGPc`KPFNPVBXBHAFDP@VGNSTKPATUV_nONaTEFER@JPNJLDLRPJHrHRHLDT@TCbNRTT`TDTBNCHJRJRCX@HF@`HHF@~ORBHFJLVRTLfJVlZ@ZLLTLJTHD@NAFUFO@OImLUTOZ[V]@WGM]cEOJgJSXAMD]NMLMR_L_LKLEPEb]nCHCLMVMTCHGBWJKi\\URIH@BNDJ^l^TXBV@tJ\\@rUVAFJAfJV^Z@REbBP\\nRJ`VhJLLFJDPLBjID@HJBHFFJ@\\KLHHHJLBHJFTT@RGRPVLLXfVBBDARO^A^]\\O^GZFLRHHHGZFRTFHHBDANKPWjGNI^UPQBaGECKFI@BDBH@DCDDJ@FCJFBFHBFCFFBBFMJ@FFFBFBJFBFJEBEHCF@LHPAFFDBLGLGB@FCDNPBPCD@DHJ`rFD@DKJEBCDGDADKBEDEPC@@CEEIAA@IHOB@D@JALEDIDGHE@KIGBCHDHAFIFCH@NADGFGDiøC`@NLhRZHHFLALENSP]TYAWJg`SHMP@NDHRNAFQBKH[JKFMNC\\CjBFAH_^I@KDkCWFSPKREPE\\MXSHWNOPi\\GHiD[D]JKHEJARahGT@ZOJOL{x}EPBddBHEBmEQ@UDedS^@ZNRô´BFENSbQrANPB`EhIPEXDLJJFJ@PALEFyRABJpBNBJJv@HEPINw\\GHGDYDGAUDIFYLGJ@^RRHNCHIJFXLHPATOHBJJRFZAl@\\FRNHHd`PRJJRJLAVMTGJ@JHFTJDJ@LBJTBHHLJDNAJMHGfQH@NFLJHJFrLXHVDTdfF^HZLV@JJXDVCL@VLLD@KRBNDVPAFGHCHJTJHABMJADMLCNIDEDDDBDEJAJEFAFGFGJADTHRJN@@H@FDFVHJFZADCAEFGBGFAJABDVRXJVDVL~PPCJMNINMRCLBNI`CZAXDRFPHVTJHRDJPCJ@XKXMT@bHrTlL¤JVDT@TMPFPLN`RHVMFMXKV@pLl[hCfDVD^\\T\\TFRIdIVFV@~D\\FXTNHLJTXLHNJJJPJBPa`CL\\lDVFPThHJN@JL@RANg^GPHLbFNLbHIfBLATANCNHNDLJHFB@LNPBNDDJB@JAFDBBD@HHJFJNJ@DCD@JDJFDDFCDMFCFO\\ALCBDHHDF@BFCD^AZHfGP@LEFBFHCV@LDPFLBH^N\\@JBCHFJG\\HBDH@FFJALWHCDAF@RETHFDJZBBDCLQFCFCJBHFDBBHABDJbSRCFAHTJDDV`NF\\XDBF@ZKXGP@HAH@ä°VDDDHRHJLFHLBBJADB@DBFGJGDKD@FBHELBFtPHJDHBNFF`CP@DBBLD@XAjML@FDhDNAJEJNABgTEFODCbSPMTQHMJGJSPUXKH@BHDFDDXFJAXJL@PFTHLPNHJFLAH@BRJRFfAdBX@PDLLLVTNNTVF@DGJ@DJDBB@FDDZPPCDABACKCYBGHKnGpOH@PBBCAQDAREH@LFHFHJDDD@RCNENCFGJCFAJFNBXVRHVA`WHGvBHKBUFKfKPAHKGQCU~G@TAZDVD^DJ^GXSZIVEZ@dNXGVWLEVAjB@LCJDQNMPKB@DCJ`@\\HBF@LFFBFAFCDJDDH@DGBOHDBBRnnbGVFdLBEHe^CVIFMTO^ExLPCHKJQDQJWPUHA\\PPDRCLCVCD`NHVFNCT@TGDCD@FDPAFB@NFFDBF@HCBADEFAJBPRHDBAFE@AJGTCDGBIF@NFVFJGNCJ@JDH@JEJADADEFI@MFGLG\\KFEJMLCV@PSDG@EAQEMAMDITUDEDAF@JFV@DBJFJ@J@FAHGXBZC~BdC@VDZJrZ\\RXBv@\\LPBPB^ESTBRHDDNBPHVFf@TCFBNNL\\FHFDBFJL`JJ@HILAJALHF@FAPBFBHPDBVFHHLDHFBDGD@BBBJDDD@FAD@DLDBLALCBCNBNIJAH@HHD@DEF@HCBG@EHAFBDGHBFGV@FBHNTIPVDNCTDH@BCL@PLRVbLZBxVTRLDL@bOHDFXBXJJXFhEPDXPRRJPHHRDxKVFTLPLNNBLI\\JT^`AVGHGPGTARZHtCP@VDLPLXBXFZNPTJtLN@VA_XGXBjTXEnQ¢IdOLUTG[VMNOXETHpbbPPfRH`IR@d@JBRAjJNALGBMPE@bARCNGCQIKEQAONSNMR[FKBaCwGIIEBQTYVyDOHKRKRE^@VCVK^KPQJMFSLWNKbYPGLGZEZ@bGTE^F\\FVLTNPRPFRCPKlUGlBXETCXKNCTBRCJEhABHCFKFAPANFFAHKFIFC^@JDHDPBFFH@HGVABCBCAECACWHEZFbD`HZBRCLUREjLTJr^PDB¶ANCJKP@dHpD\\@HDXBLDJD@LFH@NDDZXBHVLRFPGVBJDBD@FB@VCXA^LhJHEDEBEDARDJCDEB@VFLHD@DALGJAHIJCJGHOLKHKH]DEBALBdXHBR@LHHCNKNIDCDIBAVARFFDJJJLDDJLDBZHPBJFFHFBFBHCHBBBHHPJdALDR@BBjJP@bFJHJLhVrTNHPPZLPHTFfHBFALLNLRATBDFDJBDBDF@DEPCBiHEFADBLCJDFBBdJRBNFFD`H\\@TBHFBF\\HLHlRZBN@NBPALDRD^H`NpJHFJ@PFNBNBTEJAXBPD\\NXDXTNDPFTPDBXCRJZFDBLVLDXBDDDHBBlNRDTLbNZBFDFBdF^HDDTXX`NHLD¢TMJ@L@ZGJ@VDTCLBZFbPnJTHNDNDHFDFADGJ@BB@J@f@lRF@ZADC@CGG@GRERIdEfSLCTORUJGDEFmDGDAH@HBXBPCLEPAJEH@dIjAJCLAHCXAjDVGDG@OHGHGLEF@VGJKJAPMFAF@HDFFLDPCJBNLLBH@@LJHBVJHHBBDALBXPJLRFTHDBB@JBDFDdHFDFDFLXLX@ND^BPHPNL@NFLBTBXCHBPFLHBBFBPBLALEZEjNLA\\DP@jJL@fERBHADEL@PNPBDBDDDJHJPFDDJTLFJBBBVV@DDDVFHDFFBFDBJDL@RGJBDDJRLL"],"encodeOffsets":[[88137,36722]]},"properties":{"cp":[80.105498,32.503187],"name":"阿里地区","childNum":1}},{"id":"540400","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@RLNPVBdCLLVfXJZDNFNLP`PPZ@XNNLZ\\VLZ@\\ENGLDXIBOA_AMDOPKZA`@vARDHPCPDXVFVBX]HKXKX@hNNADI^@\\CTENFnFBBM`BLENCF@FVDL^RFVDlEVF`VPJVDR@NE\\[VEVAXCTI\\IVDTHJFLJPJND\\DPETObGjEPGHQLMPAZAZFXJLLN@NINCLKFMLCRMVFJP\\LNDMVFFRgtBLHHCTFTVbPNTF\\FXKVKXQRQZMJMfQRBLJ@dJLRAXFVJPDZOLKXATGRQfIRAEIKIYWAOFMRMdQFKHMTINHNNFPEPBLXDPGfKTDDNEdBRfDIPGRKPONERFTLXJN@LG^[`GTEHKTATB|M\\IhAdCRINQHUQmQSEcLIfENEHMXMTAHKDMFQ@QNONELaPQXGT]LGPKKfUDKGG[IQMASHMPMPKVInONKAOBMPSTI\\@VDP@vYLFTBPHPPVLVDRCPOHSJGPBVXNAJMBiHQPU\\EV@LNFRPDRDvIVHXTBV@RHTJzLPRFPAP@NFRJLJRF\\@PFLHZHVFTATChIJCPFDDP@LCPFJHNBFFTGN@DCLEDCBEECOCECJCLKHMHWTSLEFAFBDBBBBJT@DDFHFDTCHGF@DBDFBXVZFABCHCLCR@HA@KPSNEHGNILC@GCAEAAIPCRORGFAACEE@E^ALDDADGBI@CEEEMAORwAEAC@IBA@CGGCGAA_QSAEE@ADAHAHCJ`GVWC]cmWi@QLO@OI_KSW]SSWMsUIUBQVeBYGOUQaMQWMUB]MWSYA[KMeIUUK]@WT]@OAUFQNK^WXMXANBVAVKPUH]BWLY\\EJ@LA\\SNIHKH]BIRwJMN[BSOQASGKKIIaIGSAY@ECFEHMPMHAZEVIDITMZ[LKZINDF@BA@AEK@CNMJQ@SGQ]QKAG@KBWJ[JMLC@GEEAMBOMMOI@QDQ@E@CAKSIG]KIGCEOI@CHKjWJA`WN@RDLCBEAG@OBKB@RA^WNIDE^IRIFIPeLs`mBC\\iDIJGTI|PF@NET@RFNNR@TKTEfChaRC^DDA@EKQAM@MHKPEVCP@PHBREfB^A^F\\DHf^F@ZSNILARDPJDHALF`BfATKPCLFJJNFPF^A\\EFUBIBSTGDGH@HCd@FTPJNHBZBJHHVQGPERATLjDFNJJDlFJAbQ^GHBLRBHEFMHENDPXpJHF@HPDKJEHEIaFaDEJK´¥HErC^BBBBJR@BLFDDFPAJBFABEFCJMHCLBJFFFFBXBRENBJCZC@AEECEKAMGAEBETMt[rPQVQOAOIMCEQBEFCNCBEEKKKCE@CBAVQVKBAA[DEFAJAlHJ@FAAiD[AS@QHSJiHKNQDGCUG[K]EUAC@MCSBMFU@MFMFaH@JDXDxJ\\HVBJ@FBDJHF\\@TRLCNBF@PED@HN@FIPAHKLQDMFCH@HFPBRBBNF@JCHABDDDLDDBLJJVHNFD@\\ONKHAB@BJVRZRDFHFCFMBQNUVONCFAJCDEDWDKFGH@BDH@DAJEFAJ@H@BPBLFZAJGVCPFHHVJTKVQ\\KX@\\HHENMVS\\DPOJKZ@ZSDOHU\\WTGXYJc\\WJAXQCYJSbcbInHhBARP@^HRPLLAtKFMTcRQRKPIPENIBGCG@MCIFGBEDWAWDEHABCFCX@\\HHFB@TKBA@CAAbWJIFAFE@CGGQEIGAGBCFC@CKSC@KLA@AA@ILShmTeHSJKHCTCDCDKAgCIDKHDVJLB\\EbCLAJPHbDHFFZXHFBD@DAFFFHBDCFIdejOLENORKF]EKBOFGFAJS@WBSXaF@RD`GRSHIBKF@VDVBhJVJRLHFJ@VYHSLUFKLEP[G[COKKGKLKJQFSEW@IDQReLIHUFIJGBGCKDEJIXGNGFEJUHCFOXSBCAEACMIKOCQDQRSXQLCbHN@JAPIcbMHIFIRYBE@KCGCG@ARAJCBSTMHGDGAIHQJINKFEMaKEWEICIEGIEUCK@ELQ@ACGIWFQAGDQCKBG[GCCBICE]OaBCACEIEKASUCGGEAEAACSGGGBMB@BE@WLCAEDCDQHABG@QEIBOFYISCUKCAAKQQEOGEKEIACBEDQPEAEDC@G@EAG@AAACKECEBCHI@GYSUGCCCGEG@E[BIBUCKFINNX@DOTDZANCFFH@DADGHELABMBGHF\\HTBPANBNAHCDKDAFFBHHDB@HKHCJALIJGLITBNMFQBGHQ^MBCHALFFFPAJ@HAFKFCFCBCDGDCBAHENAHFNAHADQNGAIDECGQEECAQCKAMBGCIIKAEOCQ@KA@CBURMDCCCGAIAQBGFIFElYJKH]@OHE@MHGJEBIFEAKLCHKBGAGGCKA[GQMKAU[GAKD@FADCBE@SGU@IEKKACBeAOJKBIAGGEC@GDC@CAEKGAGB@CCIQMMNCHWPkLELA`EPIFUHc@MICQ]CWPQPGNAHDVLXHX@LMZOLQPIPSFkJMJ@FTTOPQFKJILOL]jKFCKCaWCGCS@IEE[BWJSGKCIBEJGZGPWbGJMFW@GDEFCNINBNHNKPAP@LFVEJALDN@N]nKPOF[DEPCNGH_DMRQDIAMBOAMMUSKAOBIDCH@PS\\UBMCY[[OGQWQKMOAK@AMAaDMZg@GAGMIYEAIPW@MKWGAIICAKACC@EHcNEDGEKGG@CPEbQJKCKGKMEE@I@CDYCMMKC@GFOHMJEBEAAOCKKIEE@WPQPUPILC@KIIKQIAEBSZ_AKKAKIIEGAI@OEK@EJUCGBC@ICCC@GBEEE@MAIDGAGFAL@JCDECQEM@GGODEHI@CMM@KMCI@EECIKBEEAIBC`WDE@EIQy_EGE[FMHKHELCNARFhDdJF@AIGOAKL[FAPANBBGDCRGJM@EGMcSIYMUCMAKBWEQAK@EHE\\M@CeQ@CZcBG@AMKWGIAKBULM@SAGBCB@DBPANKNCDILCBCBOAcWMQO[[g]ekCAUGGIEQUKGA]GCCCOIGOCaGGCGI@EDeAMCKACEAG@KFODIDG@GCERADARKRCJAH@HBHFPDL@BIPAD@DICCDU@ADA@ICBACCACQEEBEB@DCD@FCDBJGBEPEBADEDAHCF@DEF@DGF@DONIDK@EDOBGFC@CBADGDCFCBECEBILEEGHGAKDCA@CQBIAEGKGE@CDE@aEGFAAK@CFKHAFIHGAGFKBQAE@CHGFCLQTCN@NCFEBQDSAIJOBMNCBWBSFMJMHEAKGSGOBGBONMHIHQTIROHADGJCNO`ERURMHGBS@IDOPKRCDIBUAIFOACDADBFCF@FIAIBGCG@C@CHCBI@CACCCGECCCYxB\\ELCFOLIXGLKLQNeNGDIAMKQGGAO@ACAEJSDKCQCCMBmAQFWLgDQFWJUHCFEJG^BNIRCNAHJhANCFINEDKBsB_CWGSKMEOCg@CAGGEASF[@]@QF_@IC[MGGAGCAMIK@WD_CSB[COLIDWB_Tml]V]EKAOJGVCbCRshYKQAiJSEWMo_I@[J{@OC]OgIOA_Is[WM¥scO]cIçgga]QcGc]©QS_[MSWQa]ecWQIcMaIsUaMWEu[[q[iScIMYKueeOSGoeeKOgOmW[Sµ_[K_QOIs]Õy[YOSG[ANQESK_OYAaD]FYIaGcC]D[JASESQ]cEPSFKFINA`OPIH@FDL`j\\RRJRJjdXNTRNFLLNN^RVHVDDF@JGFIBCDKDCAOMA@E@YTOHEH@PFVBRLR@JHLLJBJAFBDFDL@DB@FGHADPLHLDHADGFUHKLMDILAJFFBDARBPFP@NELIF@NGTGHA\\GTCHMHCRAD]VOHEHGDC@IAgAMHKJEDSBIFEJCXCHCP@LELGJKFGHCH@NMNCBG@CBAJ@FMFEJI@CFAJHJBLBBLFHHBJ@FEHAFCTDHCFAHBD@HBDDDFBBDILDF@DKLAHCD@DJ@FDBBBLBPEJDHBHAPCF@FBFADCDMFOBGDC@ECE@EBGD@JCFIFKTOREDENCDCHKPIJEJADBJAFBJODAFBD@BKBaBQAACIAKFYDGAS@GCOHIACAA@GDKBEDM@GBEBAFCBK@CHGFONIPAJEPATBD@JDL@DAFIJKRDNERLNPJDFEJKLBL@FGNBDFFBBAJDNLPCD@HEHBBHH@DADIHGH@HFHYFGFCFIFI@CBEJKJMT@HEPBTAFEDGB_@KFCFALGL@DHL@FADG@_KMNI`QVMLqc[M_DIaQUDGfULYBWEeMgFCAWCICQDIAYIE@YFgFOEEBAHBFHFFFABIhoRH]IcA[NMRKXK\\oJ_I±CUgY{JcAwBI«PSBKDS@GFGDGBMCaOGRGHCHQTDJBDABGFG@IMC@ULWFKIYEIIGCG@II@OSU@WEG@IESM@GBMIIBIBOCKHOEQFK@CBAXCLMHGHYdYD]DYAgVSCsLWCQHEEGKCASP@FECAHKBOLSD]N[HCD@FKFKHMHQDKCGGGIGEOUA]CGBKAAKKDIOI@GIG@GCKAAKGQECBAPABEACBSJEDGJKJ_VSXIbBL@JMX@BfpBLBFHHJDJ@JFHJ@JJFNLB@J@F@LJPAFABEAKLOLENFDE@GFCJ@PTHHB@D@BMBAPCAKDIFATALCH@DCL@HCLBDDVFJDN@FCHILCFCL@NGTHV`DZ@TJ^NXRX\\VZNTCbBZZPRJ^SdFbRXDZHZLZBRFT@RPPrVf^NPJPVN\\Fj@bFLPDNNLNHHNFTBPJX`ZVPRRVLPFHHLRF`VnBRADILARBJBBPBHFJJDXFDZE\\DV@XHLHLXNJDPk^ApB\\CR[NIRHhAPBNLLTLFLMNEVEjIRUHKJAPINUBUHULMNMPUTWdLjHNBLIPIR[XcPQJONGNMJyHQLSJKCU]CKUG[JMIIKE]YBgHSCQEWYMKMEUAWBUBQJ@PANMLERMHQFWBUEWKOIOQKQKG[NSBO@SE]UKSMWMQIOMQAODSCQSIMI@eKEXEPARIPARV\\DRCdDTHPCPVPRZPNVbLLDPKHWXIXDtDZC\\KJSAaKKGK@KLC@IACDAHBJ[AKAMDG@GACBA@CZKNDQFY@QEG[AMOO_SO@KHITATIRELKLEN]ZUTkLU@oNWDUNARNNBPKTDPNJDXARLHRAVMjOrBRFRPTHbX^ZfXVDZIPQR@FLBNNNVJXBLPNHXDX@LNFRUJQBIJAPLNPDNH@LBJdTjXTH`INMVBRJPDT@PFFL@VF^HLRDLCHVEJDPDLNHjXALFLLDNRGZIJNN@dCZBRFLBVITCTPL\\AjYZCTLP@NGTBJTEVOLMNHNTBVITC\\INHARInJLHZNPFPLPVBP\\CLRfERIPa\\KDAN@PNHTjHPRRfDlTRD^ER@HMNBNRBPFTDTAxFJNLND^AbWlKRMTIRRHLN@NETAZILSCKIMAMDMEcBUFQXQbIbC\\IVSFMAQCIPMTIHW^qRKTCf`NPTRVHJJRFPHFRNLPFRHFNB\\ZN^IXOXS\\S\\@TDrAXQRSTQ\\UXMRKLWAUGQKGWEEMBYF[TQTGVQbMVEdC^IdORDX@REVUVEVBVGrBPDLHBJJJTHR@JOFOXINDrF\\Jd@RMVK`ERHLLDP\\NVFXE`IXBHLJN@TFRhDnMPO¤eTBX@ZER@LFPLEjDTHRLTDZNBRERB\\X^BV@TFRNFTBrEZITETNNpPRJXJFN"],"encodeOffsets":[[96414,31219]]},"properties":{"cp":[94.362348,29.654693],"name":"林芝市","childNum":1}}],"UTF8Encoding":true});
}));