#!/usr/bin/env python
#coding=utf-8

from pyecharts._version import __version__, __author__

# charts
from pyecharts.charts.bar import Bar
from pyecharts.charts.bar3D import Bar3D
from pyecharts.charts.effectscatter import EffectScatter
from pyecharts.charts.funnel import Funnel
from pyecharts.charts.gauge import Gauge
from pyecharts.charts.geo import Geo
from pyecharts.charts.graph import Graph
from pyecharts.charts.heatmap import HeatMap
from pyecharts.charts.kline import Kline
from pyecharts.charts.line import Line
from pyecharts.charts.line3D import Line3D
from pyecharts.charts.liquid import Liquid
from pyecharts.charts.map import Map
from pyecharts.charts.parallel import Parallel
from pyecharts.charts.pie import Pie
from pyecharts.charts.polar import Polar
from pyecharts.charts.radar import Radar
from pyecharts.charts.scatter import Scatter
from pyecharts.charts.scatter3D import Scatter3D
from pyecharts.charts.wordcloud import WordCloud

# custom component
from pyecharts.custom.grid import Grid
from pyecharts.custom.overlap import Overlap
from pyecharts.custom.page import Page
from pyecharts.custom.timeline import Timeline

# version
from pyecharts._version import __version__