(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('青海', {"type":"FeatureCollection","features":[{"id":"630100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@PBHANKJMDCTJHBJALC^CF@PDD@FIFCLAJEpMJBHFDD@JBBJDL@DIRIAE@AVE@CCMDEbA`BJ@TSBCBK@A`IFEFERINEJCP@TCJCTMLYLETIPCGMCWA@SHE@KEIOBaDMLY@MOoAQACC@QBAACEEEWK@ADEAGGGOIACGMBOIIIMAGDENGJOJGBG@GMMAA@KIKBKM@GAWMDC@ACEAIECKE@ELU@CGK@WCQ@WIMBK@GFCBE@UAEKKAEKEAEFIJEDE@EESDG@CKGAC@MEI@EBSAEGKKKBIDCLABAACGGHIDMACIIEO@ICEGKDIHGRMB@HHFHDDD@DADG@CECCSDEDANHLBHAPADCHIDAHAJHFBD@DC@CGU@ABEDCFATCJELKHCDMBAJADCn}FM@KCC@I@CCEKIMIKIQ@TS@ACI@EJSDMACCCOKOSUOBEDIAMIEGBMKEKCg@O@WDCFMRW@CWmIMMOWaBQCOEIMG@C@AFCBEECG@w@MASEUHUNKDEC@C@CCIAGBKCCGAaBBMAEIQCIEIsYKKEAG@MJEHKRKNCJ@PABCBG@ILGBGHCDOBYC@PDZA\\BF@DGFkLE@OGIAmBiPMBKDI@YJOLiHMDUPKJAF@HkDQBmRCD@FCDEDGAMESQO]McCAYCGAOIUEACBKEOCAMASAAAAIIKE@EHGBG@EAOFGCCRGDAB[BOFCBAJcPGFGPCFDH@DINCJEDmJ]HIDIHOPKTEJOTAFDDBJAHCD[BSNKDEP@DJJMNCLBL@HKLMHEJEDI@KHEJWDCBEDGDEBAJCBKFCD@BBHJJIF@JIJCRQJADJVEBCB@DDH@FHN@FSn@FBD@DOFCFAJADWTWLCDGPGVARRN@DUTENSJCDGPOLADBNBHHCBBADBLERBNEPUX@FEJ@FBDDD`HFBJLXJVBLHNFD@JKPCPG^WLELARUVBPDFFRFTN^BPDFDVXPLJLfTFD@D@DVTRHVFFFFPVbNFJDbHFFPPVRDADEPAJEF@JBDAJABAP@HCBIHAF@HFH@DB@FFL@HAFBDFH@DIJG^@NCJGDEHDVNPBTBJAHU`GLCJ@JCHCD@NGH@FJDDHCJIHMDIJSHINDFCDCDOJDJKTCBI@WAQDKDQPMDCDKRERKFCDAVGdSVILELAPEH§hMDIAUOGCI@eREFBHQHQPGD[@QEGDCFEDG@CAISEAIBGFADMDILIBAFEDANADADFJADGHUL@BB^EJGRKBEDCF@DBD@HCHEDYRUHCBADNLBH@NBFFDBDAF@PBFHDGH@DAdINLNJHHDR@FAHIFBJFFBANNLFHVHFD@JJHFHNBNKXA@AGACCCCCI@EHCVEJQLKJCTD\\SBC@EDC]F@THJAJGHCAGBGHENAlDFAHKJCH@XFPH\\MLBFEHAND`@^DB@JQFA^FTILAFBJLPFDHJ@PHH@JIXEPMLBLUJIFAV@RKtAXBFDFBV@LARANERBJIJCP@PFLBNAJCNMFBLFL@FAJGVIHCV@HCBA@QG[@EVSBEAECE@AFAZ@HBNHF@FODAZGTGJA"],"encodeOffsets":[[104041,38159]]},"properties":{"cp":[101.778916,36.623178],"name":"西宁市","childNum":1}},{"id":"630200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@CHF@BDIBADEDADBJADFFREBGCMLB@CA@CEE@FG@GKF"],["@@J@xarSh_PIHATDZGT@PALCJGXMpSTCJCHELILCv@fKVJTVJHJFVFZDZ@hHZBp@PCVBrLlNhL\\DJ@^GP@VEPITCHEFAJBLCZC^MJAFGAIBMDCLECOEG@GLQBIHIBIQIC@CAOOACYOIMBIAMEEUGECPIFILGF@HFRGTBDFFADEAODEPCFCH@HDHABA@KDIJAP@LEPCJEH@HMGM@GDCHCDCDQJMNCDEDGDED@FFD@DEFCZCHGRCBC@IDCFBJFFCLSJG@AEABENCHEBACEBCPDFA@@CC@CBCNIDKH@HFB@BCBIJCLKLE@AAEDEDENIHMFAACIAePI@OGOUQEQQCAK@CKCE@CEEIAKBYJEDGCAGIICQIG@OFCHKEIAGDCDKAEDGJEJCBIJKBEDEFKREFGHATKTEFEJCBCHEBCJGRCN@\\@HAFAH@CEGSGELCPIRGPKN@FBFEJEDCEMG@OCCDEAEBGDAGCIFADABKBCLEGEAA@CDILKFMHCH@XEJKBYD@JJPO@CGGDMEIECKAMGEEEMHEDEBIREJGDKAIFIBG^KDAAIBEAEBCBAb@CGEICKMIPEBEJMNI@AGEBGAEBEJMBIDKHCFIDABFBBJAB@HGD@DBJBHCDB@FDBLAJEV@HGFKRGFEN_BCVERKXARIPBFEBITEHGDGDCPAV@FGTAFI@ECQEK@ED@NDTIPEDGFEFADBH@FAFGDMBAGGS@OECAIDGAGDK@SFSCSQE@Q@ACBEKE@CDEKK@GCAEACACIBGGOYAEBCA@CJO@CEEIEBMCMCKCQKGE@ECSECAEIICGAGBIFEBOCCACKFKP@@GDC@IBAN@BHLB@ABGP@DIH@FIDGFG\\FDGLC`ABELIACEAMDEASUACDKJKJCFKBIBAHAAECCGMKKGMIIAEBSCEEEAC@OEUNMAQBADGCEDOEK@KBCFUFGDKCEKOAIFUC@CGCCC@QJE@GCG@MVGDOAE@_JI@MGWDS@ABAHCDUFUAKIIAOJUDSJIBUMCKGEEGQICGOICEGKQ@MEKAEAEUQMQCAIDQAEMGCGBOR_FsHSLQPMVML_HIBIHKDCHAbEFCBGBOI[CEBEFE@AEE@CLGDC@OFGLMlYLMDOACEAUDC@CAMOCAIB]GS@KAECCG]O@ADE@E@ATCJBHLHBnJDBF@BCD@@EBECCEC@EOCGGCCKECCEMOMEBIJIDSNSJYVIHQDIAG@JCBABBHQBUESDOAQDKHUFOTKHC@AEC@CBKJAJEDODANE@QAIFILE@CACA@CLGJK@G@AEAQHG@AABCAA@CDEAA@EACBGAGBG@AGCAAKkIOCAGBECWGACDADGIkEIEDEBADA@EEBMKAAEESFC@EBBFCL@@AKAgTIHODONCJDHdXBD@JER@JBTJb@DCFM@QGCBAJDJ@DCFKDWLOL[ZWTI`@FGDeNMBSHMD]@]AKBWLYTGDOLMLIRBJFXGbGNIJQFKAc[QEQBCDALKLCJBHZRHBBB@DEBDSFEHDFFDXDHD@FEHMLEP_`UL_bADGLHR^PCJ]JILANBB@D@FAFFFPB\\ALBHDDHB^@PGRCHa\\CAKKOIG@MDMEEBGCELGDKV@B\\R\\D\\HFD@DADeF[HSBMPC\\]baFIHIDQFGPG^EBaCCNSXPNHVCDeAmVaB@HVVUFQJCJHNCBkH]VG@SMcBUAQ@QHITA\\KRSFOGGGC@EDAHJHBFAJCDCBICCC@C@QAGCCGAE@GDETBJ@DCBC@CCGGC@EDE@]AIBOCKDSAGC@NHZCB@H@RCLBFRRER@DDHADKFNBLLtZFJDJJRBFANbAHBDDALBHDJ@D@DFDLCVMVGTFNBx@H@FDAFED@B@DNHFJDPARXbNPJNXn@DQXENCD@X@PDhFLNLHAJFBNCJAFVPPTPLDDBDCNIT@FDJ@BSTR@LJNJLJDF@D@JDD@LENm~CDIBABCNGDKLIFSDEBCDAF@BHV@DCDC@EAIGGBCBGJCDOBGBKAMGCBCFDTFD@DCHCBC@CCEGGGA@QNGHCJHLDF@JFPJJBDCNGJHHBDABKBCDAJLLHLBFAT@FFJ@NBDLH@DCHFT@FCFIFEJBFLFBFLLBF@VAFED@HALJN@XDR@XHL@DKV@FLFFDBJDF@BCDXNHBN@ALJL@LBBNN@HAHIHIPMHCFBHJNJJAPHNBDPJHHBHCF@BXLFFDFBBRAD@BDBRPp@NKZCNAbJPLFF@TGB@DXHN"]],"encodeOffsets":[[[105308,37219]],[[104361,38040]]]},"properties":{"cp":[102.10327,36.502916],"name":"海东市","childNum":2}},{"id":"632200","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@IB]NYDKDIAEBGFSDOJUFU@KDODaCgKkMqKUAODo@YAgGY@YCUEIEIGSUUIeLu@KDKJGFIDSDoTQHURKB]@YHSCGBOJg`qTwbQBaPGFIVSNIDSDO@IDMFQJEFEF_J@BALADSTI@_AaBCFDN@DUF@BBFQJCJK@ICAA@ICCGEIAoNIFKBEDEJC@OCE@]DKDIBGAQGC@OREHGD]@SHYHCBEPE@MGGA[@CDDFBFAFUT@FH\\@RABGDU@GDUJMJK@SGMNIDMBKAOEO@IDIJQAMFQBKBU@EAECWAsBQLU@EBIJKVKAONWFIJG@OGI@CGOEIKEAKBSJ]EEBIRA@]C_@MCGBEFKA[NOGWEG@IDGLEBkCMBGFAHBHGDIHIBSGE@^CD@FAD[TSCIDKLIRUFGD@FDJDDDDHB@BWBOLKAEGIG@IECUGEGMKBMEAIEEAGJEBQ@GCIGKMJMBc@CHGGCAE@OBEACECAE@MAGMKBCDAVGZQFCDG@GAC@CDEFCLAHQFIA]@AVKHGBCEIFUFCBEJAJKNCBCHEJAFBJTDBH@FCDEHCRF\\@HCRORGAGFEfQJ@HDVPJBNC¨gFGBOFKJKTUHcBUDCLEFQLQDCNCROLCRCXBJ@DALSCIPIDCDCCEJMTGJINCJGDICGIC@EHG@MDCDG@IDIHKV_BGAIASMOCUFGHCDI@MH]JI@CEGACBE@GEK@ECAG@GEE@GBAJGDO@ABIBCBIAE@IFOBCFCBUQOOEEaGICMEUaEOEEUEQGUS@C@CECeSIKOKUWECOC]ASMQEEEOCUAQVKBKF]XOHODILIASKGAM@WIIKEA_GCCAC@EFI@ENMJMDKAMFQAKBCAAGDFJCFIHOJeNSVWJE@KEWMYMAD]ISC[DGDqhÃbÅ^}Pɑ¬œȧªÉbIFGFGJAHCFCDKDKFU@QXa`]G[BEJDRCNUEQBWPOC[D}rgPMXEDYJIHkJm^cBIHEBEJCDSFOFCDGNOFaJEBSCQFYFBLBTCDSBUDCBAJFVDZADAFFJGN@DBBBHWZCD@DBBHDFDALHHBD@LJLBH@DF@FDDDKLAF@PIL@NKHAJIFIJElBdLTFDDBVBZLRNLFFJPPBHBT@bCPEVSb@LDHRRXhLbTZPNHDjJLFHFDLBJAFINAF@DDPHFLLRJTD\\GNDvnFFLRVRjRXFT@PDLHJRBF@\\EXKXKJYDSJGNMfEbA\\BFDFTJHJBD@FCHQHcHWJUDKFMNaJeHS@uRQHO@GUSQ]@MPEx[LmdSDUHWLKLK@GBKJQH@JHHNHJBFHCLKBIFELgTADDTZ\\P^dJB\\KVE¸`XAZFIRBPHPLNFXNZF^BNAJDF@F@BEHAJJJBHDHDVNP@IFUBEBKJCBIEKDIAEHEBKJEBE@MPMBMDgLKFE@AB@JF`J^N^BJGPDFAPITAHCLIFgHKNGDA@@ADE@CCIFGMDKFGAI@MHCDQTCHCZANSLO@kC}TUBuC_M]EO@KBmX[LkFaLWL]TMX@DFDLRAFQLCJCBSBWCCC@IGEKE]CUIWBECCaCGG@MJUCYOWS]IeIqGcBGEE@aHEHQFENEFEBSCKBQIKBEBEHC@[MCAGBMLOBMHKBMDGFADDFABBD@F@DDFPNj\\FJDHCLEBED]FWJCFAJ@DFH\\JLHFFDLBFNH\\DN@\\CHBDDDD@HMNCFELETGLGJc\\sXWNMHcLSD]BQAgBODIDKBKC_AUCeDqJSNKNEHG\\CJQNMBYDoMkCQBiHaN}hONMZIJGDQFkHk@cDyNmFZUJ{hgVaZOJaBGCACBKAWEAGBGDW^IHFk@KBCBGHKRU\\EBKBIBKLGN@HBHHRBPCRGNON]BCBS^IFCFABALHBPRXDBF@HDFRFRLXDFBT^NLRLVDFDHHDBPDRTLFFBFH\\HHDNNBDBH@^AFCDQDEBAHNVNP^VLLRZDJFTHVARCHGlDHHJFB^FZB`EdALCD@NEhCNMLKBSFKHCFAN@VDLEBABEIU@MFIFEFCVMTMNA^@dD~DRG^CZOJGJKHCL@LBDDLZDDb@HJHBDD@HCFIRIL@DDDXH\\DNJbFJRJLJD\\TLZHJBDFF\\JDLNDHFVbBVVDHDB@LGFAZHN@HCJBLAFBHCHBHCCEBCPO@CKG@CDAfMDEDAFDH@LCDKD@XDJCHGJAFEHSPKHWTGPKRABELGNANIDAbE`@NKFCXDNJDBJCP@^E^GJIJQJGLENC\\BTEDIKKq]WQIK@IHIFIze\\UnSPIjcPOsXSPGnEZGnWPCFCnc¤}PYBGBUFIJGDCdKJCVQNOJQLoDINONKFAT@LBJDTF^FRAHCBADMFGEKBAAGHQASLUDILKjYFIBIHIbQHEPQBAPAZS^OLCTCLEHGHQNOFGXOXKSTOLEHCpCTGPILKxalUtQfGY^CZ@PIRSLKNEPAZBXAVMVQ`MFGXMJCNBTDLALEVOJCIE@CDGJGHEJAL@BADGDKHQFGVARGHCTMFAF@L@VLD\\AHCHIHALGFAFCFAHCH@DADBDADBJCD@FGBADBFFJ@FGFCNDDLFDBADDD@BEDAHI@MFUDKDGHAB@DE@EFM@@BLF@@ODCDBDJBBDGJ@FKLAJ@FGHADGDADCDINBHENCBECG@@AA@GHCF@DI@EHKDC@CGC@EHKBBFCF@HK@@EC@GB@DABG@GAIB@BDLNLGBBF@BABEBKEABABDFABKFEHMLV`DJNLFJDTDBFBTCRFRPDBHAR[LEHEHMH@T@JBLFF@ZWHAFA^EFCJQRQPAPATA`AVGFGDAR@NGFCBCDWJMBEEQFMDUFOAGGIFGNIF@HDPTFBJCLBNPHDHBBCDOXULSFOFKHGBCACIACGKEAABAJEfQPIJBJG\\BPEBA@EBE\\KJHVJJHDBJ@DE@EP@B@DC@IEODGGO@CDCFEFBJ@LEV@JJFDAPJJBFB@PCHKPCDIBARAV@HAHKNEHIJEDGHGDDHBHCP@HFNBFAFEJCTED@HJBNbXH@HBNCNGXAPCHCNBFAZMF@ZANBB@DFHBhQNKDAJDFA^[PGLOBIBGNCAIDINEJIH@HEJQJIFMHEJAJILAHEZAJBFJFFRHHBDHPFFDDJBDJFXCXMJCHE@CHGIMOIAQACCA@IEE@IAE@GAEBG@EJOAGDCBGCIECG@MKAGQMACCAGKEC@ECGFMACBIFGD@DE@GEMBILGBCHCHBTMBBFJDDHBPAHEFAPHFAD@BFNDRGNAJMNAFMFERGbSJ@JDD@FGDEFGHCNCJCDIHCFGRMBAR@LCLJLDLOFGFM@ODEFCNBFCHGBEJKTIFKBKCOPGBKB@PDB@DGBIJ@LAFENCJIJE`ARERBFAhUJB`FFADMVERABA@IJEDEDEFBH@TIRCHEHAHIHEFAL@DFFDRJBBCJDLFFDLPLRDHDDRBBHDVH`XDFAFDDFBB@LALBHABIDEFCLCJBPCD@FFJCJ@FFRENEDAJCFCbORGJ@FDB@FAXAVINALCJS`OBIPY\\aXGJEHIPIBE@CIKMOBORGTApO¤[UNO^KBAEO@I@IFI@EDAZBNDNDHFPDD@JIBLPNAFHN@HF@DBHHFBNLFDBDDBJAFDH@\\RFHDBHJTFLFVBVEJBPB^EH@@IDGFCL@DEDCDC@AAG@EBCDE^KHG@IEOBIFOHELCBGCQMMGM@AFABIJAFEBIH@JBJE@GDEHED@GM@GHADADIJCJ@DCHAZHBECIFCBEDE@ETIHKH@FAFIBCEECEIEEI@KDGAEDABCKGEGAI@IE@EAGI@OBCFCHBLBRFJGPEjS^OJGDE@ILIBGBCDGEMVOHAJ@HBHCP@NELANCNADGFCBCbUtAHAAMCIDGAIJALEAGFCHCJATKJ@LGBIVGBEPC@ENCBCRAFEFATDJGJCDCJ@LCFAHGLCOSAC@CNOPGPKJCFEHAAKDKFI@KBAFATCRGBCDEDKJKHANELEHBPDTIJDJINGAEBAJKPKHALQDENGFGRANBHDHADAAEJMBG@AEKRC@A@CLIBINEBGCCBEF@DCHABE@EDC@SBCBE]DKDEAMBUBMEC@QFIKGCEAOBAGS@SCCAG@KEiJE@GEMBAEKICC@C"],"encodeOffsets":[[104949,37969]]},"properties":{"cp":[100.901059,36.959435],"name":"海北藏族自治州","childNum":1}},{"id":"632300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@GE@IAASCEAEMGIGOUMFI@EAGGEICIAOgKK@MFEHKNILMBEQDMA]FKFWHK@GAE@MDEAGAIFG@MICAEBC@YOIDU@MAGGIKSCAA@QDKDABIPGDCBEAEACKECEBCFGBEAMB_AAIAAAGcJm@CEM@UCA@GDOG[BCDCAIJIAIFILI@C@EGKOS@UDMAUFO@CEEBG@EHIDQDGD@BIFQFCRELBHAFSHSXGDCCOBCFA^ENGFA^@ZCR@BCNFHALDTCLBHCLBX@DE@ELENML@LDD@LMBGNGDEDCLBVFDULMHOJKAEEABGFGEKBEHC@EDAACFADEHC@AD@BCD@FABAACF@BEDA@CABBCACDED@DIHAAEBECABED@BEDAAAFCEAJCACF@ACBCBBDABEB@BCB@AA@CFAJA@DDA@A@@DBJKBB@CD@D@AADAAAJCBIDAAADA@AFGBBBA@ED@@ACAACGEQG@ACBCCAB@AC@EEEBAAG@@AEBCAABAAAD@AEDCB@BA@@BA@EBCACDCAIBEDA@@FCDCBECACMaCEMGAE@GBEAMAGIKACSKEE@KDKCKCCOBMBIHIB]L[FOJaBEBAABCAEGCAEBEC@AABIACBAFCBEAGISBEHGBE@SCGCCE@OD]BICIGOBEA@CCC@CZQDEBCAKFOYACAEGBIGQAKE@EGG@SDOFYBG@CCECAE@ANEBA@CCIE[EMA]CGC@XG@KJSHIFCBEAIIUBEBCFCJEJ@J@BKDYDC@AANUAEGOIGMCKJYCKDMCKEKNK@OGCEM@OC@KCE@ECECQQSACIAMKIHADBT@DEDECEIDK@CECC@MDABAD@FHX@DAHSVEBG@CCEMAAO@CAOBUJOJILCLCDEJBBJFFJ@BEDENCDSHKBAB@NCJEBmBCDOFKHCH@HEBE@GEICIAI@EF@DBJADEDM@ABAHEDC@OAQKMKE@IDC@KIM@IFAD@FHNAFGHGB_FWBQBUJg@CDCFIFIBS@KBGFGHGDIBKBGBKCMBK@SEGAEBAB@D@BDBJABFAFGBE@AD@DJH@DCDGBMEE@MDQ@EFCFSAIFMFEDGJ@DHDAFUFMFOIMBEDCFDHADDNFHAHDHADGFGBiBQFED@BA@IIGKIEECMCGDURODIAAC@CCCIFQAKFWGI@KHIESEEBGFIBQAQI@DATCFCBGDG@EEAC[PGPQHGLMLMDMLC@KGGA]LSPTt@PDLNNNf@ZDhG`GH@DBFAPDF@DGV@LDREBEFIDIAGIECCAEBMJgrDbShDjcXAhELPAVGX@RB\\FXBZARGb[RGVCJDfR\\XVbDHBN@PBLFZBDLFH@D@FCDCFCJBHBDHFVBTERMXCJKLETBL@DHHBLBDT@rHJADFDLDFDFXXDJEPKJGPBJ@DCD@FDJ@FEFCHABIBOJE@OKC@QPKBK@MASAKBMCQFKRCDEBAD@DHJ@DABYFYCK@MD^UNMLQ`ILQTMJgTuRSBC@QFaDaAODOFGDIPKFOFODs\\SFOLEPKLC@IPC@QBKJAD@JAH@JBFDHDPEPCDPLFJHDFHGJCLIHF@LCH@RHLBX\\VPZHNBRFXNVPLLZPNPvbd\\¢GHEHIBID]AGRVkI]AAF@XA@PBI^qZEFIZGLENARJZJD^DRCPC^AJAP@VFTAXG`CZ@LHJLHNLFJArKR@tM\\Cj@NGLKVKLAjJTBH@nGrDXGLKFCF@JHHFD@ZINILCnGP@HCFEFIFIJETCzFjEVEdQ]PGXCZA^sGG@G@OUDAACEDAHACCHA@AAETUJMACBCAWDQDEBGFYIMGSCMBCDAVINCXDVALBJADFRNJDJF@FCB@DBHIN@FCPCLAJEHQTD@vbHATDHAHBFSPeDQH@DCD@HF\\@PB^G@BDDDH@HDFDFPLLBBD@LLFRBLLƴGRSJOBOJIBCHH@DDFbFHFHHNHAHHHFBPCTKLBJBXAFADEFAL@HHDBJ@DAJFDHBZFbFLBB@FLRDFPFVLH@DHFCFMD@RRBD@ZJD@BABBDBBADFARGFGTKROZAVQHKAEBE@EMY@APWHODEHAF@VMBGBKNS@GDCTKFE@MLGFGFMBQCC_MEEI@KCIKLCDAAMAEBGJCJETGFSDcDEFCHQ@CEI@CAEFODAHBFEHCLAFAPARCPGDCDGFSASDQLQLETEDAMIAE@GACKAIC"],["@@O@GBQPSLEHMHIBBCAAACBA@AIC@[CEMME@ENEDCGG@UKOECEKQ@EAAEKEaAYCGECCACBI@CAGGK@EBCFEBWBIAKASLODEAGGBGMGGGGEaECE@CGGADIJAPIPQTƳHDHALCDBFMH@JCF@DHV@JDJFB@FONIFUHE@CAGBSDCBOcQO[Oc[C@iJ_L[E] NBXFH@XCVEXJZPfJDL@D@BIBCDEPOLG^ID@F@JSLCJGBMN@FDJIDSFCFGBIBCH@H@BIDGJEBFNKJFF@HDBBFCFCB@HBD@FCB@DEBAHBBBB@DFFTDJGDKLGJCNCDBDCPBZSPIHALDLHBFBHPJL@JAHAPQVQPCJ@FBLHLPBTFBRDDF@BDHPBJDHANGLIRLL@JDLEFBFJDDPDHHJ@JFFFZLHFDFABKDGDADJNNNH^HR@FCFJCD@F@DBHH@CJ@ANCFEXLDHFHNHDJL@JHHLB@B@BBDJN^LBFPFPNDLF^NJAPHR@RCHSHCJBFDHAH@BHJ@DADEBCDOCKHMFMBUACACAOJo@MDA@CNGBGF@DCBAD@BGBABBBALEBDDLAHHHBKTEP@LLLFNFH@FFDHTDB@DD@HFNPLLBHTXFJHHBBREF@BFHD@DADEDCHM@ADWJI@EHCDOBMHCFEBABGF@BFH@HDD@NCBBFCF@FCH@DDB@DKJBJCBADKPG@CFIDAD@HABQDCDFDRAFBBDCFMFADAFFVMP@DBPFPNNADGJGNGHAF@DDHHHBDEHOV@FARDRDHDP@NHVBBF@TDHDFDHBPBLCPDJA`BNCHHDDHA@CAIFSHCF@HBDDBH@R@DDDJDDADCBIAEIGBGFCD@HHPHTELQB[JSRGJ@^BdATNH@^UlGDAGMDIRIVEUU@GbAnUfBDCGUOMTWDMbDFAH]HOREJCJGbE^aD[NOTA\\GfEBC@CEC[G[C[QDKHKHCFIBAJDBANFNCH@PJLNFA`YLY@OA]CGGCKA[BOAEEBE@E@CAABMJK^IDI]OGQHKBC`aVK`_FONKFG@EGCWCECCEFGTECFA@CAAGAYQAGDILKBKDCRARFd\\LBREJIHMHaEWAIJQNKPKHCZSXKLA^B^@NCTGNAfMHC@EJ_XS\\YPKXKLCDE@CCIBIDARHJBDADE@CIaAM@ODEDOCIcWCGDIPMPCJGhSLB@E@GEIIGA@GCAAGC@AGCIEAEGCCAEBK@AEBICAKBWLyPKFODIBaAEBIHEBGAIEEGKAIE@EBG@IKIBMKKAOFIDGAQHE\\EFCBSTMB@@GMuYHQAGCECCIAERIDCBGB@RGVMTAJED@NJH@FEbWVIBECODI@EIM@EDEFCLABABCBWdcFCDIDW@AKEIKOISEG@GFQEMHC@ECGCCIC_EEQKMCOBCCAEDIGYKEEUBIGK@KAOMOQKMCMEIBQIUDKJK@KHI@AAAKGE@EBG@KCAAAMDWGK@Y@AAGKQKAKCEE@KDC@MIA@CDADEDEDSFKFKRCRBTI\\SLQDOBEBKBGDEFGACBEPBF@DFJ@DGREDCFCdETSHIFIDAHBFBNCBKD@BJJLDJ@FF`NDDARENEHKH@NEFSLCD@HMTALAHUNK@EHGPOZNZ@FAFBFINQNCB"]],"encodeOffsets":[[[104564,35839]],[[104424,36164]]]},"properties":{"cp":[102.019988,35.517744],"name":"黄南藏族自治州","childNum":2}},{"id":"632500","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@\\F`KjID@d\\\\PRPPdDATCHADBF@VGJEPM@EEACI@IGWDG@INGAEDCBKGIGIQAEAEC@KACKAOKCECE@GCGCA@CAAIFQDOA[@GEC@CDE@CHAJOfETGAGBSCGBuaC@RSFGBIDKDO@EJMAG@CDA@EIEICQMCEIBKAUBOAGAMDUJCBADDNHTJNEZAHCFCRBXAD@DGNSVBF@BGBDDIB@FDDVCPH@H@tH"],["@@ACAKBIPKDIHITIFMVS@CQM@CBMHUHODCXKXSBCBIDEPE@CAC@ETm@EGM@ECG@CDAFAIUBCRIDQJI@IJEIIAG@ADCLEDABIFAHCFCDAXCFILGJ@FCFINGLK@GAKDKNMII@CFOLCTM\\ADCBGAICCBEPSFILSPOJGhKnIFCDIJM@CCGLUHEdOBIDAPE\\ABAHCDQHDPEFBH@HAFGF@JLBJBBTBNBDBFPALBDVFPJHBZDDBNdP^TRNFHBFCDC@EDCnQRAlC@GBELIVONCjGPKZIJ@LCNAjOnAJBPHF@dIPG@CAEB[CY@OZDPADCHGHAJKH@DABA@ODILMRYZOBCCG@CFQQQAEDK@Q@C@CDAGY@MAAGCSCE@AAGU@MCOCGCQBWPUFGACGGCG@CBEHGHMHIBCMMEOAO@CNOEUBEBCNEDEACEAQBECDCRCBA@GBCJCDEH@LOBCDAAILI@CCA@CDG@EDEAEDA@MCC@GEG@AHEBAFADENGPADCFGJ@XIBCN@DGFCBC@CGCAEE@QFAAGGEISWAGKKMOGEC@@CCAGSEC@EEGEMKK@KFOLSGAGGKBCCFABKAABAHA@ABCDA@CHEHADMB@NCp@PIDBDBVBNANELGPDDCD@DC@EGI@ABGCGAEDIVGDIAOGQBOMIE]CKOMOEAE]KIMAC@A@AKAGG@IIKGCGMGEKCFWDEBMI@@DGGCAE@C@IDDE@EGQG]MMIMBCHCLCBACEGEYKEEIEI@GGOCCCEIEAKFICK@QKKJMHGBICOACG@ACEQCEAASKOKGEAI@ODURORGBIBK@OIAGAEKGKCGBOJYTOACDCAMDIDKHCLIHSCEE@CAAAABGFA@CDA@EAC@GDADEAECA@GEELIEMFAHIJC@A@GDGJAHADETEJCCI@ENMHADITK@I@EJCH]PKFODCJA@ECKeIYOWIUFWDG@OCMCYB_DOH^cROFgFyEQBIBIFEJEJEFGDO@mHKDMJYJC@GEIGE@EDKLWHqCmH@GSAiIKBULKLMH]A_DoNKBWBqLC@KEGMIKKGY@_DWHSBUEO@IB]BODQD]CICIU@GH[HKJWFGrYJ]AOB@@WBE^BlJUHQ^BJCJAFGHG¡c[uaMOYOKKUOWMQEMAYGUOW[KAQGG@KDE@JGDKHIEGGCEIOKDCFOCOEI@MBG@G@ENIRAD@JOD@LKFOPKTEt[PCPELEJOHCPEPCbBbCRED@TAvQhSNIRSJKR_NKVM]NCL@ZDZEBA@CGI@CBCFADCLQRENDLATBNBL@LAROD@PLF@PIH@DCDGFE@ECI@EDC@CAIHOLIFQCGGGOOCECECKCEIBqGS@ACAKGG@CAKDKBGLKDIJQJW@GE]ACCGGAIAEDCDEDC@G@KEACEYAK@OAMCGUa[WeQICUDQHa\\QHYBWA[EQAW@UHOBSxAfST_D_ScIeUOA[_WMmP]UgN_EC@AHAHGFCFCJA@CCA@@FADBB@DBD@BCACCC@ADG@ADAFKHCDA@ICK@EFCD@PCFBNCBGCKAGKEAGIWKKKCGEDEhOXNMRQHov]Ta`iJDV}Cz@HBJHNAJKHCB@DJX@DADA@OAKBEDCDBRAJUKI@GGUEIAUKWFWCM@UAUF]BEAMAiGOA]BwEGIEKAECCGeGM]_y]GAGBWHACBIAKAAMBGDU@KBOCGCE@YFeVMBKF[EIHGHYPM@MCCBOFMJE@MCGEKKECGBMHQAEGEAQFGLCFQHABAJSLI@OHOCGCKLIBADCBOCKBCBADCLOJ@D@FAJMPSLOFQDWBMFYRGNAPGJKBMCUCYBkFUFOLCFSHQHO@EA]GO@OBcJK@YJKRSRANOFGHAFMLQ@CBAD@DJLCLMPAFIH@DEHQLMDIJILCJCBOZENANEDCFGBOAQDGDCBBF@FHBBHABG@@DEBDLGVEDGCC@ABGNOJKRIF]\\KPERalCDKHOD]DSJADAXGJCDSHIBI@CDBFKHEHG@CHEHE|VX\\\\JPrZ^^FJLJJAhFJDBBFBZN@BA@E@FDDAFHDAFDABIJDHBJHLAFIFHJCDG@INOAGDMDIFADAHHFAB]DaAEDQAMDMBMF@HWJDHLLBFDJB@TC\\DFAXAZED@BHLHFHDLBNHHXJfLV@PAJBBDCF@DCBIAGFObCTCDCFGFQHEHÝMHIFK@CD@HCBGBA@ICKKEAIDCDAFAJABE@GDKCJJ@JFLDBFJHFBHFLBDNBFDJPTTHL@FCNHXABCF@LFHBP@FIJMDEF@JILALEJBFKLOVOTAFMHY@OBSLEHCHEPBPHDFHBBAHER@FFL@DCTIJMPODEFVXFJBN@JIRINcdQVSZ@FBLbjBDGPOT]ZmbMF_HIFEDAHHXFR@HADEDGDIEKEUFMCCBAFDFCLEbCNCFEFKHiPGDIL@HBFDBdHJ@jFTFJFDL@FAR@H~XXL@\\bVFVE\\KJMD]FIDCDCNK\\IBM@IDEFCRCL@DDBJHBDADQX@BNFL@PĞjªXüÒbjZV\\RP`HJAfP\\LHL`TBPCLUPILGTATENH\\JLQVtCDÁe`G@GBGLOlCDGFAF@JAHILQJ]HULQLKFYBOFITKFODWNQFIFBJIVBBL@ZK`CHCF@`PNBVNBF@JJNFHDJHPBRDJBTdHXJFDFJBDF@LDFPBJANJDHBFDBLCDB@BADBBFBN@TAXBTXFpFZDHB@NIFAHCRDLGDBJBJFFAHKDALBNCHE\\BLE\\ERETDFArOHMDCPETEDCFIFAJGdAn]lIJGZIFCNWhO~q\\CPDXORAVFDMCQFI\\A^Hb_RWV@LELCDCDEBGPONGÆ_Ȩ©Ŕɒ«~OÆ]ÄargHC\\CTD^JCNBZXNLFF@XITUfMPIJGDEEI"]],"encodeOffsets":[[[103841,36136]],[[103340,37624]]]},"properties":{"cp":[100.619542,36.280353],"name":"海南藏族自治州","childNum":2}},{"id":"632600","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@èFGRGHEDEDCDSPaHEJBDA@CDEACIAOBU@eKWIGGAMCKEGKGAGC@YFWBEB[CSDA@CIAEKKCGXI@GNENANCRBFCbB^CBAGEBGBCJENCHCPBJMH@DCGIJEBEGKAICGJIBAECCBEGCBECF@B@@AYMEAAAICgEIBKIEI]]qYIO[[UWF{FGDGH@FGLGAEDCJ@JATGDCHIBWBCTI^CPCLGDCbkFQLO^[JELQPIHMBAD@HDFCHUCKFA@CH@BAAGGA@EAEDAHCRCPBHADEFCBMFMPYDADIJKJINCRKFG@CJGBENODKIK@CBCDAR@NKBEHGPEBMTQLQZIL@dIPAP@^HFBP@RGTGDEPKVElEZAVDNDLAHIBOHMZQNEXARCPETKNOBI@E@CPIDKBCDALAPDDABCJALKHDPDPGJ@TKBIBARGDEHKREFBFHRBNGHAFDLLHFNDF@NIPEDANDN@ZOHGJG\\FLENAfUZEF@HDPDLAV@HCNABBBLAJBDXGHAHBz^^`HNHfDDBFFLHJxF^APBjHNBFB^AVEVBN@XDXEVLJBVFHHJ@VLBIAQDCFCLAPBB@BC@CIW@CDALGBIGMAI@Gy~DUCjIb_^SpuRGNQMPWFgFCDHLLXLHJFBHLLBHDDAAMDE@ODCFEL@JDB@DCLGBEBCH@BCD@DDDB@AAC@CAABC@EB@DDB@DIDEHEBGBGD@`FhM^VnOXN\\`PBfVdJ`T`CTSBeZBgdWCiTgCahqNIFADBFDHJJBJCFEFACQ@KHU@CCEBOAE@CHGH_Cg@YMeMMCK@OSsWMIBKCG@MCUDW@EI@OEMIEIECKKG@GEGYCGG[@KMO@CAM_AEDIACECICEEBIDI@KCEMKAC@CDETOMQECQG@EFCBCIQ@IEGKEACDG@CCCGCGAGCCMEGBCFEHEZIDCDKP@DADEL@DCDIJKBGJIRKPUDEAKBIDAFABA@IHMD@HFLITG@CEUDGVQCI@IBI@GDEJEVDBC@KHE@INQBGFAFDFCBCFEHIHGJCOU@C@ENILCB@AGBAHADAFKJGXKDKHKH]TQDGFMJQHCPHNBJFF@FENWFFFBLAFCDE@WHGtMTAPBTFFBFCBCAIHCJAPBVKDALBJ@FABCBCAGEECE@CDGFELEDKNKDE`UF@DKCOK]BIDKDM@EACCAK@A@AQUMEGCEDuPKJCBAGGDIKGEEAQJGJCL@BBAJJHRJJBLAXBBJFFJFJJJBRKHKHALGNALALAFIJANAHFFBHKB@HDFJXOH@PDVKHHDBJENAbKJEN@nJVLHHBF@HCP@HFHFFFAHEHABBXHXBNFRPPFTFHAJMFANBLGXHJ@JALKFI@QDIBAJCFBHFFHHBJ@FCHQAM@IEODKFCLCPGDCFOFK@GHKDKIKAEFMGQBOBGJEDGEOBKEIHGBEAECCAGNiFGHCBEBANANDDFDHFD\\CTGFBLHLEVFVIPCLBLDJAHHDHNBDFFPJLBH@TBBHBPBFADCDUAEEG@SBaCOEOCU@QFCHA@C@BC@AA@CC@@AAA@DC@CCIACCKBCAC@CCC@CAABC@ABIBEACBCACEGAMBKCQCGCCICOKOMUGGCGAIIIICAECcCGEOCWCGCS@IJMJINGFAROF@TB`@FAJGBGBANATIFEJUAEGGEGICAAAEDIAMKUCOMIAGA@M@MIKCUI@EJSDGCGSQOIGESCL[@OBKICIGCGAIQQGIAICAEAGBCLSLELMDELKHKJQX[PKLCJCDSFEJMFGBG@ABAJAFCDI@EBCDANCHQHOZIJEDC@SGE@QFUAOBSHGBGAGECAa@GAIIIOIG@AJEBEAGHUEGAGDkUIABCDENERCBMBMPCJ@L@DGDCHIDADCHEFALGHEFG@AB@LCBDDBFAFGHI@QDCFKTEDCFIAKFSBEFA@ECEAC@ADKGIBECI@UJIDCFICISAGCAIBGAA@BFCF@LAFOCMDG@C@IIICCCAEDEACBECCCAIBK@EAEEFCDG@CCCO@CGGAIGQCEE@EFEKQBEKKACFEDE@EXDJCAIMKBE@IJIPAAIHECGV@FEBGEG@EII@CDIDCRGBCFIBKBIAIIAEEC@IDEAEGGGAC@EJSCUCCFCHBHCJBB@TIAKV@BCFEEIBQMGEKAIBKLMAGRUCCg@[FOAQHI@AIHaEOHKBEAGIW@AFI@GEIGMAE@CTInCNELGPCVURINQDC\\IHGDEC[@GJGRIDC@EG[CIGUBEJK@CACMKAEACFOBQGsAGCGGGYWGKU[EEUGEEIGIOECECIAYBSAICGGEE@IBOFECC@CIDGFBJCHAL@HDHBJDBCNCBEAAADC@AMCAD@JABC@CGGCADAFGCCBKJALI@]K_SWM_cUOMOIAQ@SEEAIDE@MGgaIECAC@EDIRKLE@OEKDILCRGDWBIFE@IAC@EFUFCHQHC@SGC@GDCBMCIDGLEBA@EECGQOGAE@EDEFAHA^ADCAGECCCIIGMJQDYJSNKHO@ULME@CBCTO^[FIHUDK@MAIEGCCIAGB[TIDQJM@EEEGCIE_DY@ICUDYEO@IP]FMA@BAE@CCIFWBCB@BCHGDM@CBCFIFC@CEC@CDBHAD[BADDH@DG@EEK@CBBD@FCDGCIACGE@CDBFHF@BGDIBCJABE@CEGCCHCDOAAH@FDD@DABK@GJBFHFBBADCBSMA@ED@FBBDDHDFFOB@LADEAGBMCEB@D@DPFBD@DCDGAIDCHDBFAD@JFBBMDALOR@DCFCB@FGBADEHAHA@GBCDGBCBBHEFAHBHCLEDIBKLC@KMAAIBABBDJ@OJ@LGHAJCFMFBFMFCFIGKMYYIYK@OFAHJFHPJLDJ@HHLDJFBHFGHAFDF@DEDACICIGCAUCCAEECGQGKIEAKAMOIAUPEBU@MBKDCDWFgPK@@EHUACKCQAKACCBMCGAIKS@CDS@CECAC@KDMACACDKAIK[GKDKAEEGGCAAHKCEIA[L@FBJKL@HCBcCYBYL]EGBENE@ABWC@TIPMNCDMBAB@DHJBPFDN@DDDNRNFPLHABDFB@LAH@DNBFCTANCTITANCDCFELCT@PENF\\@\\HPSLGFCRBDDD@BCDYLE@IGABCJGJAFDPC@C@E@ADAHGFIDEAIIC@EHQJMAKCA@ABCDBFJHL`@PABOFMCODEBGHKHOGQDO@MACBEHKDGDCJAPGNAH@NAREFKDIHEDBHOFEFITIBEFAFAFBPADBHADGJSAGEAFGDICCADC@CACBA@GFSCMBIAI@CGGBI@GKIOQBC@EKMAE@GBIAEGQACGAGBGBKNEBGAMEMMKBGACBGJUTEBMEGCIMEQ@AFC@EGEEEBAHANAHEBG@ENQ@CAGBMJIBEKUBMAGEEIEIOBSAIKMA@@EDKAICCHM@CKKCGBY@AEG@IACGCGI@CEGOIEGAAFU@COMCAE@KNGBAJEL@HADCB@FAFBDKNE@CDM@KDC@ICM@GFGNIBGAACIECBCDK\\ADEDI@SQM@KEC@GFONICCBEFBXKTW\\MFEFCLCBQHG@KCGJGDSAM@KDCDCAGDE@@AGAE@GHA@GFOBGDI@MFIACBADEDKDCFCB@DCDIBIAEFA@CHMHGAGDE@ADIDUNQ@UOWMIFKNGBKCEQEGgCMLQAOBaMCDBJOnIPKNEJDPCNLLABCFIDUB@NCXBHDHBDKJIFKCC@ADC^OL@DFF@FKRKHAHCBI@KHGHWBcJ_@IGI@MNALEJEBQEIFEJAPCBCB]GG@MHCFAHM@IEMBGDGFEHCBGBAAEIEC@GAAGAWBCDCHEBGDI@IDWLAHCHBLCFSF[EM@UFE@IFCBOBEBCBCHGHEFMFQBGDIPQ@GDGHGPebABBF@XCHEFIBUHBFELGF@DBHFNAFFHCLLH@BEHCTGJEFYDIHI@KCMBIBEBCNDJXNFLGLIVAHBDLDHBBBGL@H@BHDPF@BEHCJ@LBRAFOJOFKJGJANAFGLA@QDGFFjFJDXDNCNDJAJ@L@DM@CHEDKBCB@HAHDLBH@DGDKAKDONK@CBKLO@EDBHGHAJCJEFCBE@IGE@GBCDCHBXJHBNFH@DE^CHcVYHAFGXAVBDNDXBXFRHBDAFGHUDADAJg^SHAFMJIJCFCHD^EJUTSFIFMBSJYHIHEFCVKLIFC@OAMCGEGBCDGJAJLZ@DKREXKZGPMLGLABGAMICAOAIBCBEJILIFSJKJL`PNDHJ^AFCH[XCPBPHN@LBD\\HFBBDDJFFFNB^CLMbERCDBFABEAAD@BGAABBDF@ADEBEBE@AHCB@FE@ABBDGBABDBABGBC@CD@FCCA@@FFB@FAHJH@BCBGAADDBD@FBAFFDBDA@CB@BFBFA@BGFCAMDYBJ@AEAG@I@E@KCCCMCODKCGBECEBGCKFI@EEGBGEG@M@IBGCC@SHUIGAGCE@AD@FOHAJM@MDCFS@CDGDEFGAAHEBM@CAGECBCFIAE@GD@FABK@IHEBG@EFIBCBKAGDM@AABCAAKA[DEAKACGA@CBGBCFGAAHABEBECGBCF@DEBBDCB@DIH@HC@@DCB@BCBADGFE@IFCA@FEFEDEAGJBB@BKBIJEBEHI@ABDBCDIDCDBF@BG@ADE@BFEDADCAE@EAABI@EDACADC@ABACCBADA@ABG@@DC@CDG@ABC@@BABCAABCCA@@BC@@CE@CCABEAEDCACBCACBOCIFECO@MDE@ABEACBA@BCE@ACKFEAEBICGDEEBCECCECDCA@DGADABCA@CBAE@EC@DA@CGCAC@CA@BE@CAAC@@CC@DIC@@AA@@BA@@CEACCE@EGIBABACDAAA@ACAGDACIAIBACO@@CBAAAGBAECDACECIACAC@EAACCBCCCBCCE@AAEAAA@ACAACAAC@OCEBM@ECSECOKZGHIJYdAJALETENC\\CJIPOHKBGAIESOGSAYBIAEIIEAOAeHOLILCPEHIH}LIHEFCJIdCDGh@PAFMPMNQJODEBYDYDEBGJAHBLCLGPEJSRIHUHKHGJKTEFOLOFEBUGWHAJU^ADBFNFJLDJhFNNFNKAEHGDJL@BWN@PEREDQ@EBELILYAEFGDOEGFmJoR_@QC_IMKE@EFCHEBGHUHMFJJLFDNBBHBJ@DHFBFBJ@DBBDFHDHBHHFBHAHBJJP@DEDCJ@FHFCFDNDDEbABODEDiHaHg\\OB_GOBOHaTGHIPBJNRBH`HJDLFH@DAJ@PFBD@FFFBPDHNRFRDBBDM@K@YCILGFYHIHKDKHaFQAGDM@KB[FOF@@@EMOAECAACBMFCDCAIG@QDWDGHEHUTWFCBGLAJEPIHCP@LRZNNLNJDHHfBPFHDFJ@HAHAD@FHDJBBJFF@FPBBBBNHTGNKNAJ@JEBC@BFRLFBHDJBH@JDJ@JBVCRINBLH|x`\\f`t\\PLBFCNAFCFBNEBKJKDDHAD@DHFFDAFLH@HBDAFDFFDFF@D@BFAL@H@LHBPDHELTH@DNZAJ@BLPCXFBFDDBBDDBD@ABFB@DB@BBDB@BB@@DD@BDB@BDBABB@DFB@DD@BFHFBDD@DDDB@HD@@FFHJFBBFBFHFBB@HFNTD@BFFDFBDFD@DDFBB@NF@DD@ADHF@DJBDD@BC@AD@LEB@DOHEFE@IFCDGD@FDBFHCFGBDDF^DFAH@FTPN@D@FCHMDCDAL@LLLDVBNASPExYZGZEXETANBNBDFD@RCVORETAL@VDHFDFBPCJALEPIBxHbDFFHJDDFVFV@F@VEJGDE@IK]BEDCFE\\CLAFBLADAZ@p@TFHBFAHERWHERGXGTAL@`HREVQVAdDHAZWVKFAFB\\RHBF@FCNSPKJAVCN@dDtBdERDnNJB`CFBDFBZ@FLPLHN@RGDHDB@DZHFAFDLEF@BCJIFBNFHCJBTIT@@BCDFLCDBH@DFJBTHLDR@HJXBDDJJd`lJP@RBLAJGT@HHJLFLDJHDJDDJBHF@HAHBJFBDHFDX@NBDABIHANA`GDEAIKUMIAEFANEDKJIRDFFFLHBLMFChInF^ALBZHXLPBjEJE\\MXQNEPAhBxNtHV@`FLFZR\\hHFNHfHZRDBTDBlNXRLFHFHLJf@HDZANGPBDLHjHpGdQFKRKPCLIHADEDBNAJJRBDDXBJ@LF@BIJCDIHDDBBHFFDnEPGTAZGJDTGPBTCP@NCRDJDFHDTH@PEBGDCPAFDH@FAJCHCH@JCXDLHTBFBDF@JJHFLD@HDBHJBbA^HHCF@BABMFEDAHADBLLLDF@FC@GDCL@NI"],"encodeOffsets":[[101595,36458]]},"properties":{"cp":[100.242143,34.4736],"name":"果洛藏族自治州","childNum":1}},{"id":"632700","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@CH@FCFDLFFBDHBHBHB@DU@YFGFCB@FDFADKHAHCB@FDH@DGFQDCDANCDEBEAGGMAGBKHMBADBDHJADABOBEDSLOH]VONITQPSTEBGEEEGI@YOKACAEHGDI@AKA[BUCEEIKKSICAAACUMO@ICS@CDBBCHABK@EAEACGACEFE@EGCD@FEDAHABCDG@UGAGCCDEDABC@KBICE@MCCMEK@WIE@IPIDGHKJI@CDBF@DAJELKBGHC@DSOW@IKSECAGFMFIAOEIMEAE@MGEKCIBAJEF@HEBKAIAKGEDCDCAGGA@GJqYASBIAC[JUBQFCBCFIDK@GCKIE@YBYDSFCKYUGYAGNUHCMK@QMCQDQAEBACIYIIKCUJIFUDQHEHKVCDU@QBIJKAOBC@CAGIIIEAOB@EFIAECAEAIBUCONIFAJAFI@YGGBCFAPEDCF@DIHEFWESGQASIKG@KC@KFONIBSCMDOBECGKECED@FHFGDADJTCHCBEDCFBLCLBFKFOBSNDL@FCJCFANGHaNMDEBC@ECI@GBSJONIAMIC@ADELCDMDM@IFE@UAWAMEQCKEGDCHEDaECCAC@GGGIOECK@KBAAJM@CEKIGESS@AGAAcMEEOEKDAC@GECKB@EBC@CAAIEEEAA_FGCA@EKBKEAK@CAAB@BIBEFERIPGPUGKAGDGHAXA\\GHMRAP@JABIFKBKDC@CCKEQBKCSDAEBCCQCAK@QEAA@IGECKAAEBKJAPMLGJOLILWLADADgLMAEBAHHJDJ@RAJGDIBED@FFHADIDKAIBAD@DCBUAG@QFGHETIJ@DFJBFUNG@MIGCK@MDIASJKJGASHGDC@UKASCEAGAEM@OEQBGAMFODCCCIACKAe@ECEIKEMAGBGFCHARCDABBJMDCBCVDJ@DMFADBJLZ@DCBWDEDIBCBFPCN@HCDCXCFMBEFA@ECGBGCGGOIAABICCUEECGCCAIFSEQLIAC@EE@GACI@MBAKCA_PEBSKKFC@CEAKBIO@EBWZGDKDKFWTIFYBQCKEIIAAEDIFIAGHKHOLEJEBAAA@CBICIFAJCBC@WAGHO@SRIFIBG@CAACAKMQCMKOcWYCIBGF@LEFIASGE@GFGHAF@DAHABECIKE@UHE@ECAKEAM@NTJJFDLLDLFRDRANH`@FFfBV@VBHAbBLJJNJhLVNJHHHDFBD@fBNHPDFJHZPBJFJJFHLNLFL@HMVDTLLBNJHdNNJDFDd@JAJMdCTGRKLIHq^SNEFAFBPRX\\^DHLJRBBDBLB\\C\\BFLHFFBHAPCFMJ[P[RIFwVOJOD_AEBQVSLADDFTLBH@FITAVGLCNBDHHRLPHnTNFLDdBADKBEBEFANEPBHHXJRFFVPJNDT@RDFDDHDFBHAPE\\MPGF@RDDBNPRJTCpETDXLVR`NPNJPDLGjIFKNGFSJQHSXCH@FDLJTBHCHGHAFBFHN@FOLGDKLGBGAED@D@FBHPX@LFPBPBNAHCDKBG@GDAHIHYJMBAD@BBDRDJFFHBJ@BQNCJEHGP@DDL@NABIFBTFNBJBDFBBDMPADAFCDAHGD@FDBBDEDAHCDBFCF@DHFBFIHAHFH@BAB@BFDFHEHBDBBFBBDENADDD@HCDADABED@HCHHDHNGJCBADMFM@CBEFGT@FABOBIL@DFHF@JDDF@DABAPDHHFFJ@LPJFLBBDBN@DDDHBBJ@DBBH@HDBF@DD@HBDPBJPBJDB@D@BfCJ@JAJFJ@HGH@BCDBHARHFHHF@F@BNAFBLCDBJNJF@NB@JBPDLFDBFBDD@FJL@FFJBJIBU@EEWEIFO@KEMAEBEEA@QCECA@AAGA@GECC@CCCDIBCFUFGFCAOAICC@I@CCQCACE@GDC@GIGCGDIHSFIAAAE@OEKCEDKBADAHAAABGBEFCB@HAFBFA@C@OJEB@DELMJCAGDI@EFANDDFDBHBBBD@HBBCHBFGBCDBLEDALCB@FC@@FEJOLKPE`IZQfCLMVILKVCTSNINKXERCFOfKT[DTHXAFONYFUBKGEGM[EWGGGBMCYAKDoDIJKBGH[CMAQG_C[Co@uFY@I@QCK@SCGBEEBEJGDAFWROF[@eHI@MDUHOHIJ]LQLMBCFKD]BeNeXoRQHMJED]DIBQBGD_DcJCDGJIZBXNPZTbhBHCVEHGFOD_@sJOAEBM@I@WFUHUDKFILMXGHGHOFYDsCOBGASDYTEHMNM`EDEHG@MFW@KAGCOIIAK@uXmNWJMDaRUHSFsLgFiHSBcHIAKDEDUBWH]NaJ}XM@IHODUJ]XKPEDILID[ACBgESBO@[FcVMDUAqKqBKAIAMEMKSGEEEAIB@JEDmPUBKCG@EAG@EDM@EE@CBELUDKAGGKI@Q@mHC@GEGAKQIQOAUFIN@DEBSAK@EBGHIHCFIHADBHDNFP@NGFUFKFEJENAH@NCJCDEBIHIBaNIBKF[FUHKB]NG@OLQFIHIDMHKDMD_AqEYBMN@FCDEBWFGAkBuMKDIJEP@JCHIDOBeFqAWEUBO@aDgBWASBKBa@OAWBEBM@MDOPKFWCWEE@OCYCkD[FM@WCQKGGCCCBSFGBg@[TKLKFG@UEUAWGKKEIAGMGMMEIFM@GAICAOKOKSGE@UIgIQDONMTEVQPG@MD]@QDKFeFCBQ@SGEEKWGSKQUSOYGUFufMFKNDNK@OCKGK@WCMHODCBKPKHKBQFG@QISACAOKQIEHCBE@IECBEHGDCBIDGHEBC@CACAGQEEOIMAUICA@KACWBEAAGGBCDIAEEIB]CADHL@FMBODa@UAE@ABJNBNGHOBGFABCNIN@JAFFFBHHDFFALEL@FN^FXAJBFQT@FBDFDTHFHDNDZEJGDCFBDDDPBFbBZCHGFCD@DNLAJQH@HGDG@GDMBQCOBO@ABAJABIDIDQFIFAD@HAJGLGXWVOTGNAJIVEFOL[NAB@DDHNP\\LNLNLZHRHPDLJVLDD@F@DEDIB]CC@QFEFCFAJJNDPLTNLDHCLAFBDCJCDQFCBCF@H@DPRDBT@dGLFNHTDLBLLVCPBVNDFBJf^`NPDPBLFF@PETCNEDEFDLRJDDDEL@BXFDFBJTHDDNVGHDDH@HAHDBF@HDFfDFB@DQHGFKXKHEAECOBOGEJM@IBADLLILAJ@FDLEHGA@PBFDBFPDLD\\FJBBLBH@^GN@NBNFLHBDBVQNIPMFEHETAHKPKHCFBDDFLDTBFDDFBVAX@DDHMPADPFDLABABKAEDAFBFPPFL@LAFGVAFFHTFJJJGFAJBFBBDDL@JCFKHEPGRFFRHDDDRBJCJBDFJZRFLEFKFCHYHIAQEaGIDCFOAEACECAgGSBY@UDMASEIBQJU@QJO@SDA@GGOCKBULWCODEGGAA@ENCFEBSDCBABDFP@NAR@BD@DCDGDG@IBSJmNOLWHIAWCIBcRmNIJAFAPDFPJFLBLCNEDELBNAVBD@FDBHBBBGJEDMNULGDCF@JFJJVJNDDF@LEJ@BCBIJIN@JGXFRMJCNBHJLALDN@HEJ@\\FL@PDH@JCXN^FJCRBNANDHFN@HLFFNERFJNBLEFFDDANDNBFHD@NHDDTLJLN@LAHAF@FBBFFCJAFCL@DEDCH@JCH@DANANKFAHBBHFDHADGF@HCTCHDXFDBBFJ@DBNEFAHDJAL@JCFDBDPDLCJDHEHBFAF@FCF@TBFDDEHCB@@FHDPEL@LGRIJD@PEJ@HAHDB@FFHBDADCH@LABEFCPENDFLPZHRJ\\JZRLLV^BFCJ@HDHLNHN@TDN@RJVBH@J@DEFGDUBEDCBAJAJDBFEZCnDHWFGPKHADAHBJDTABAFGJ@`ALC\\@DAPGPEDAOKIKISAC@IFEZGJGHGHA^EJC`ANCTMl[LINC\\CH@RFNBPCLClDV@J@HCLONIFCJ@PB\\HrQV@dIRAHBRAlCZBFDFHJFTFvJPAhGNGFGJGNCD@NFHB^IZELFPFV@^FPAvQtUFAHILIHCNADEHEXAhMFGTeLGACFINIHIN@JCDCEEACLERGPQREJ@NDRLJDXCVH`FHANCJDHJHPNDR\\FJJfJVDDRHBJHDBBNCJDHBHCDGFAPFRARED@F@LKDAN@RB^GTCV@hNVTDLBFADEFELANBHELKNELCFdCRGJIVKXGrInO\\EVEZKZGdUZWLGrMxCI\\EbDpRzPHDLDFDPDNHFFLJJ@RJPRHDHBDBBPFJPF`XBB@HBDF@RAXH@@EAEECOBCEEGM@GMSDIEECEG]HG@QJCJBDABGAKJDBANOJEEKLCRCVBNAHCLITMRDLHZET@VEbO\\ITGSZEfAXCxJ`HnPlFTALA\\OtIGFCHIAUhWJCLA|YTEH@TAÌe`GLIHChIRA^GhG^CNCJ@fEH@ZBn@bFdELKJMH@JBRLFFHBFHX@`FJ@JDJATGH@RILGF@HCLCVBLEhCP@rKZAZEK@f@TCjAP@\\D`AfG`AVCE^DZ@TAjIL@hMVChKXAVCfI^EZGHAH@DBRRNHFDHBzCVCLELAFEJODOHQLML@JCN@JAR@NCnCjMfGlAdDLAnSXCzAFBBNA\\E^Db@HAPEJAlDf@dKNAJ@RCPGL@LETAJBHALHDDDL@HDJFFTDfSJCLAHBJ@ZOLAJCTANEZAFCL@JANB`XJ@LGDERMLCH@hBRFDDLFJBRAJCDMBKHMHANEDC~INEL@HBNCNOPITCL@^CHEJ@`DVHX@NCJEDELCbSNEFCZI`ENEJIHGPQPMbSTEF@VJHAbDPAVCL@JBHHFHFDHRFDHHXJ^@bGTGfYJ@NBFDTRHDL@b@FCKEQG@EFGPOZKH@fD^FPCdMNAXBLAPGNILEXCXARBHB\\PLG\\SPGHAvEJBTN^@NEXEf@bEJBPQH@PJFAF@TDFFF@JI@CBBDFL@FDJJFAHOTDDAJKFAN@LADCH@TBDJZ@DB@NJJFDHBJCL@PCJBV@NL@CDEJGJEDIHCDEB@NPTHBPBBNHHBBA@IPKBGAC@CFO@KFKBAJCDANFR@@BCH@JFBNCHDHDF@F@D@LELBLDPEDCRENDNGHACE@CLGRGN@BBZCZND@LKLEJCDE@GBEXINBFDBFD@DCNCLBNDH@HG\\BPCV@LALEBECCGG@AHKDKDGTIJABDFH@FR`@HIHCFDLJH@FIFBBGHDF@FADEFDDbMNBLHHPFHDHAFGHIF@HFH@FEHAPEJD@H@`JTBBBIDIRSP@BNNFJBHDCNQBIAQ@ADAV@HCJCJFD@LCFEHAJDFFF@NFRBNAdMN@JEZFf@V@RCDENCJMHAFAPDNYNUBATBXEFCNBNAfDFADD\\THDLBFHBPNT@XFLJDFFVDDCHCH@FB@HCFBFDJDH@JIHAL@dJH@LGRDHBb@HDJEHOREXHHHD@XEFCHAFBDDLALB\\@VBHFTD@CCCACFSFKDAzPhEþEPAHQHEZKH@PFFKFC\\kFOAGBGBMPEBEHCBGLGBQFKHGHCNCNDVLH@DBBBR@NHDDL@HDLHFFJADB@HFDBFAL@HJPBFADDF@FBFADHNFFDNJBTCFHN@F@FBFFD@BDH@HDFHRLDJ@FHLBADAF@NAHED@HCJAFAPBBEFAHETBLCFBFDDDHCP@RIDFFDDNHBL@BJDDHCR@FAF@HGDDFAH@LDPAJHNCHEL@NCH@JCHERCBHFHH@DFFBBJDDTGV@LEVADCRAHCDBFCVADEF@FAZDNOHAJGJAl@@GDARCLBPEZCL@LFT@FG@ANGF@VEFKACH@HEAGBCLINCJ@NFd@TDFHLAHDLGF@HBLEH@LFH@DDBHPANBBABEDEFAJ@FBFA@CBGFCDCDAEQ@CJCFEZGBETOHBFCAG\\QRELMBGFIJIB@JCLBXCFALDDEFAFBHFL@JHFDNG@C@MBC`KH@BEDADBJEJBDCHADAHHBFFBDDBH@KBCH@FCF@BBBFFDTPJEJGBACE@OAG@GBENELHNLJTD@FADEFCZCHCPAFCdi\\QZUDOEcDIDERQ\\INGdo^SNGXEfBSNARARDbBnYREZA`BLHFFHNHHDDN@NGBCBEAICIJUNOBETAR@PB@EBGCEE]CCHADEEGCA@EHCDCJEF@FEPG@CFABOD@@ACCIA@CGEBCC@@CMEA@EACCC@CEEAECAEC@MSGEA@EAEGEAAAIEEG@EC@@GCACCC@ACGEAEC@@CEA@CAAABACA@ACC@@CA@@ACAAAA@@CEABAC@CAACCAECEADWKO@ABIMY@CSGFKCGAOKGG@K@EB@A@CEEECCEBEAC@GKGBEECGE@CBCCGLCLIFAAMDEBEDMAEOKs[_e_[{wKGMAQJUDIAI@ICG@IAGCEAQKAED@FA@IBILMHMGSAMAAOA@EEEAIIAGC@EBCBG@GEIGCOEeAGGICKMMMIKGM@KDOJGFOBIDGHEXEVSFGHGXCRCH@BJCDEDANBDDBBFNP@F@@PE\\ELAN@HCRBbELGLCJGZGHEJKZDL@N@@@ACAAACEMMQACCK@GEE@EACOEI@CBG@KEIC_GAGMQAIJOHGbSPGPA`HPAh[bGjGFCPCBAFaCCCMDEGE@EDIFC@CIOAIBGAGGEAGCGEGACCAI@EAEACGI@GAAACMKEIINEVGHGFADGFEF@NL`JRD`@pQnIHEPFHCFEZBJKFKFAR@FCFQ@OXM@AIKHCFGLBEMMMgECIIKMEAEBCV]BIXGVHFAPEPKFELSHILGVGJGTQFIHODKAKBGHIFAZCZCFAPCRINMNOBE@OHgDCJcDIFEJG~KJGFGDOJKLGDCfGPBJFFFBFAJBZHTTPJFHBLAPGJODID[FMFSBKBIZcJIHGLYCCBER_NQFQBATEDACIBCNOFGAkOQOUICMGOFK@ECGICQHQDQFKCK@EBG@EAEEIAEECI@GG@QCQIIEAG@eRSD[IIGICgIU@C@QQICOAE@CDAHABM@MFECAGEGEAOAGG]JECEGACAMC@UBS@SCKBC@SIYLEBE@CAAC@GDIJI@EGM@ANQBECCmGGC@EDMAGGIBCJIDADBNI@IFAR@HCLQAGFWHKEG@CPIFIFEAEKGD_AGVOAMIIDSJGBCBGHO@CICAC@GBGAGGCAEAKMYAMMEEE@CDCAILKFO^KJBDADKLEHODAJAL@XLH@NCDDF@LE`C^MAIGIBI@KCKCG@EDO@EKMAG@CLIFMPM\\ODODGRM@CEE@C@CJCJDNAFBJHHBDAFGFIREDGDCB@F@LPDBDADAD@NFHAHGLCFGJCNBJCL@HAHG@ECA@CJGD@JBJEPCR@LCDAHIP@bQ^EFEBGCBEBG@ACDGACQEEIAAMCOBCAEKEADGAAC@CFCBCA@ADAAEDE@CECIBAAAAFGAAODIC@@@D@BG@SIAIDIBG@CCAGBKA_@WHCAGCQEEEKQ]AGF[@GCGMEKMAA@K_UCMBKCAGAOIKCCCEIGEG@KFE@GAEECGCG@EKGAKCCAAEAMII@KKMBAADEBGG]XOBCO[DIIM@GPMLELATBBIJIDEHODSHEFK@GAGBCJWACKEQCQOCAMFMEIB@CFQJMTIFGJEBG]KQE_CE@ADCBC@GEOKO@SHS@EAKEWCGEGICCIAMBQGS@GAMIGM@ENY@CEEEAEIAIDKWECOFKJEJAZ@JCBCCEII@AHGVEDC@CAAICAC@ENMFG@K@CBOIAG@GAACD_ACFGCEBOFEBSHIHIP_HGDILG@GBCTOFSDKCGGELMPCHBDABMJC@CLGHINGJQBANDFAAEBEBGFCNCJEHAZDFCDE@KBALGD@BBAD@BFDJALKBODEHCF@VDPGN@LAFABIDCFBDHNFF@HADEFaLSPIJKD@BBDBJCFGJIRILAFCBA@GTMjEBCBIFE`IVAHC@@KEkAODMHIDUUEE{LE@EBK@GGIAMJC@IBEACBMDEHKMBGAAEHEBCAADGAIFADCHICE@KBGFA@KDC@CIIADCCEW@MDAHEDE@CCEAMHCFM@CJWDAJEDEDEDBHEDDH@HBDMBBD@DIJCDGJGAWIGBGEWGCKBMK@GCACGASQMAKCEBCDGDGFCLBBEFWCCGEAQ]AI@GDG@ICCCCAELGF@JBJ@JDNIVC@GHCHCRAFAMKCEEQCAGAGC@IAAQGOICEAM@KKK@EHIHCNAPFJ@NKHAN@JKBEEI@ELCLOBQDIHEAKLE@AAMJQ@GEIBQAECEGEBEJEVG@AKCCCCEFQ@KEKYAGACEEGEGSCOMCAGBGDIDCBAFCDE@IEEAAD@HHN@FADEBSFSDE@MK[EEGKSBSKe@EEKBMMe@GBKCIIKCMEKAEFK@MDMHIFCEMBGEGBADCPCNGJ@JBR@LCBAACIIGIEMMWAELMFMLM@EE@GAIDK@GAYEQDMACBGFEPOBCBELEFCVWHCAAMEEGCMBACAGTYZMTOFQEOACGC[AC@YTGDIDGAOUSUAA@O@AEBMHORMFQBKDM@QAGAGEKCKDSLSJKGQ@IBKFMA]@YPGPKHGAME_BqEKCOOKGCE@EBEBERYLERAHCFG@A@IQOAGAEICG@CCCEC@CBCHEDEBKBKHUFURGFAAECCSGAMGQBIAA@@MBCH[FG@ECCCAIJGDCBG@GJAJDJQVQFABON_FSNI@ICGIKBECI@CBIFEBYCGDIJKNQGEG@EDEFCNCTOBC@ICICK@OBCTWDOBUbGJEBCDODKJQFC^MPK@A@GSWKWuCEAECCGDkFMB[HKTIDGVIJGDEBWDQFENEAKLOBGBGJENAFCLQBE@MACCEYSEIW@OFMCIEOWCOACACGAM@]@OBUHWPGJEJGHKFADKTGHGF_LE@IC@CDYQKI@YJKFWVIPKJ]MQMWEEICCECIBEBSNONYLIFEFENIHUFo\\_HABAFOPYNUPCFAJCRBHENEFWNCFITBdORCJBbUvCDED_@GCQKK@½F]FKBSFIFABSGGOCCQGOM[CGFI@QC@@@CJMFKDCBGDEHELAFA@EECCEBAFABEMI@EFCGEACEQGAI@UGOU@GLWBQAKI[@EDCVGZIJAVOZOBAACKKAEAKTSFMNKDGLKFKBAEE@KEID[AKEEgCECAG@CDG@IAMDG@GCAKCAIEA@CHIGC@EAEKCOFCFEBUAWGU@GDIR@XGPBBFN@NBF@FADAFBNELAbAHMNGDAFGEMA_DEDBRCD[@GDQJI@EDIAA@CJCJEHKCK@IDW\\QNc`EHG@GFGVHbCNEBADC@CFS@GDAAGCABCAEBEAEBKAGDBDI@GA@BA@C@KAEBE@IA@AE@ECCBC@CBAAABEA@CCGAGKUQUECGIEC@CECAGEGIWCUGEMAACJWDU@EEMGCG@IEDMGKKCIEOJEFCFIHGHAFCTIJCJAPCHQTEJQHQDOFQDQHMBSC]JYDKJEDCAIEC@OFM@KFMBSDKBKAQDGACGAIGIOCM@IDIAAAAGAIBIAIMEMKEBGFEDQKI@EB[NWDCBCXKJADAJQFABITIHCHABGCI@QHGFCF@DDDHDBDAHWVIFE@CD@DEJ@FGH@JABGDBJGD@@BFABKRFL@HINSLADAPBRDH@DSAKDCFBJUEEDKAGFINED@DBDTF@HAFSP@BJDX`DJCBALBDHBL@D@DHFBDHND^CFNB@JAHEBIJBH@FDPBFFBDQNKFSLKLEHATIF@BJADBBHJ@HBBD@DDFADB@NED@JFHBD@@BCNENBPDNCFAFDJANIRIDKBAD@DJTDF@DCHAF@NDJABEDWAADAL]ZADEEEAEBQNKGM@MCGGEIAC@CCCJUDEGGC@GCE@ELMFMCKGSHCAGEE@@DCH@FELK@GDCFIBEDC@ILALUXBBBFHDJ@EN[HAPEHBHGF@FAFDJCF@DEJFD@DIP@JITADGDCF@FDHHDBBALIFBLAZICQAOJG@AABMAGAAKC@SACGACAQAEGICCEGESAK@IEQAICIAGGEKCBS@KIOAONMJMHKJDN@DCDBNBBF@FJFDGFHBLJDLAFJ@BALDFADBJARDRARLRFL@B@HABBZB`AFBF@NJPDFAHFF@FFLCHDFCFBHCFDFBBDHDHASRGHGDSFIEAJBF@HAFIFAJBHIFBDAFEAGDDIEEECI@WAEDCJK@MAGEAIEAUDCBCNBFFJMCIEE@QDCGDM@CWACFKACCEACBGFW@OGMOIFEJOJCD@HGDIBGFK@IDKLAFECGCIBIDMLMDEDGBCBE@FIMKAEM@ICGBE@IHGBECIKEAAFCDaBGDKHAF@JED@D@PEHEH@FBLINAHGDCNCBMCSCGDKCGEKCC@SZSHIAC@EJMHE@KAEJQN@DDFIF@DDLIBEFBHCF]ASFCF"],"encodeOffsets":[[97034,33311]]},"properties":{"cp":[97.008522,33.004049],"name":"玉树藏族自治州","childNum":1}},{"id":"632800","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@BCVEPBJRLRHBHFD@nGR@J@HLBHCLKVAF@DFFN@FCH@FBH@LDVAnOFC@IJAFBFFTHNLNFJBLBrArLVBNCdU\\EP@TAhFDA\\BJCJKFCLO^WVIPCJGN@~WbI^MXGVAFCLCJBdGTAjGhEtKTEVGbQNCXInMvWL@JBPJHDLBX@NEH@FGFCN_NMFGZSTCHBPAtDZCPEHGHGNWJKLEVCVGXEJ@N@FAPBtI`@PCHEFGDUAGagYSMOAWJYHIDCdI`CHCRAJA^CFCNIRGpQfWfM^ALCDENARK^KJIPGVGNCJ@fG\\@PEXQBEHCFIFAFHATDL@RDJ@Z@vEp@\\D`DRHNB\\DHGLAJIpCLCZBNDHAHHFXN\\FHLHVAZEPMBEGWCS\\LSPeDEFQLWJMTMDSLUJKNUDKReJYF_LOPKFI@ED@@EDABKFCAKDCHAAEDGAA@GACAAAGECCCBMFEJ@HCDBNIFK@CFAPID@B@AEBE@GDAFEHABABBBGBCLAFCLDPFF@BBJBTEJGHCHDHJD@HCF@BDRDDDJ@D@JDPBDBHEVEDEJADCDDD@FD@HHBBBB@FDRDB@FFFANBLFP@HCF@TDFFV@F@DAAA@GEI@EIK@ECCEACAKEOCIAA@@MIEIMCAKDEAMB@A@EGEEGQGGBCAADG@GHI@IEIBI@eD@A@CCAAIIOOAAC@GCCE@CA@GAGCAI@AACGCCM@CAAAEKOI@KEIGECGBOBA@CCEICE@EG@CJKPABA@EHSFEDAN@NEBCDAHIGMGCDG@GFCBABCDC@GCCBCFMACEAAAACFGEGEC@ABA@AEGBGJGAEGE@CDEAEDCBGFCACCA@EHCBGDCBEBCNOACEAACAIEMASJEBA@MCK@CHOFGDIRM@AAIEGIEQCAC@ABCNAZIJGBGHCH@LADCBGAMAOEO@KOWAG@E@CFCHBHALKHCPK@EGMAEBEHGDGAGISCK@EDGTWRGTIHELMJEHiCKIOOM_MUQWKSCoFSDQIMOCAQCE@OH[NOFGBEAGCCCCE@QCSIMUOEEIQGWAGFOBMFEFALABCcAKCMEmSOGQKGGACDMHKBUJS@EAGSKCEBCTKRUFA`BPCPIxUJE\\Q\\ONIDEBOAGEEKGAED[A[AKACQAKICG[]QWAOBEFETMr]JGLKHQDSNcBI@ICcCEMIcMIGAMKKCSNU@GEKMKGKIEEIAIYOIGCEGOAM@eACCEGGIGUMgKMIIIAKBaAG@UAUEe@EG_BMCQEQCKKKECIIMSGAI@GJIBGAM@OCINKBMFC@GEKHOCCBIHWHIHGLADGBGAMES@aQCAAEIAIDcFULKDQBMF@CDO@IIMEAMEIACBKREDWDUAGACGKEAIAOAAE@KDA@GAMOKBKCE@EFMHEFGDCHCBCBUIC@GFMXMFGFJJFN@LBLFHBNADEF[RABNHNLJDJJVBDD@DCNHTOFURMFAHBLCDKBUAGBOBSFQ@EBENCHEDQCWKOCKSGEKEEAWC[FQ@GAMEG@IHKBYUAC@GDQ@CIII@MFYFCACCCOWBABAAAGCAIAGDE@MCCBCFADCFADBDEFMBK\\OLGXCFKHIAECEDKTCDCAADDHFBFHAFELCHOCSBI@UGI@@@BDBDAVABCDKDEVEJGJAJADI@MEKJOFA@IGMCAMA@YDIDKPQNC@GACBABCJEFA@KAKBIBIDEHANABSAKFM@IFK@QBWPMDDLCH@HSASFMLUHEHS@SJkHEDAHEFQDGD@NABABK@ABANBHJJAHEHCBKDCBENMHADCBCAGCCACBGJC@IGC@GBKPCBE@MAMGKKEEGCQCAKGKBEBE]GGAAEE@KJAHAFEFMB[ASJGB@DILYLWDS@WHO@KF]AQHEHEBOTEFMBGCA@OHCLGFKAEDI@MBMAE@KAEEDE@EQIWBGCGAAEDOIGGIODABAFIDWIAE@K@CECMIEEBACI@CACFKC@[D_V]NOHqbCBMAACICMGGEOEEDELEFOHEBKNE@KACIGDI@EDABcAG@SAIEQBMHEBMA_UCSOaGPCDCHG@AXELCF@DABGAY@CAECIBYMEBCDEBABI@AAMBEDEAK@CAKAIBOLOBEFQFGHGHGBWJO@GEICGBMB]GIDGHCFKDMJcNIFIJOJ_JMRGBADUN@BCBILKJGBIHAAOFC@GDEHKDBFAD@DGFaPqJcRKLCDEJEBEBGAÙKABAHGDKDAJIFIBI@SHA@EECBCNwrSTOX©ÊIJYhEDEDUFEHGDEBOCa@GDCDGDyLuPoLSHKJEJ@HHVML@LCX@JANCLOFQ@YHCDADGDI@eHSJCFCDMXAJGJKJE@DZAFBDAFCBENBJDHANJ`NFBJFHAJEB@HGDAD@BHHBHFFDHLHADEHEDCACBKJKDG@BLCPFFBDAJABUHQBOF_LaDSEG@CBEJDJIPBFJFFBRPHRJNFFFLPHQJSHoEI\\GDMBWJAD@NCFMBADAJDJ_ZSFE@MCKGC@G@OFOCIDORIHBJABEDEBKFKJAHDPAFADA@EA]HWLCBEJEHObEFMLEBEBU@GDBVENIN@FFDBDMLITKLABBHABCDM@IJAF@N@DEFABQ@EDAN@BNDRBFDFFEL@RCFAPDDF@BBAL@JF@J@FHPBNHLNDFFFBLBDPFJALHTGl@FAHEFCFBBDAPCD@HL\\^@VEHBHDJJTNNFDDDJAHCDQLCFPHDHBJHBNCCJBJCFDJ@DGD@DPVJlHF@D@FIPKNBHEL@JBDFFFDNHLDNLFDFJNHHJFPBHADABEBI@A@BVADCFEB_GWLEBKLDL@LBHIDK@OFEDEH@BRRBNBDHFJFDF@HCLFVCLHNCDIFAD@NABKFADRLBD@FCJGH@BBDCHBFFF@HFFBH@FKJAD@DJFBBKJADBFDFBDADSLWT]R@DFJ@DCFAP@BJDBFFBL@DB@FCNFPHRKBKHCPCDGACAAGCAQHWBQDGHGTGDKBCB@BBFLJDDBJDHATEJOHCDAFDFHJLDDBMLCHJPLDP@BB@FBB^BFNHFRCTARED@JHHBANFNEH@DBBNFDFNFJJBJCFCL`RT@NHH@JBDD@HCD]HAH@ZKXBNEHAFEDUBEDKBIAEDDHDDPF@FGJCFCHBHJJHAFED@XDL@LHPDL@CMLMNEveVEZHTPRVTLXHLFFTHR@DAfELERC^@NCH@ROFUNSPMRChJVJF@THdZBJ@HENBDLPTLBHFJLLXHVBVFH@LELK\\Sh@HATEDADDHHRLXDN@\\ElCZDPDF@XFXDLEPONCN@FAXAPBb@LATAXBhAbCP@VAXFrBfEPAJCDG@IFOJILCvNlAHBXEFADC@ENMZArF`BZGNGJCJGREPKH@^MLAVG\\ELEJAbMJAJGFAHG@E@MBGFMFILEVEHE@MEOCMAGBCJGDEJGHGFAL@TBFA@CHI"],["@@D@JKR@TEXOJGDC\\gHELE`IjINCXKvQ`QpWTGXE^OfITIDCFIJW@EGS@CDIRKVCZ@JALC\\QTCXEV@XC^K\\GNEp[^YRKjOZK|KLAJGHBFALKVGLCJAZBVCLC\\WBE@GBGHGTEJKJGPBF@NGJQHMVUJEBKBADEJET]DA^APMHMDQAOGQAG@GHMLKJALAFAV[LQHGDALAl@EJGX]HCHAFBBXALBDHDbAPIbYhU|gVIYnEzMdCl@lGREHCJINYPM~gbMjGRAlDpNZCNARMDIH[FGLMTMrIfCVD`BLDLAJCPChARB^ATCdKNGXMlSPId_HKFSFKDENM@GCCCCGA[DM@aEGEAECKEEKG[IEGBMDEXI^EFCFADKCGEIi[KKGG@C@EACBACEBCHENCLANGPAJILCHDXLD@FGFALARJLATDFAFEFMREFGbGF@HFXAdDjHtPXTZPVDNIH@DHDbFDXAVJ^DLFHF@JDDXDTADADIRKBEKQEC@CNW^SXKbKlE\\KnWLAP@^F`NvDVA~SlDP@TKBMDYDGRSDCNGJ@HBLENCEHDJ@DCF@BB@HCLMhGHCBADGBKJSBOCEHOAIM]I]E_@IBAF@LEhKNCNANOF@FALIFAFGJBLCJFDALIFAVAJEO@UMGCGCIAIIGBAFE@E@ICMB]AYEWMMEOKOGQAJYEWB·_UF[LIAcO]Y[CSBChSFKJELADKEGIAMGGG@IRGLIHAL@LKXKVGTCnc\\KFwNO^@TRHVP@RGvQT@fGbINMLEVCXIdGRGDG@EACGISICEAEB[FaNeHMTIZCLILWFW@[KWKGOCS@WEiQUQKQEEumMC[HEAMAQISQCK@GLSBEAICKGEKEiIGCOMSYKaWgMMEGAC@KTaFUDO@aASAGOOEIKEQMYKUACAECKSAcFkJIJEBILG@MJK@OBELKCCECE@@CAGIK@KACGGBKECGCAA@CDCXYAGAA@CHMEIBEBCCYEUBIDAVCTADCASAKMF[AGFMDKACBGLEBIEIACAKHQCGDEBMJA@CGEYEoSWWAaBEAAABC@ACAKDCAAECGMIIBOACE@KCEIACEGCIYcASCIAQGOCIEGIM@IAEUMMA_OE@GD_DYLK@AAJUAIJEREXMPCLEJSPEZALERKVK^GRIJKBG@IBEHEDCPkHKHAH@f_ÂDCsRUIKG[FMBSHSJKVODKAO_SGK[KeOIB_GQOU[iYÑaû©WiĝOK@ME@ARWBCACIGCA@CDKDQFEJCN@JAL[DMDCJC^ENCLIF[EUaU@[KWW}@GBQ@ECKIESEiEI@cGCAAE@GJKHCjOLGFEDEDMFaDKCEBEDANDVELFJFHCFCBC@GEQGWBGFCJE`GNEna^YPSHOACaiAK@ETYRUdcJMJQ@IAMEIUWFEPCNOJIDS@CEK@EFQBGAAEGGCAOFODGFGTKPAZ@NGBEPSPULKAEFIBKJK@IFEPEHG@CAQEG@KDEBAGWDOGOSSIOECMAACEKAGGEEICAEK@IIISC_BIAAGGCC@EKIG@ICEEASAKGWCIDG@GDIDEBG@ECOBCDADADKDIBCSEGICQCMDO@SDOASHICYHSBOHmFECGEAACCJGDCJI@AKEI@WACCQAIIMBCACFGBKJODQLELcRoHiGKGACHOBMCY@GIeGKGEKEWQkMASCCAYQeGMGGE[gYQKE_EU@sGwMgAOBMFWR[NIFiFOAWKYGKA]BmEgJEDKNGAEKEEQCIJCLMFEBBFNJLVBJCF_HMBGBAJCBMAW@ECCGEAAIBG@GGEIACCCIIGKCKEGI@GHSBIAK@QIO_kIcCIACIW@GCQGKASEI@CAGDCEKDC@AS@SJIAGDMEEAIJADE@KFECEBYG@CCACGQHK@EAGEKO@EASCKEAYDOAYGeIcFsAcCcDIBOLMTEDE@GA[QEAEBULYXGBcCUBURQF_GK@SBWHQHKLMRGFEB[GQ@w@CBKBEA_DGBEFCD@JJZ@JCFIHODKBU@UECEEAGEEIGaAwJFOBKDIAOCEGEUCU@[HUPKDE@C@CEMAMASBWFYFYHwZOFTY@QAKIIEIDKREDC@M@QMGC[@SBAFMPIVDJ@PADMHM@CCGGGMEEKG_AYBQFmZaAQCQBMBTeAQDSJ]TcpMH[JQRCFCJFdCPYV[RcjEDOBGDYDEDCFEBC@ISMKKGMFAF@HBH@PDFABIHIFSOECAEAAE@EDG@AD@LAGCCEAAEGGCBGBCDIAIFCACBAFG@_LAD@N@DMHECIGK@GEEAEBCFKCEBWDKAIDA@IJEJAHKNQF[RBHEDGASPAFYHEFID@DFRCBCDEDAH@DEBEAI@EBCFAFABMAOBAGCCG@KEG@KFGAE@KHGCKBEGSCc@MEI@MDKJADBHGFG@BDELUFE@MH@BEHS@KEK@YDOFKAQDCB@Hk@IBIHGBMPYCEBE@CFUBEDCAGDQBCDUBKFU@SHCCAIEACEG@EGAGQDGFIDG@MDK@GFMDIGOBKCG@EBCCGHE@EBQ@GDCCAIK@GACMECCEQJO@GDCCECEAKDSAGFEBAFOAEBIBGDC@GFMBE@CBABGK@ECIQKEGGCG@ACC@EEEAE@M@EGSDIACMEEGMBCAE@ECEBCAEIO@GBKAEEC@GCAIBEEKGGCK@CCMGQ@AACAG@UKMCMDGDGHELARKHAHGDAFOFANAHBHEP[lEDELOEG@YLGFGROBýFgFyOCBELETBDDD@DSCGEUA[@KAKBCCEAGBEDWFC@GGWGQFGPIFGCa@GAQCKHG@cIK@GBIJG@ICECEAGD@EAG@GDCDUCEEICEK@WMSAOEGKAGC[SCCEBeCMBMAEDWFSAABMVMZOCEBGBINMDCFQDU@e@YEIFM@cNMBQAMEE@EEICGBEFKDC@IEIDGDU@CB@BBRAJMRCDAGEIMM@ATOJQJCAASA_IG@C@FIBOFG@EEG@GJEHGBECGEGGOKGMAaNCCFEBC@ECEHGAAJE@EIGCKDEJG@GQ_@EEGACIBSJCHCLGL@BHHDDAFKFKBU@OD[AGHG@MCKAMDCDC@AEECMAWJAF@HCFIDKFKLC@YMYDAAM@QHKH@DDFGBMHMCQFCDOFKCKAKFC@E@E@GCGCMDEA@IDG@AQ@MECBIDABEL@LEP@DBDAHOL@JABGAMGAAAOSGMOA@CFGDCJIFIHCF@DMKU@IAODK@IDGAECII@MCAY@CISAG@CDKBM@EBILCBSCGPEBIIECK@CEAA@DIJE@EESCE@EBOIG@ORIAaFe@WFMF]@SMIAuFGBOH[TKH[OGAQAWBWDKFMJOHKBWAMBcNOD]EeCG@YLOPEH@FRHLFEDa@K@GCSQECMAI@eZSHaH]@WIGGECGQECEGGGIAK@UDOBaCGBUIE@SFaTONORGHIJMF_FYJEDMFaTKDCFIFMDW@UG_CI@GF]DK@SDOJMPMDGAK@MF}JCDMFGBGNALCNIDQBIAKECCQEgAG@KDQNCFKHI@_WMAIBK@EDYBMFSBIDKBYPI@GAKBIDeTSCEECI@GCKCCKGGBIASBKFK@OHQDI@MBcLe@kCIBOFGBa@]C[FMBAEAyBWDmTKBcCkBeHiNmDMDQ@IBM@IDK@KNGRCPIPEFKBKFUDyDGAECMGQQCAG@GBYH]FeJUDWBgLUDgNK@iJSBY@]CFUD_BeH_B[CO@iBSDe@@LYFYBqLO@gDKFUAKDGDE@KHQJG@SHIBICI@_EW@EGGAEEQKIAG@INKLcFaEm@YAG@eFI@MD]DgH]HQBgJGDKJ_HËfSBG@SF{ZKBIDgXBVGJEDHsJ[PKBSBkEmO_GwIWDeBYFTSH[JaPUFS@YFKGQCSNKJGDMBUAQDKDFLIFMPABICBLAHCBIAID@RGHH^DFFFCJNT@HHNFFADDPFFFB@@WGQBE@AC@GAA_WOEEIAOCAGAGCOQQII@KIEEMGOCECKCGCyOoQaC[FJwDqNKHYXcVYHYLUF[FmPqJWHULIJQHcDIFQDBDTV@BCJMHADFV@THNAJABIFYHQJWHEACBMTBVHTFJNNZRDH@HGLIDE@MCKBED@DBDFB]TULCHBHHJLH@DGJCLCJBFFRJLDLFLCDKHCJNNBBAJDHTVBDBH@DCDEBW@GDEDCHFbDPEF@DTFDBABIHELBDFJ@FQPAHBLP^@BABED]BKLKDODO@ReDC@KIQFCHGFIDWEI@ODG@EEGAIBMHG@YAKCC@CDOFEB@DBFPP@DCBODGHC@IEA@]DI@MEQJKBWEWBILQXI`@BVDFJ@NITALBNOLMAKCG@@DNTBFAFIRLBJJARBLFJdDHHLDLF@FKVWHERIFCFAFJN@HMH@DCXA\\DFHDBBAPBFFL@JDDB@`EL@JFNNTDDBVTBF@HFNPRNJLRNFRDH@XCR@VDNBdAVCv@XGLA^F|XRBDDDTFJDbDFDBbFBNDTLBDBLB^DLBBNFN@PL\\HVDDFHBLAZMPMJAXBLANBHFP@PAhAdBLAJBFDFJAHEH@FCFEDGDMFEDCDBFHNPLBDALB`ALEFYZ@NCHBLGTBNAF@DAFEFBLDJAHCBSBCDCLGDKD]BKDCDCLMJEL_DEDSDABDDFFDDCJIFAJHP@FCDANCD@DDTAH@JBDFF@FCFM@CBUJEFCJBDDBDJCFKJEJMDKBIJMDCDDdGL@DHHADKJKFCBLPCFKHIJGRCLAXBTAPCPEJMVYTGLIF@FAFQHEDKFI@UDgNQBKAMDGCOQIDM@GCIAMGGAQDO@CDAF@FFDBDBLGHaLMRGHMAGBcT]BE@CD@HDVJP@FAFDDLFBBBFFF@FEFCHMJKJMDADCPMBIHSAUHKLERMJWACBEPUPGHK@QFUEOL@B@L@BUDOJKFE@CAOBIFE@GBGHW@AB@DBJGJCBMACBGHAHKAMICAMFI@KAQCMDMHSBOAABGJCXEDaDQHI@IEOHUCCDADGЊ^Ĭ±EÕKUQÇÓHùÀKNVRHBEDOBAFBJHDHCJBJCTZTrMFHSGEHUTELAJ@ZBX@RA`BJHFDF`VD@NEH@V@|FVEJAVBbHnGVBLJLDFFADAACEAECBGDAVFL@XKXKLA\\JZ@NBPHj@HDFBFJBHJJJHRDLHPFDDCJGH@FDF@JGHADDHFFBBBD\\BnEJDRHZ@NHFF@D@DGL@BBDRDFBZNHFD@LANA^D\\BJ@DD@DGJCHBFFFNPVPJFZDDDAFIL]\\KN@BJFVB^JT@VGLCL@T@TApSL@jHVAbHpFFABCIK@CDCLDrZ^DNnDfPjDLBdLRBfETBlDTJRDjDtF^CV@LFPNÂ^dPLHJDHEH@FBFHBBRHP@jMJHD@RGN@LBRJJHFJFBN@DHDBTFJ@PADBFBJLhXPDLHbADBFLDFbJXLdF^@XAJFF@FElNZJPATB^JTBNFLBjDfNFBJNHDF@LCbBL@NCDB@FCDBBXN\\DV@\\CVBNDNBVEXGLANDbRLD\\DTCnFRFTBDBBDATBHBB\\FPFhHFJtTF@F@H@HLFDdFFFHDTARHF@L@JAPLPF\\AHBHFPBF@ZBPAHDHFNHFBVCFBFBF@HEHAJDREHFFDP@HCJAJJJNHHJDDHDBPBJALHNFNFJAD@NHLDL@FFFB^BRADXATEF@BD@BFTFNJRDLEDFADIJCPIL@FFDRBFD@HFBRAJCDBNCFDLEF@DBBJ@JDHEJ@FBDNNJHPNBLJLLLDBLCJDL@FBHBJEJDF@NCD@HDABAFJHRAT@NIDD@DZ@JFFBRGR@RFN@ZHFBFFTOHCJBTNFBXEJDLBPNLBF@NELCDBJHL@LF`D@FHFP@NFR@RCLBFAHEJALBHDLNLAPED@HDFEN@LAFDDLRLVR`B`JZ@HFbELEDEBEDIDGPIFADBVNHBC`GXLVAPN@FZLTFLP\\DH@VMXW@AGEES@ICCAA@CBI@ICCIE@EDGHEAIRIRAFCDELELGDKNQBMVGFGHI@IJICuCQOÁMoVIbGhAXDnS\\URCh@~TĬX¾FȈLbWØXM¦@@ĩKMCMYBCHAHMBGBGFK@KDGFENCJE\\]gRCZI`GTFPAPAXG^CFA^B\\JNJŬbƎfTC\\@VCfA^DLF`F¶ŇêǃDIHGTSDG@GAK@DIRK\\IDFF@HADHHBHHTDBB@HBBTDBDFBDBNEL@LHT@DBJBJHPBFBLBLDLALDN@RCJBDAH@FBLBT@FDF@L@B@BEBAJBP@PAHBN@NBFCJ@D@FDNBPAJAHBJCNHL@HADHRAfDJBDHR@JFBDFH@LFDZDJHXANDTABBBHFBRBJ@PDL@RBF@PIHAJANDHCP@PFJEDGFCJIFANFFHB@NGFAJEDEVILFN@VLXHPALFHIPM@GFCDIFEDBHADADCT@NAFC@ELIHAFDD@HIFE@KEAACDGFIHWNIBKJGH@H@FDNBF@HGBGHAJELAFCJIFQPIN@FBFDDLFBdLF@FAD@DHFFHDDARGFKDCTBJFXBNGH@HIN@JEJFLDFGJCF@FBFLHBFFDBJIH@F@LHHIAG@GHCFGFARJFDJBJDDJHDBDJHNDNEHEBE@UJ@JCDBBBFHTL@DJLZBNPLBNDDDAHFD@DJDLJNDREL@HCFBFBFHNDFDVV@HDDPDRELBV\\@DCD@FBDDFN@DBFHDDPAHBDFD@HKNA@EBCNE@GDGVKP@HEFCN@FAFABGLCNGb@JENCHCFFH@LFD@HARQDE@GFIDWHOFUBGAGBEFIFEHCF@JD\\FLDNBHAVSNOPIVQEO@AHEBKDE\\GFIFED@LBJ@BE@I@AVCDABIPAREFBD@FOJANBDADCFIDC^SLE^IDBDFJXJ@LEHA`HLAJE@EFCLAR@JCR@RCJKT@PENItUZAHLD^PBJEZ@DIAKDEPOPADBLLFBLAFBD@BFBBT@PH@BGNBNIDELHDPLEPr¢~lJVAz@rE|MQŠC|KdDFCFKFADAFADDDD@FDCDMHEFIFEJCFAJEFBJMVBHCDBLDJDBBDDBLFBBDFBDFFDFABDDNFLJ@BHD@FHNRRHJHBDBF@RRHX@XJNDNIHKHMFq\\@LLJPHjCDJHHLB^@nEB^LJR@RIJWNWHIRJNVPZHT@TKEHAH@JCHSPAF@NCD@DAD@DAB`@FBnSX@|eVAXBXINMPIK`DTLdtVKBJDH@JGBSBIHDBN@HD@FFJDLJJIH@JOJGKIAKBGLM@ADGNIPHFBFADDFCFAHTV@TB^WJUBCHEDEPANGTDP@\\CNFFBRDJCL@HCHBLAJCDAFEHBHJJFLEDI@IBIAEDKAUPIVI@ID@VRjENGFGNBRRzbrDRS`BPJ^IVHDNDBT@Tff\\`LHHJGJI@BHABG@CB@FCJBBAHMDABFFCDEBBDCFC@ECCDIDEDBHAJGFG@@B@F°Vt@JAZSPC^@¸HXAVG^@^@zCfK[tORBLCN@jHJANGDCJYDGJEHANA^JPDJGRSTMLEFF"]],"encodeOffsets":[[[93168,35583]],[[99772,40066]]]},"properties":{"cp":[97.370785,37.374663],"name":"海西蒙古族藏族自治州","childNum":2}}],"UTF8Encoding":true});
}));