(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('河北', {"type":"FeatureCollection","features":[{"id":"130100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@DLBNFfAPRjpllzR\\ptJNFLDJOf@LDL\\bH\\FNDPG^ONOHWDiJGJIFWJKB]COQQSBED@RBRDLHJ`T\\HXPFLDJAJCLMJWNKJBLAJGLQFaCMBKHEJELALBCTM^E\\EJILMHODORMhENOTENOTMHGBEDWCEBEHOLBBTBDBDLEH@HJT@LCFGFBJCHHHBHEFWJGBEH@DDBCLCF{xCBK@EDEFLZJNDRAJBJDALEF@@FCFGF@DHFFHADCDKBWEOGS@oNaDS@IAEDCAKEGDKFABPHDB@HNFDD@DMHGAMCKFADBFDNCJGFUKKAOCOBKDIFW^MJMDKBU@wKU@KDMHIJI^QNYX@TDZRtDrIRUNMLMVCPDPHPBLJ\\RTLLj^LLJJ@NSRYVCN@LCLAJAXFHFR@dBNJRdLJFNJNLFLFRGLARLnFPVLRB^GjCpDVFPHHP@hE`BLDJNHRATINKd@RHHHJfFPZnNJ^IXCTDbQRGfBHEHEFCNEJGFGNIbS@EBIEEPCT@JCXBHCDCDGHIJGNAHIH@NJJBJFFCDCJBBBLJFABAACDCFAFCZLB@BCACDCDAPABKBCNDLA@C@GFGJG@DXDJENANHPCDBBHAFBBRJHFLDD@FED@JAPD`@ZLdLLBhHvL¢PL@RE^[NCfCbJRHTHdHJIZINBRLRGJCJGxWTOPULKTGJAAWBIFCLMBELO@GEIMIKEICECACDKHHPLFAFCTDLEHDFADBAB\\FBOHOHIDGBEFGHERYFMDCD@HE@ORUDCDCNCTQDK\\_JQBAPLjT^DRIHA^HXJTFRBT@xIJEHIJ_FGH@AICCEAKB@CAMJELE@SPBBR@@DPA@@DDNDBHAAEBEHCFADDDI@G@@AGAAABAC@EDIDBBBHBB@@GB@@FH@BEZKJGFITQDERA@C@CB@@CCABCHCL@FG@CACBKDG@IH@BC@ICI@GD@@GFC@GHAJBBACKIS@@IBGAGWE@@AGCSEEQ@KWEEGGACEAG@EDEAMFEZCVA@ALDBDAB@NJ@@HHHFFH@\\EFEnFACLBACH@FGJAFBBCBMCMHEPCDHJHPFbFNADGJACID@JHLCTNBB@NE@BH@FEFILDDLFR@HIDILMXMVKlI^CPAbFFEBEFEJ@AANA@KH@BGFCN@LCBBBDDADTF@JJDRFD@BCBBFDFGFNLJNTPRGPQJOG@@OFIH@JEBACW@CDCfKV@BBAHBDDDLFL@NDAc@UV@ACHAACNAHAHEBE@IACKCEEAED]AYDMD@AAD@CSDA@MDA`ABWF@@KJ@DE@ICA@@AKNC@A@EF@@CDAAMBEFAH@@HBBPBPCBJP@@EBAFCL@BCDCVEHAHBBDBDF@@DD@@FH@DDDBFA@DF@@GF@DADAAENAFECOG@GMI@KCACH@CUC@@@AGEMDICKAAKAGBAIHABOGEK@AEG@BMC@@AD@@CBABDJABDRA@EH@BAH@AEDEGBWCGEAGD@AMVGFCCI@SHCFAB@AEECEBGOCBCKAAKAACSF@DSJSABMC@@MDB@CAICECCG@UBELAMAAE@CKDAEEMCIAKD@C@QE@@M@AC@AOFA@@XA@CDA\\AAEFI@IAGE@DGCAY@@IE@AB@HGAA@@CG@AE@KCEDIC[CEGBAEEQDECWB@BOZABCLK@IGBAEC@AKEA@CIFAAGBGGCBAUBAH@BCAG@CNCACDEXEBDF@JABCPCBIHEF@@ME@GEKCK@{LABKDKEAOACMEEAAA@GGBAE@GHALK@C@ECCM_YBE@AACQDCAEAAC@CK@EHA@AAIEBIAOBGJIFICIDIBCFAHB@BB@TENAPLBFD@DAH@P@BE@ALABCBAHABADE@E\\CB@HQBA@@FG@@HC@AFOD@FCCG@EDCFQ@CB@JIB@BIAACSJAAG@CD@FCBAFMBCBBBGDAGC@ALAB@LAB@DVJ@DAJD@INCB@FC@@HE@ABBDF@AHA@IA@EEBBE@@QA@CA@E@AJKBCLEDU@@EI@BCO@@UG@@CCBI@@CGEGDKEAC@[EA@EC@@KFSEABEB@BKAACAUC@@@CQEKESLBBBFCDC@K@IFG@AHEDG@@ADCF@@SEAE@CGECUBED@JGAAEE@GQCBECEGOIO@@AABKDM@@HGB@JCB@EAAYAIDKAI@@IAAEK@@CA@ECAOHM@@EKMCACBAIMBEKE@CBOACKGKABAEFGCESDBIEDEIAAGBAAEA@GEEE@ECAEBAAEECEODQGECBAGAAE@EDSB@AB@@CGAICQ@WDeFOBQEIIIMQuGOW[OG]I[Em@{ES@gHuRQJUHeHK@WCWIeWSGUGKAKAWAOIC@IEOKCC@COAIA@IDEAGEIIDKFCBG@@A@GI@MGC@AIICYCIFICAEGF@BGHCD@AB@@AECE@KGCBCAACDKAAGD@DSCCFGDACI@CFE@AHG@EB@BKBEACDUBCDIBGAA@KPGHGBGAC@IJKFQ@IDCCM@IBIH@A@CDEPCH@@CCGKBCC@ELC@ECCMF@EHCCGKCG@EAGIA@IBGQCABECIA@ADA@EFGDGLABQDMKUcKKCOGCIQBMODKCACOCeEK@"],"encodeOffsets":[[116760,38334]]},"properties":{"cp":[114.502461,38.045474],"name":"石家庄市","childNum":1}},{"id":"130200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@A@BBBAA@"],["@@@BPBJD@@@AECSA"],["@@A@@BDBD@AACA"],["@@ADBBHJXPFFB@@CACe]"],["@@@BNLB@@CAAMG"],["@@A@@BTL@@EB@BLFDFB@@CKOQI"],["@@@@BDFAGA"],["@@C@@DDDDABAEC"],["@@ABLHD@@AMG"],["@@ANFBDAAKEA"],["@@IDBDNHFABACGIC"],["@@HJKNfVH@DCAIEQOSIEC@CF@DCB"],["@@CBGHENCF@BDCPWJABAAIIIGEOE]QgQYCGFBBBAJANBbNdXNDLFJHDFCDC@"],["@@bLVFLFXVfdFBR@HEDGBIAESII[KSIKWKYG_@aBEF@HBJFJ"],["@@DDFADDH@JPEB@DKDDJJHBDBDAH@FL@JDD@BDMB@FERQXEAC@@AA@@BC@AA@NA@@FE@@DC@@BD@BBBCF@BCDDAJJBCHDFEDAGMRGAAHEFCB@BD@QTClCFAAK@ETEBBDD@@DFABDDAAADA@FAB@LABBFEGE@@AE@BFCBPB@BF@BEDFBA@ADDDABHA@HJ[JANHLFABFJCFLHCDDDD@BA@BLD@@HB@BJRNAJCBA@AFCDEDAJAB@BFBDEDBDCDJF@BAF@JADBFCAEHCFDF@CDFBJ@@ABAHBDABB@BB@FBD@BA@AF@@AJ@BCDC@CDAHEHCFB@GCA@CADA@ACBAB@A@FEF@FCF@RCFBDBBDDBBAR@DBFAD@JBBDJANBPJH@FHLD@DB@@CJ@BAJBJAPIJ@@CFEBELAJDF@PGFEHADFJJLGDBB@LAHE@DLLCDBDBFABBHDF@DDB@DDBDD@@B@@FCBBFEDDB@DF@@DGBCBBFABEBEBCE@JA@@HY@BQA@@NC@AEABCAEDGGBIACYP@TAHFFBFBFA@@NBB@CDB@ABA@FB@@ELADBNFLHFNADAAC@ADC@AHS@CFC@AJJ@CHAB@BCBCBG@A@@CAAWAEFIAG@EDBBG@@BC@@FEADCCAADAJCJA@ACC@GBEDAAG@CAAIBAE@FACGIBBDA@@@AAEB@F@@AKE@@HB@ABDDE@@FC@AH@BC@AHC@AGCAEBCAAA@CAA@AA@@BCA@AABAB@AC@IJFD@HBDNF@BDBCBD@C@BBG@@BD@@@EDFBE@ANABD@ABB@@ABFCACDBD]H@DDFADIDBFCHCACAABAAABC@EHDBCD@HC@ABEA@DCDA@@CC@AFAFILOA@AGAIFINE@@DCFBD@BCBBDCBFD@BPFZGL@FBJD@JLFJHHBRCZ@FDJNDBlLDDNHPVHBLCF@LHDBZK`EPGDBVXJFHBJCDBDDPHTHTPD@LED@TBHFDBVEJBNBJHFDjBHFPCJ@FDDR@DHDNBfCVJBAHMFADBRPLH`DVCNAfPTDNHNLdPPNFN@LBVFFD@J@LFLCXBTAHBFDHLBJLRNHJLHFPHLHBHWPABFL@LBDPDHAJAFJTBLD\\XLDNDJJF@H@NDFH@NNA\\MDCBECMLKHADCDKFIzKH@JDVABBBNDD`DVFD@BIDAFBP@`NF@DADAFWLMXBPEREH@jDJ@XCHEDAtGjFJDVLRPDAHIH@FCV@GCDE@ECGCCICAGIKGGLMBQECAIACC@GBC@CBGCBeKUCWB[AKBCFCZCBGDAHAPBJC@S@GFGDEJCbC[MVQTEn]D@JFLCJGBCEBJCBCBBAEBFBC@@FFFDD@BAFADC@GCEBEAMDAP@TDZBNRJFF@HANIjQXMPAPGH@NDJ@FAVMVIH@PDLALGCMBAZOBWEKGBA@@ADACAAEBAHBBAB@Ea@MAIAKCEECMBKCwmMCAABgAcBEDAVKHIDEAGCIAIFWCWDG@GCGIKCSACICK@GEAQEKBeEM@UCEKQGEEKGIHOAEYQQ[C]FKPK@AACQEaCAAD]AAGEiMACBIDC@KFIDIFgDKJH@OBEB@DUB@BEFAAGD@BAB@CEFKF@@AB@CA@AD@BAH@@AEAHEB@DCD@BADBLY@IEC@AtsAEIK@EFIHSD@@EC@@GL@@ABAACD@@CA@BEBABC@@@GJ@HCACB@BBB@@CJ@LE@EHIAMJEJCH@NHVBnJJBDCAGH@@AE@BEA@AGHATBLABAdG@KYGGB@EKB@AJA@CMB@BC@@CN@@AE@@AH@BBAAJCA@EBBCCD@AC@@ACABCJA@EDJ@@AGD@@AB@ADDBE@J@B@BCZ@BEZABDBCH@BA@BFAC@ACHA@EDADGEA@CBAFAGADSOKCGAIPBBA@ED@@DB@DCV@NCJ@PEH@D@BHTVFDF@TAREHEhEZ@Z@LAXIXBPALCJBLDZDP@RMFI\\M\\WLELCNGLAP@VFLHLDD@LUBOACECKCQISGQIQEQ@MCGHCHCBYSGAI@CCE@CAAECAUCEISIEKUWIWUO[oUW_]YaMUCOGImgOGEIKGGGAM@kiqkOIYYIEKCQKAABBDFBVNJBDBHHJCF@DTVBF@DGFIDUCmKCAS[WIYCO@IBIF@HCHEBG@kQaSKIcGc@eCHMD[NKD±TWEmQgIEECG@EBIRSBGAIIMGCIBPIAEC@GLSfh§HA^]HETEDGAEic]IU@[@SHëªyXOXFzAHK@OGaCoAQFgTKBOEG@KDmVG@ICMBGFKZglQXQ\\gKRGFdCDCRCDEDQDg@AVz@@FBDAjABwP@FE@@FDHMFBLDDA@@DADEDCBACBAC@@ACABA@@IEOHAAC@ABBDABECADCAGAADA@DFGFG@GACDBBCBABE@ITD@@DA@DDA@CAA@BBIFA@@CSD@A@AI@EBADO@MB[@@AQD@CE@@ACACDAFUFBHIHS@WCGDAFME@ABAAAE@@AC@EBBHKHFDBJHADPVXCFCAEBECADFDEFGEFEA@FE_SAFEDY@GCE@MFEFAD@DDT`FfBTDFBLMPJILDZELWAALrHAH@HZPAFFRFDD@FEP@BIBBFH@DhTDHLB@A@BFCE@BBHC@ABAFBBBBA@BDA@ACEDBFCBBBBBCBDAFDABBFHBDJD@BBA@BPB@JND@BDFHBAFLGJ_HiRMCEB_NGAKGK@CEGDOCUBuXSAGGkFBAiSJKFCACCABEI@@AUA@KC@AMB@TYGEGIIIIAI@MIIHEJAF@JFHAFADIDO@KDINDFFBFEJCL@FDDD@HCFYJQROBEAAKIGOGM@A@CHJL@FADGHQCCBEHBJADICKOGCA@EVBFDBDGD@LH@NPAD@APHDBBEJ@BD@HCHBBBAL@HVEBBFJ@DADDJGLJLBHCBICKF@BHJMFABJF@BM@AHKDJNELCBIGEACB@FMFO@GD[@EDKH@HIHQA@BHDDBK@EFBDL@@DADBBJA@ND@FEHB@B@DIDADJD@BcHEDEHCBE@MCCDGLC@GKKHG@"]],"encodeOffsets":[[[122174,40344]],[[122102,40323]],[[122088,40321]],[[122049,40294]],[[122031,40276]],[[121481,39982]],[[121479,39991]],[[121481,39985]],[[121465,39970]],[[121431,39949]],[[121423,39935]],[[121676,40071]],[[121616,39981]],[[121659,40047]],[[120361,40715]]]},"properties":{"cp":[118.175393,39.635113],"name":"唐山市","childNum":15}},{"id":"130300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@ERENBBDCHS@GAA"],["@@ABAL@DB@BABKAC"],["@@CBBBB@@C"],["@@EOGGOIAC@SDCojQtGXATD^@\\HTDT@TBZCFALBbBTFZAfIjATFABFBBHJHBFFDBFFC@AJFAGHAF@HCPDLJDCD@HCbEXMDCBE@ECQEE[GEEAIDO^QHIHUDCHEHAJ@JCFGNUAICIMKCEDK@GBE@CBGFE@OIMGMIcHOTU@GES@MBCHIRKDEFENaDAHA@CBCF@NGF@DGFCBQHIIIIC@CDC@CKEACDCCCGAAECG@IAC@CCCAGEABCDCF@FB@DNLBCNAHFH@DFHB@BDBDBNBFEHQCGh_VGHKHCFAHHCJXB@EFEDJFDNBDQHUBcBEHO@CCIHEFI@ICGGG@GW]MMACNKf[TE@AAAKGAIEGACFILE@CGC@AH@DIHD@@JABAD@CAAAF@@BJGACJBDAB@@BBEHDABB@FB@ALDABJBDHBBFCAD@DHGFCHD@APDBAAA@CFELKTG@AKIBC@@B@BECAAADAACCAGIC@@CCGNCBCC@BCCAJ@BCFGACDE@C@EdoBC@ESGG@QZMDKRCBICAQAAA@@XBBPFFJABC@CCIC@EA@S@EAGIKEY_CCGCsIqCGECBKAAGECmICM]AA@ERCDE@MCAADKACACCACBKHI@MCA@AFEAEAOKEICCKMKIGCAB@BLJ@BIC@FQCEFIACJC@BUA@OACREAAEEBCBKCICYQIIOYEQCYO[ACDABBJ@DADIH@DACCBECEDADBBCD@CCC@AA@CFGEGMAEFABDBEDUAADIB]IEBAAGBCA@BK@OAKE{gaaq[AG@EFG@GIIMAMDGAMIKMEKIgIS[UsUqħCK@GDG\\IPG^SHMDYEG@CBEC@KCKGSEG@UBMHKDWPCFKH[NEJQNO@YCKCIAKDOBWAWJKBY@Y@gFGFQFSBE@ECSUAGC@G@OFI@MDU@CDA@@CC@@FABOABJDHPLCTHBEBAB@DFBCHCB@FGBBDD@EB@AABG@ADACYBAFY@ADA@I@F@CABCA@@BC@BH@@CI@FIBADDB@BD@@BDCADFAB@IDBBAAG@@BF@@BM@@DD@@ANA@DIB@BLA@FHAZH@LcHABKBSAGBBHB@AFF@@BG@BHCDIAmIUAMGG@IDIFBNGJ@FKFI@@DA@AAA@BDGDI@@H@@ADABAFB@@DC@BDAB@BK@@HD@@FC@GTEJ@FJLBFst@BFD@JKZCAABC@CDA@GFFB@BG@ABC@@BDBA@@BE@ELDFA@ABC@BHEBAFA@CVA@AF@PIGCLEhCJEJ@LCDAJBDjNHFBBC^BBbDRFBD@BOLELD^R\\ZRBFGPHJFLHFLRDF@VFNAfFLBRHFL@JDBDDTJLDH@HCHDXEXBJDJBHCFGJULCBAFBdAhBBNDxnLDNAFDDFBLBJ@NFbA@ABGAABBFDBCB@BB@HAFLAXYPABDNKHKBOCG@UJUNEBI@MCG@OHOBWNiRMJGBE@IEMQYASCO@CBBNAFDF@HCDEBABC@ECEE@@ADAEBFAAADIDFAADIHKDIEC@m^SFURN\\aDIDCFEH@H@TLNLXDDFBXADDDHHVFHPFjfHJHRBLAXEJ]nGNGT@JDHHHJHPF`FHFHCF@FHBHFD@PLDBDABD@BFBDHBBDHBJNLJF@DCJEFGBGRIH@VDH@DCLBJB@FBBH@VAHBPNLBLJCFDNFPHD@HFDJB^ZRDHEFEZANFNEDFHFFFVFHHJCN@DCLCBCPCHCP@BBVDFDTGF@J@FBDBDFEJ@DAD@FED@FF@@FA@K@CAAFPBPBFDFADBH@FD@BBHDJHBFDLDN@PCFHJFDHHFJ@JAHHD@LJNFDDLFF@DAFBFEAILA@EAETELJJ@DBAHHDBBDFT@BBLBHCHBJBHBVPR@AUJGLDTNNBTGLCL@`BL@FAHGBE"]],"encodeOffsets":[[[122179,40370]],[[122181,40359]],[[122178,40352]],[[122098,41572]]]},"properties":{"cp":[119.586579,39.942531],"name":"秦皇岛市","childNum":4}},{"id":"130400","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@C@GD@BNpJ^@HCLCHQJELGFLnD@CB@@IB@A]@BFB@A@@DA@AAA@@@A@MBACE@@JCBAEOBACE@BAG@E@CMB@AAD@AQWB@DIB@CC@@BEBACGBAEE@@ECBACIB@BIDK@@DG@BBEB@DC@@CK@@CIBBDG@@BI@G@AIK@AGMBBLEBBFKB@BKDBDC@@BDDCBBDC@@BCBBDMD@DMBIMG@@ACA@EE@AGOBBFC@@BSBBFG@AEI@COSB@CG@@DmB@AA@@AKB@CM@AAEA@IA@@CKA@EE@@AGBACEB@FI@@DG@@CAA@DCAAI@BA@AAEFEA@AA@@CIBACABECEDEBDNDAD@@DFBADE@AB@H@@@HIB@@E@@BE@@DGB@FG@@FSB@CA@@D@@AACB@@CBBBIDEHQPcH[@SBQFMJKLOVKFODk@[FGJANGNUAKCMBMBCBQB@HGBAEMF@H@@@FA@@HA@@DC@@BEBABA@@NC@@FSBK@AOI@CDMDICACBCQ@CAQD@DMFSDGDEFUJGCCGEEECICGBGPOP@FO@ADG@EIBECEA@CGBGBAGOEACB@BQBEBGIC@CAC@BDEACDB@ABAA@CA@@B@@AAA@BFBAFFADBHA@@BA@DBDFBH@DIDI@BFA@C@CI@@@DC@EBCBAAADGDCA@DA@@BID@DC@@DIA@AA@CBAFA@BCEB@ABA@@E@@ABAAADAID@CBAC@@AA@GDICGBAC@DUBIF@AC@BAAEG@AEC@AACB@BABO@GBMHADCH@FQPADCAC@@BCDDFAFGACDNBJ@BDCD@BHDDDFABBHHEDAPCDIBKIMDSAACA@AJJLDH@NELIFK@GCAABGAEAAECMFGJ[PIBGAAGHSDAF@D@DFF@FCAIBCLADC@CACOACE@IFIAEWHGXILIHBHCHELMJG@MEACAEFGR@HC@ACC@EACGAWFE@GCAABECG@MCCgIEB@FOfSNCLADKDiCUECC@ODELCFC@CEAkJKAOCM@CBILKAENCFQFW@@DHJCFC@IIOBEBCDGNCBMAGAAEDGACEAEBGBADFHABC@@RCRGPMRKbIRwAUFUNSRKJQLKFWFo@MHELARANCBSDIJCBK@GAMGAB@DBFJBDB@LDD@RHL@D@B@JADBDDCD@@FABG@GHGAGBCB@JDDDAHGFBDDRHF@RED@FBJLBD@LANUZOTMHSASDGHDLHbANQLuD_HM@OLGLDPTZ`\\L`APQ@OE[GSDCPNRLTJLPLRFZGrILNBLLP\\HLDN@N@PITAVJdVZT^PRDR@PFCPIRFRJHDJO\\CNDVLJPRDNJLLFPDFGDAJCLDF@FGBMAM@KJAFA@EDEJAJBFFDNDDNBJI@GF@DLIJBHBDJAFCLBLJFPCZ[pBJJH@LCBECK@GHGXIRDJ^NDNFLRNHNTPPH`LnDRBdCNCJGJMNG`IhKLEHQn]XWJKJcBSPODIXQLETQXCr@TIb[ECAC@KKG@@BCRBRIBCVBJHTERAzBjFr@^AVDJD^TXBRE\\UD@H@PBHXDFD@BADGJCRA@EDBBA@BF@LELFXD\\A\\CtMB@BHBBFA@GFBB@BEHAT@BDHBPAJB@FFDF@P@@E@CJCL@DIHCzKTD|TNHDFAHDJ@P@BE@@DBHEBH@BJCHCBAHL@@FDDPA@FZAB@@JPA@CV@@CDAHBFHDDV@B@@AJ@FF@FPB@GX@@BFB@FJ@@DDBJ@DJF@B@DF@HVEXAD@HD@DPBDFCDBFFDF@BJF@@JX@BJH@BA@EFCHABGPADA@CL@@ENFHABBD@RULGFDN@JDDNF@BJJAFBDLNNLJPHCP@BDBJ@@DF@BB@FDBZABFFBJ@@EPCPA@DDDDBD@NGJ@H@PEHA@CCEAENA@DD@RCPCAENAB@BDFABDPB@FB@JABA@AX@DBHA@HDBDE@FDBJBBCJChP`@lIxHXHAABCHCBAD@@BD@@GF@@FD@HIBEHCJYMCQCGEBIJO\\UVINC\\BFDDBJA@OFCBUH@@AKICWK@GE@GDIDAFAZBBFDDlZRBPGbD^C`@VER@bL\\DZA_oGQ@OHQLWT[LeFAHHLADFDJF@HMH@BCACFE@CRAACJ@XQNErDpEpMRKMOE@C@AGHC@CCAG@AAEIHA@CCCAAKAAODABAAAKAAAACFGECBEE@AFIAIGUAAKKGECAG@GCG_GKE@CDG@IIGGQWSCCULCMQQNIMCECAG@GJ@L@@CAEIBCGKDCIAC@QESA]OQUMIKMC@D@@@HABCBGAIGAADCACNAGIBGHICKIKGB@DA@EIQDCKDA@E@BF@@CP@@GAGBCVA@CGCCCFM@EBAB@B@JLH@JECEFABBDA@AFA@CDA@CA@AAFAAGB@AEB@AGA@BA@AC@@AD@@GIBECCC@GCEIEEC@GRIPCVCPEPGLODKBkJKNOPMDSGKGEEIBOLCZJ`RhHPEBCGUFBCGDAAGDACGA@AEA@AEB@@CDAAARC@CF@AEB@@ELAACTCBDFCLFNA@EBA@AB@BCFA@GBBACDA@@C@@EAAABCEBAAGB@@AJCJ@ACD@@CBEAS@YFS@MESBKH_FmIBQFEHADAXABKBGAECAK@WACEAYBEAOQECIAEBCBE@@DA@@DCA@DDDFDEBBD@DA@@DCBDHC@CKA@ACAGC@A@@AHEACB@ACA@AC@EC@EKCAY@CACMCWEKGGaQKEC@OFSGIBKBIDIJKR@JDHFT@JAFED[FIFEDU^CHGZU^OJUJODSLEBOA@F@DF@EBL@K@AB@A@FEAAAA@@ED@@ACA@EC@@EEB@CC@AEEACAABACG@OCUDEDABBLEHGDMDeBICGCEECGG_ASACCAG@{PG@EAEEW[AE@EDQIgFSAIYSQG]BMHSEG@CAEGI@EAEGICCKWC"],"encodeOffsets":[[117679,36914]]},"properties":{"cp":[114.490686,36.612273],"name":"邯郸市","childNum":1}},{"id":"130500","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@QLoNoFqCMFWRI@BDQB@DEFBDADG@GNE@CICEKBGGEBKfS\\KXGR@PHR`pYB[CaKQ@UF_@]DaCOHQAkYCCAEYAEBCBCJ@HHFL@DXLJ@BG@AVED@PIBCAEC[AMDUJ[VIPAJHFRDNDIZGDAFGJC@@EE@@HC@@AC@ABGDADBBWGwGkJ_@gOIDADIACA@ECFCA@GGBCAW@@BABIBA@@EOAACEBACA@MBBFODQDC@@CMBBFDF@DGBOFG@I@MHC@CACC@COBOD@FI@EAAEYBCAAGE@@CI@CA@ADOOGKIMMCKEAIBAIE@CMAAGAM@ECKHQVC@AAGBME@FK@@DCBOBAHGBED@FABG@AIW@@IE@AIE@ECAEDCCEOA@CGCC@WBUF@GCEA@E@CII@CA@CI@@EEA@AW@@HOA@EEEI@@BA@U@CCEGGACB@DU@@DOB@IA@YB@EOBCC@EK@BGDADGAIG@FAAG@CF@@A@OCIBGCEMG{SSCyLGDCJK@ID@D@FO@E@EC@EIAOBGAACS@GBAFA@EA@HEBAAAGA@sN[D[BWCKEKFE@@AABCA@FQBIDCHABC@CEGWOAG@C@[VQFWA]SICUC]Bq@iEyAQBSFIGUAADQJQAAD@@LH@LBDFDa\\SJq@WDSRKFWRCJOPATIdILWXm^GRKFgL_JMHINIHMDIBYBE_KOGSOGLYNMTHRVXHJ@ZCJW@OFMLGNBJFNFNJJHPARK|LNZHN@VFRNPDX@JP@^btJJZJ`\\@^BNHNHHHRHbA\\DLLNXPlTRDPNFNARF^TpJJTRRJR@PFRVL@fFPDBDLDPCANJRHDDPLLVdNLRCBAHKHCFEB@BCB@DJAFDBHRJAB@HJFBH@LDDHGD@FNEDD@FKD@FDDLADH@DG@ODCF@D@BJGJAN@DDJCR@LEJID@HBHAHGLOB@HBJADCVADCFBLA@AFAH@BGF@DEJ@BDHCDETD@CHCBBCLBDDBDALHF@FD@BA@@BDCHG@AHEBFJDJEZDJDBJD@NHJ@@H@BH@DALEJCFJBHCF@JJBPB@DDDPLJFD@PJXBLBLBVHTHfXXJXDL@fGVGRIvQhGT@|Fn@\\F^JPHJJNRHPRvJNJJRFPAfEXCR@JDHB@DA@@BTAFCF@BBBHDAHFCRFPFDBFABBFFDF@FF@HFBBBHABBFJFCAJTCDFEHBFBAHLDLPBDAF@FLNABJDADBLN@FN@PGDB@FDB@@FLBB@JJ@LBJCZBBB@FDA@IHA@GN@LCBA@BP@PJFHFDDAHRF@BFHB@IFCVAFDDHF@FB@TE@CD@BH@FCBGH@JEL@D@DCAEAATKLFRF@D@@VDFDALA@AFFBET@LD@@FFB@\\BDLFHCHF@DJ@DA@DH@@VP@ADJ@@FV@HEBILABIF@B@@DRB@@AFFA@FJBB@BGE@ACBAF@@GD@@EDAJMC@BI@CUI@CBA@KBABKD@BHHCAADANABEDA@EDCH@BBTIBDJB@AJA@IDAR@DEFCH@DD@EPCBED@@GH@@EB@RA@GDAF[F@BCBABGDABABKF@@A@OBG@CECKABOFMAUUAMDUDSEOGOIKMEQAUACOCACG@@EG@ECBAD@JCBABGFBDAFICGDIBAB@DHDA@EUiHIPATDLDNFd^XHGhQPIVQJKZOJGJOHEHDBHGRDnJ@FOJMJEdGVCFEBSL@ACFA@GJB@EF@@EBAFBDA@GCBA@@GHBDDBJBB@ELAAG^E@CMBAGCAMBE@@FGBAEJEI@CBEEC@EFBFBBFB@LQAQHMBCE@AB@AGA@AIJ@@EN@FB@DB@F@@GMCCGJA@CD@DFJ@@C@@G@CC@CIAAABGXABVD@DEBEAGJADCEGYEKEQAoA]BOAKCIIEGBEXQUJGX[JQPQPIRC`CbCLAdK\\MLKPQHKDK@SHKLEhKbCL@NHLJRPNBCSOMKIDIPIbGN@NGBMMOREf@\\BNCFS@MZEVBXOFKZYNI^Q^@KOL[FGGOJi@QH[HOZSnQfQLMJK`m]EECMCGGAM@A@ACDMACG@@CDECEUKOBGIEGMKBIRGDEIABOFAHJHEBE@CScGGMEEKC@EFABGACEBEHGGG@ADE@CJB@KAAE@@A@II@EKE@ABBBCBIEIDBFEAISSESOKIEKMOAADGAEGIAIKIAE@EDIBKGI@IAEEEDA@A@EE@EB@FOEIFE@MEMCQICGAAMDOIICeM_GCCGIO@GJMJAABOQ@CDAJABMBEAACAQECKFCAACDIACC@OFI@GFE@QECCCGM@KCAA@MGQ"],"encodeOffsets":[[118246,37625]]},"properties":{"cp":[114.508851,37.0682],"name":"邢台市","childNum":1}},{"id":"130600","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@BE@E@@E@@KE@AKE@KGc@GBEAAGAAKBACO@BMBCECE@@EAAoJ@DEBC@@EGBGCEBAEE@AFC@CBMBBJ@BIBABKFA@@ECB@BE@@EF@@WAAW@AFADKBBDC@CAA@AAAMC@@MAAO@ADA@A@BECAeBAB@@F@@BC@@NFBAFE@ABBTAFDN@NaFBDKBAA@MDACK@IGGK@AAAB@BIBEMFBJABGAEYHKAAAAC_FUB[HCFYGAUGGIBKHB@CHSA@EGG@EH@DgFBF@BMH@@A@KCCIA[AADG@ACAGC@ACC@@GK@BQ@AD@BE@EMCGKQEUA@@BDADI@@@MCK@KECCACBGAAU@[HIDCDD\\ABIFIBCH@PH@IPORQHSOIMMKHECEAEDA@AECCQIIE@CSCBACAAKDM@EDAHG@@LMBBBI@EFAFEFaEOB]DkJULWNKNCJGJQ@KECCJKFE@EAGF@@MAASMKDIGC@DJIBCHMBaEOEIGCGODGFDNANADEAIBEHG@BDKABDmEEF[FG@EEGG@GI@@MBAACKC@BUBYDEFBNCF@FBHDFHBFHXF@LFRTFHD@BF@HXHBJA@@JTDLABIAGB@HED@HC@@HDJ@JADG@@JCHALBD@DEHK@GDADDB@DA@@D@DQBCFSREJIHYLAFG@@EA@@HA@GAAACACJ@FBDBABBBH@@@HCJCCEBGDAFBFGBCACM@CB@CO@@AQOA@TKFIFBN@DLAFBDDBJG@EHI`GJIFwJS@QASEWI]GGBQJ]CiSOKABIR[`CLSRMDCDCDQV@PGFC@CDENQZGFEHAFCHGJGPAP[EBACAEBGCKFSCEDEBOKGGCLBDFDJDLFNJFJ@HKPAFKNEDAJBXIBSHKLOVSPwXIHIDQHQKMAYJIJcGSGQGaIeDMD]\\QFK@¡OuKgGKAcKYK_@OCIBC@EFC@KCGEQIAABEAGCAODMGMBIFWC@CABEDABEH@H@DKBMCADALOBCBCDBDADA@YKEDEBCDBDABEBKIAAIACDEDIEG@UMABGJMBIHGJCHCDGDSAC@IDS@MBABFFAJ@FaTMJEHIHMFEDGFGFeAQHaR@VGT@RBRHL\\PHPCVi\\OBUFQHMJKLEJCLOLMP@xANE^ItDVPbNFHAhBpn`TVR\\TPHLNBNFNTFnIT@FPJNJTLNZNJCdGV@LLLlpV\\HPADIF]PmHABAB@BAH@HHD@AALAAGZKHO@KDOLSdATDRHXHVCJERMRANDRHZNPLFALBP@PJDDL@NAFARD^BHFJDHEHBFENCFCDDFDNDRCFBD@FBDDFJFHBDDDBDB@BFABBD@BDFJJBFAF@FADBFEPCFGDDNbxRR~KPFDCD@DB@DD@TADRAFBB@FDDLBJCJEB@BBBFHDDHBJABAHFHDJCHKHADKBGCIHG@CDCAIAIBUJADBBQJDFTFFJDBLLAFKDCLCBCLBHAFFFADHFFD@HCJCD@BHHBNB@D@BFTBBHABHFDBJCHDDABB@FBD@FFDHD@DJFBHKFEBCBFPANAL@PCLBXDP\\bRRFJLfDFAHBFEJ@JVFFAPLN@DBBB@BDFDB@NDDAJ@JADFFPVNFFF@PDJCLLJBHFH@JLRDJRHD@DERCDE@EPONAF@DACGBARCHCH@DBDHHHJb@HFPLLPCHO^AbFN@PF@LANBPHHPDdIfBPA`KRAfDVARGPaNEHFDRJNTJRXPLbZr\\ZTNDNBNAJBbTTDpGRVHRPRTJRDj@PAOXIJGPEJ@DCHGXMVGLBDBHJBXETDFR@VCbNbZHJDHLFBFFDFBDCHDHAdNJBNRDF@JHHNJBHJHHBBHjLHALDADEBEFCJGH@BDJJDFFFBDJCL@L@DBJDFFBDJPHDHDDFRCHBFEFFL@DRBX@PDNFDZJPNdL\\FBDHFDD@DBD@F@DDLAFELABCNEFCHADAF@REFKFE@ENGBCHAFCD@HCDEFCTOBCECEGCAAEGCAEBENARIF@AKKCBI@GMUIEBCDKF@TCHKJBHCNEBEPEFAJCHADCEGBIICCEIG@AEAOBIACCA@kGMIA@CBIJEDCDEB@DCAOFGCEIcQKAQHSGEKKADIHDHCAKDE@EHKLCHCF@LGDAF@HGFFX@HAHEF@@EGEAEFEAEBGBKDKAEEGF@HGDABCCCFCAACAA@DACA@AE@AABACCEA@CBACA@EAAJE@AQMACCCAGAA@CBCJDFCNAB@BFBBTAFEDIJA@CLAACBCCEBCBCCADA@IBCGEIGCG@IFQ@CACBAD@DD@BAD@BLDNHADBBFF@D@DLHLDB@LIFIPCFG@@DGLEACAEPCHBFADJHDNDABDDPAJBLFHAFGNAD@ABDDADFBJABGB@H@DDH@@AH@BDNHDHADBBADBBHKJEREHI@KJKBA@CAGBA@AFB@CB@C@FAAC@@@GBAEBCA@A@CEAFCHAN@AAD@DADDJC@AD@ABD@AAFIC@@AJCEAB@@GBEB@C@D@CAD@@BF@C@FAAHCBF@BCDBDA@BJC@BD@@CC@BADEAAA@HEFWBCFCBCA@FC@ABA@C@@@A@@D@BD@BDBDCFBF@BEFEDDEDBBCDJAJCBBRGLB\\AACF@@BCBABTCL@PCDDEB@BD@@DEBEC@DC@AFD@C@ABJBAFGBD@ADA@ALH@DHHB@L\\@DDD@BN@BHA@DD@@DF@@BLMHDBGL@@BB@@DTA@FHADHC@BBB@CBL@@LAB@DAAAJLBFADB@AD@AABABBHA@BCBH@DBA@DFCBFJBFA@DDMBBHEDBF@BDBBLDCF@DALA@CBALA@EDA@CDBBMF@@GJ@@EF@DCBB@IB@BEH@@CF@@ED@@FH@@DHA@HB@BDJ@BAB@@FF@ABCFDF@FA@@RB@@HDBBCLB@CHB@GB@AGB@DEF@AMHBJ@@AFBDBBJH@@BA@BHD@JCJB@CB@CMB@AEFABBD@DA@CFAÂF@FFCAHJG@IP@FFJB@GRA@CPBBFHADBBHB@@GB@@BD@@HB@@DB@@JDFDAACLB@AJ@ND@@J@@JH@HB@CL@@CF@@DF@@ED@@FB@@E@@BF@EB@@F@E@FDA@IF@@CB@BGZBJUDCB@PF@CCEL@DKF@BAACECFECABC@ADMAGACD@AGDBBACE@CEA@CFCCEG@CB@AIGGOMEBLEB@DQBIAABCE@CA@@GYC@@AIO@CC@OI@ACE@@KI@CAAACIUAIW@KCEQ[JACEF@@EQB@CBoCMCGEOCECAACECACAIBIH@@GDB@@DC@CD@@CCC@ABADABJBCHCDEH@DFJARBXABBL@BA@CJADBFD@HD@LALKP]DK@aGYAqB[AIMcOYEKBKJILBRIFMCUAYBQHULIJIQLABUJGHKHGpULIT[FMBICkD[B@PDF@IMA@AFE@AG[@GKAGTAACEBAA@AFA@AMFE@KWFA@EHCAEF@EILABDHAFDBFFBBACEBAB@HHLGLGCEHGACACCEGBCIGIIEAESJABDDKHEBAAKQ@aKEKEM@YMG@EC@C_GAFRF@XC@@HOAAKMAAYJ@@ECCiEqXIHiLGDEFABOG@CEAACGC]EBIB@EG@AB@DDDM]IDKwBMEEA@CA@KC[CMGEBGEEEBANEEGBAEIRE@ECWYVSACIKA@UDIAOGOMCEMEDA@II@BKE@EEHGEAEAECEE@CEBCIGEIB@CBAEGCAKBBEGA@GE@EC@ICEBAMC@GJIDMDCL@@CBAB@BDBIBBFIGA@GAAM@BYJAAMA@BCF@@IB@BDJ@GSPBEY@CD@DGBSCISABEeE@D@EJBHQFCDBHKBIAEAMAA@UACDIHMSCG@IMC@CE@CIAAAACBAECBGC@@CJA@EDCB@@EA@@A@KC@@DCB@ECBBDCEC@AD@AA@@BE@@EGBABAEEBAGaBGEKDABBHKDBBCDK@IM]BKED@BBZEB@ACHCRK@ACECAQB@DA@@@C@@BCBQDIDCB@CQDSBAFKBMBMCWMUUQYOK[CUIKMGKU[MKCURoNkAKGKaGCOE@@C"],"encodeOffsets":[[118483,39289]]},"properties":{"cp":[115.482331,38.867657],"name":"保定市","childNum":1}},{"id":"130700","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@JMLEBEHEBEJACEDA@EDADBAC@ALA@CFAAAFE@CDKGCBK@KFIEMDQAKRABCCEF@DMFCF@BFBA@EDBACFABEBAAAHCEE@GWA@CHALBDEDABEFEDB@DNBPWPo@QGA@AFKAE@CFCFGJA@CAA@CBAH@FCGCHIIAWB@AHA@AEA@ADIBEG@@CDA@ADABAAAIB@CBIPGBI@EEAAGDICQ@KVcBELQCEUQGSOAKKQAWKSFCAOB@GBCEGBAPAGEFABIPSNKLSHW@SIS@IJgFoAUE_@QEcKOUMEICEEEKEGGAEBMDEHATBDBPLNNHDpDbHPBCpB^DRB\\IHE\\KH@JBRHJJBDP@@RXB^ONCHDd@VI^IdATEVUAKBMAMpHXBZFJDJHHPAJBFAFARNPFDNFJ@JEXmLGFGTDj@rDXNYTgnT^@JBFJHDNMHgFKRONGBPVTNVFVARBXHZDXHxNhXjPDHDhFFDTH`TNNf^P@dFVJJJJFVH\\CHDLHDRHVPHNHJHJLHDN@fGRFHFBHARDLJHHBJ@JETEF@NDbRLJNR`BJ`ZRLBF@JEDELEFCTB\\F`THBPBZDHC@GBIHSJIL[\\qJMRODCDQLSLI`YHMDKBWBCJG@A@BAA@AD@@ALIECACFC@CDADIb@@L¦A]qAMEKQU[OMG]GMEso_WaQi]_OUKhEQFCBGKM@KTEr_`iBYL]BcAEEKAIFGTEJGLKDY@CDG@ENKXCFEHKDSJQDEFENClENCJELKLAXA|@PA\\MLGJCHEJCPO@KFAL@LIBEFC@EDETCGE@CCGDK@CIEICAMICCIBUL[@IJSTaZWRSBA@MWYEI@C@KDGHEHEN@JAFG@EAEBMCMU[JSPMRERKLE@GBCRIAQLIDILEDC@CFGWIMMECAGMCCGDKJADG@KNKJKBEBMAIDCLIHCNAh@RAJK@GFUPMNKRO@EEACGS@CCGAGGCIGEBQ@CAG@CLEDC@CFGD@DEJENEBCDADCBGJGFAFGFCBCJAHA@EDGNIFEDIDCBMFELCBCLGH@VCBIDABA@EAABCLEHEBAACDAH@FC@KDCAKLOAEGCGAGEQFG@ECKBMAEDK@CRMFGCCBGCIBCCGCG@ACEAQ@EAMDECKAMFIAABK@EBGAK@CAC@GCIKBE@EDE@ECAGHKBIFGJGAEBC@GECDC@@FEFAD@LEBCDAFE@ADCB@DE@CDKDCEGACEICBE@IIG@C@A@EAEFABCUKEG@ICCIEEDCCG@@EBC@COKKCAGKIBCIC@CEE@CCIGEACDC@ICG@EEGAKEK@EEASBMDCBKBC@EEBAA@EIEEACIACCKCCCBABKPMDEAAEA]AE@AFA@SEEESICCAKAAGAK@IEOAKGQCABAAGECDDF@FADCCADCCA@GGEAAADA@AGEEIC@CCAGQB@A@CACEBCAK@AAEBAJGJCNCJ@BMADF@DGDG@GDI@CAGDMBGDMAQHQ@CBCCACCAGGIEACCCCGGEEBCAKBCAIBAECAGAG@CAKBEDECIAUECGCOAC@ECEBICGKCE@KDKAGFI@KEOICGIAGIACAAICGBCA@CDE@EC@IIIOAGEABCIONQBFBBhBHALIHBHE@CGEACACBC@GEECACG@GFEF@HDBA@AC@CEBCB@@AEDC@AADEA@DEEBBCAABC@@EA@AAA@AD@AA@@FBDCD@@BB@DE@BHEDAFIP@BEEAA@@AD@BGF@BGFB@CB@DAD@@BNB@CJ@@I@FB@@GGAH@@AE@@AF@@CG@HAG@@@H@@AE@HADD@CC@@ADCJDFA@@HD@AD@@CJB@CD@@ALBDCbDDCNC@CBABGHKEEBEBEDADCACGC@AHG@AFBFABCFABGNCAC@CAACC@AB@BEHG@EAABA@EHBBCAADE@CHC@EJCAADID@DEHCECAEAAGCO@E@@CA@G@CAMDC@GAGEC@AAC@KI@ABCCCAICAIAIDGBBCACKIAEEEEIA@A@DICA@CFEGGE@CCAMEA@CAA@ECAM@QFACKELGCECGEGECBEDAFBBCEADC@AHIACBCCCKAWFDEACMJA@KF_@GHADWTED@RGCK@GAIUEAECIDEAAIGKBCHC@GIMCACCGCAAKEKBICOJKBKCI@JEN@BA@CE@IDOCCD@BEFC@ECEDE@EAGCaA@BEDSI@CEGDGCAK@IDCAG@CBCBICMFU@IG@MCBBECGBECGKAE@EBCHABCACCAAEAADE@GEE@AECADKAECAACKCECA@ADG@UCSKCEKCBCIK@CG@AEC@QIAA@AACGGGACESGO@AAE@CAAICGIICCEGBGFAFEACFOG@CDGAOICEECBACGA@AGCIBEFCCG@CCGFE@CBAECCGEAK[McIOCYMEOCW@QA@CEKFEAEDGEQCCCGOGCIEACEAI@C@KDKCIEAEEICCI@AHGDIFEFABCKCGBiKAGGAIGAGMIGG@ICEMQIAcMGBGCCDEAECAEKECGGIaYaMUDQ@CEFSAWGICAKAUHWNGHCDI@OFIHWJPOBi@QCSIOQGQQUoHSCaSIAMBMAMCYSq[aYOKQWSIIMCQGEMFObQHUBeCQB_LOBeAcJOCGGAOBM@KOEM@aE]BGPODKKEO@GIaGGEII@GDQDABDHCBE@MBOP@FCFQDAFC@SGCIKQ@IGI@DDLHPEJMHqSCGCA@EAAGDUACNGLAHAD@DABAFANCDAHKL[JMB_EQBKAM@KH[lGHMXCPDXAfBF~LVANCAI@AHDHG@AFCAABAHEFAVEHGHBFDDRDDD@DFD@BQZBJAND@IVOAIFCCSAC@G@aGY@OFICMGCBIAEDGBMCCAICGBDFAHBJGFKBGGIC[CQIO@SAEG@CDC@ACAELAJCBGAAFC@GF@BABC@EDCFAHDHFFVLNFDFHABD@DCHC@ADF@@DCDCCC@@FB@@DKJGCAHKQICQAGEIIQCHTOBQCG@G@CBIJMHIDU@EAIIC@YvCTIN@PBLBZIHGDIACDKBCCK@KF]DMFcFODCFSDG@QKQFGL@NLLLDdANBPHHFXTJPF^FF@DEbBHINHZDBTBNC\\GTIFI@GZ[@CAO@IROLBXPLDNBBBD@PBNH@XHLNPARKPKJGLGV@RERCBEXA@IXVL\\FFDFFHAFBDAHBFGFAN@@KCEBA\\GRD^ZFXBVCRATFDFB\\FTTZLBXCLCjCTD\\PPFNNBfIh@VDfNjJhRtr`V`jHZ@RIFUH_DOGICK@SDGDOLCJKNIFG@GAOIcIEGMGQEI@CBADG@@JCHE@EBOEGHI@KHCAGDE@cGG@GBIFCF@FIZWjANOT@DDHPJFFANABEBOF@DCH@HQCGDEH@DBBENDFLJAPJDHHADCHHHDLBTAJ@BNJJLAFCLBFCDGAGBK@KDABDDAFFJADFBCL@BLZBDADILKH[VG@ICGCS@WJAHEDCFEFG@ELPJ@FEHIH@DCLMTaREHELCPEJWVajKLGNMRWTINMJAFFFBJAD@PABAFBDAFE@IGIFAASIKHELIHCHGDKX@HSJ@DLLLJZHDJDJGJQHKDCF@FCDHDEFAH@LBFSXAZED@BH@HFVDCHOJMEeHQ@OLCHEFEACIAEA@EBEJKLKVA^CNSTMHxULKHc`gheXuZIHDJPF`CZBND\\TLRrzDLBNHJLDhClBZFVLRPFJHTBLAR@PLHHIHHDH@DADGFIJ@PCBMLEB@HABBDC@BBCFAAABC@@@AAABA@EAIC@EFA@ACA@C@IG@AECCBMAA@CIBIJBRS@BHCD@HDB@BI@@@LBAFGABBFB@LCLH@BHiP[EGJGCGH@DINCBADABAFADBDHDJAFHNFL@BB@FDHADGFBLDDFBFNJFBF@F@F@FABC@BHCD@BDB@DBBADFBABHFDHFADDGBABEBMAADA@[PTJ^DFJLLF\\HNFLHHHHRJdFJHDDALEV@NNNJLFFHBH^HJFJBFJXBHFLBBDFBDFDCJ@@@ABD@ABB@@BB@AB@BBBJGDA@AJAF@DADBFFFAH@@@@FB@FAH@FAFBDCFHH@JFF@DDJBPALEH@HDFGFAD@DANAM@AD@dENEJIN@TDBQbCV@HBJHBVZKVEDATDDPDnB{QZCFGJLJINFJRGTDIRHBILBFaZSRDB@DJHFRADQD@FCDHPQR@HDFAFFJPH@BJNNLjj`fT\\PNHJVREFCJ@DH@EBADBBJARAFAHBDDDDBFGBAFHDBFADEDHLDBDA@E@AHAFDBCDALFAFFFPBBCFCDAB@@DB@DCH@LELEH@LEJCRHjFLFH@BBbA@@CDBDJLB@BDDBDFTHPDFADB@FDDAHCBOTIDEAGFEBCDEL@FDDCDFBD@BBGDOHGHGD@BHB@BEFED@JPTL`NANGDB@FHBFFAFHTGFAHHFDFDLFF@H@B@JRHVFZJVNLFLBL@\\CNC`ObSLAdApTHBTADDJB^CDCDEBA^DV@DCBBBDDCD@V@BDRBPJFA@ND@@BLB@AD@@BH@Jd@@v@PA@CCC@CGABAD@"],"encodeOffsets":[[117582,43152]]},"properties":{"cp":[114.884091,40.811901],"name":"张家口市","childNum":1}},{"id":"130800","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@f@RTJBVXEHRF@HCJUXQHCF@DBHDJDBADC@ADFHRNJDJBLBdCJ@NFDJLAFEDCDARAHBDAFBHDABHDDFBHADHFHJ@BEDCHNPADCLHBFD@DDBBDAFDFPFBFCDABEBADHDBHFBBFTBfPPL`FVLFFLdFNFJNHVHJBJCVBXF\\DRIJKNE^EJGBEE]QUEC[M@GNKRCXBJAJCH@VD`JXNNNJTLNHBFBNDTEJEFGNWHIBEPWFEVKLCZBRBJBTHPBbGlCJ@NNHLTHRBXCRBJEALFDCRfNP@HLFdNLCNIRGRCJ@LBNFHFFHHXNJJ@NALGHA^FFFRZ@PCHD`DNRjBJARBLEHG^MTQDGDCPGHQjqCLDPARGJ@j@ZAP@bCFAJATBLEL@NDDDHNBLBT@ZMd@RARKZOhARCjGPIfD\\ZdKHB@BBBAD@@DLBF@@@BAFBBB@BA@ADA@FFDJHABBD@DDD@BBBABD@BD@ABHA@DBA@B@BD@BADBDFD@ABDBBABBHABDJD@BFBBBBABBFABBAFB@BABB@FDBBCDDDBACB@@AD@@DDCDDBABBDAH@@ADABBFA@BDB@C@@BB@BH@ADDBBBADBAD@@B@ADBABDBADBB@DDD@HCFLDBFFF@AJBHBFAD@BDJ@BADA@BNABAAAB@BBB@@@F@BB@DDCFB@BJA@BC@BD@@D@BADDJ@BAN@CDFDDABBEDFD@BDBCBFFBHFBDFFABDABB@NC@@F@AEBADDDGF@AAFA@BD@DCDA@DDCBDF@D@CABCFB@CDBDAA@@AD@JDJABBD@@AFB@CDCDBBAPB@AJ@BBJBDGJDFABDH@DAHBDB@BB@F@ACBAB@@BBBBA@BJDABDDLBN@NAF@BAHAHFHCBBB@H@@BBBBCD@BBBAD@DDDABDBABB@DF@DDDA@BDA@DD@DADADBFCDBDABALA@CB@@BBA@AHA@ADAFBD@B@HAAADBBA@AL@BCF@@ADA@AB@@ADCFD@CBABBF@BBB@BATAJBDAFB@AF@HBHALB@AFBDADDP@FDFB@BPBRHANAFBD@JFJ@BDBADBHEJDNAFCFKDSCUALHDH@JDHAFJDBBLHJDLHH@NJHDDHADLLFD@HDD@DMFEJJ@`HFFDJHFTDTANGfBNDIGDCJ@DCHABANAGDNH@HFHDDXJNG|AZCVUEpMZFF@HEjLbRJBPHpPhRJBPALIFAGMGEAIBIHOJKNGNALGPKhePMNULWJMDCXSRKdYTKJIVM^cVONGta\\WJIFILSAOEKOOGKAKBKNYRSHITMbOJKGOGIIIMIcQOCQCwUOICC@GDILMfG\\KNGHE\\]TGREOLEVQFMEUCKIMEICKIOAMFMFEHC\\ErO\\OJI@WAECCEAGBEBE@@GDIACECMECBOCIGAGDGFELCbA@ZAJBVFTVL\\CPIPANRNLDZFZCRK@FD@PGBCAIHGJGACBCF@BCRCHGBGACBC@CSM@ABGCEGCIEUCwCCCFGJCVMJAfBNCBAJ@FEBCAGFAFGFEF@NEAGGEEM@SFCBCCA@CEAAEIEDEJG@GQCSGMAGCOACQCA@@LAACTGDCH@HCDAAEF@NKBCFERGVUH@NEHGDAACAEAAACCAFS@ICGGIWQGKIUEYEICKUeIGIEWGUD[TGJCLBTAHIRIJWFYASAeDYCSKSWEOEGC[OwFSDEFEVIFEFM@cAGBGLQACTKLAXIRIVQPQBG@IK_BMDOFOLKTMZIxGNKBEF@XAJHFDLADEFBBKACGAIK@K@IFGDMFEJSBEAEUYGGEIAECEGA]AICCC@GDG\\E^OjMLERQPKLO@IAKG[@CDGZKFIACEEIGIIBDI^_^SHCJAVDJFHJDD@NDHdNzHJDTBb@PBF@PDVLRBHAHCHAX@VDNBV@XGNAE`DRDPB^ATIPMlOtM\\DJBFDHPFbFDnHfNbJNFLBFABC@CAEKUDGFSp{RMNGNCLBL@dF^@FDHDHNHFHAVOVEX@hBJApOVAbCTBP@\\EJfCTBPAXGpSF@NDFJBPAPDFXJT@LD@UBILM@CDCBIAMKM@CCCABIEDCGG@AAAY@BCABCIAEB@AA@CM@BI@MDECAAEIEMAyBGEAC@EDCRELEHGHK@GCKEIIIGCaMMKOUOOSMMAUB[AMAMIAEAS@QB[CMII[MG@IFIAGGCIEGGCIA@DCBFD@DCAEAMAKBAAIFK@QHE@EFI@KCIBCDGBCGEEAEICIEEMIGAAEADOEMHG@CBC@CFCDALKREI\\GFCFGBGIKSOAGEOAIQ@IAMEBCCBCABC@@CBA@B@BCGAAFKACBACGBUCSDA@BFABODACSHEFBCEEYG@EEK@EDEC@A@DGEIEMBKAAKBEABCBIDE@EBCAC@CBCD@CC@GCGDICEAGECDGACAECE@CAAAGEAGG@CCEDC@CKAOKG@AABECGAAAA@ICEGAAQHYZDBIFGD@BCF@JCBCBIDCHA@FDAHGFAPHTIEA@KIG@IECE@CCBGXFVCHEHADBLAJAJ@FCF@LI@GFM@EDAACDKJEBCNGHEHCHGB@BID@BBDBFAFEF@HGFA@CHCDBLHP@DARIBCTEFMAGDED@AEH@JCNPNDJAFAVMJARDLD\\PTH`VXHVERSBIMWKQQIGGOKACICCC@CFCBELE@IHA@GS@SOGAIAGAGDKAAAS@CEAAGCBGCAI@KISFBF@FKBBJEFEACBE@KECCMEKIC@GGIBI@GECGIEEGWDKAKEGCEO@AECG@CAEBECaCDEDBL@B@@EE@@EFC@EBC@CFICECAEAI@E@SHECUCAAO@GDODADKDCDM@IDGGUEEEGECEMFMEYBEFGFQC]YIAEC@GGCEOCMDEKIKAOMGAUBG@AA@EIAKACDG@UCG@QJAHEHIFCDE@KIIMGAACGAACAEC@BAACKC@OECAGEGE@GDGE_EOEIGGGCG@IHSHM^mFIBWAKGQGIieOEEGGUCGCCWBEACCKWKMIDOAGBABAFCB[FCFBLA\\DXLVAfHDDAD@HAD@BDBJFDARKNHHJLBHJDDDDH@FCFHD@@U@EDG@GJCBQOUKICiEsHOJWDiEM@QFOFWAMRALAHCBCBE@_MO@EACBAJC@UE_CCCAMAAUBICG@yLEJCLCDGBKLDNCHOJYHA@@A@KEGMCG@E@IIMCKC[WKCSAEIIBGBOCAC@KEKBAXOAGKGOGGEIKMGKQAIGKECGASBWAKDKEI@C@EECeCIMKCCaMMKECKEOAKCOGICMBUD_CKGQOGACBENABUIoDCAGCASACEAI@ODGEiAECIGMAIAUFCAGESAC@KFC@SOSGOGCCCAIDGAIEUWCAOH_FYLCAKGE@KDGAOUMGCCkKCAIMECY@QDGAIGKE@IOEQBSFOEABCBABBJABIHE@CBDDBFBDFBFJADCDBDC@D@KHSBACC@CDA@@FC@MCE@CAI@IAABE@MCM@EAIHC@MDC@ABGBAJCDI@CAAFKBCDGDG@MHE@@BQ@ACECAAGCC@CDC@E@CBCAC@EIDEBGAACBEGCABBA@CAACCB@FIBEA@ACEECEAGBCDC@EBCDCAEDCAK@KEGAAFEFE@@DCLEHDTEF@DCDBFCF@PCJ@HEHEACEEAG@@@E@@EABCEE@CAIAADOCAHCD@FBB@DBB@DAB@FGFCFE@ULBLEH@DBFCFDFBBBFABGBCBK@CBBDGHAFCL@FABBFCBE@CJADEBAFKBCAEBCCG@CF@HFHABDJPJBHH@AHEFAFDFCH@FABAFLFDFDAFJHBBFNJFHFDA@IBKF@JKDEFG@GDELDDB@BHIBGFCF@FDFUZI@GD@HLNC@BJJDNCJAHFF@BDDBJCFEPFJCF@BHEDELEFAHCJIHBBDB@B@DAB@DFBDDD@FDLJHDJBDAF@PJNBHDDABDHDBDDBJHD@BBF@BA@ANDHEJBDDNFF@DADDBCDCF@@ALCH@BEFA@CF@AABAF@@CDCH@DCF@BAD@BFFFPFBFDDHEH@DCDBHCDBRL@HGBEBERBFEDAHEDCHDF@DDBFLHDBB@JGJBLHFD@DAAABCACHEEAFAACP@DBBDNA@BADHDBJAFBDB@CJDDFA@BMDABJBR@B@@ACAFCF@@BHCBEHAAGFIN@BCJFT@BB@FADDDFFELVFBH@BIHMJCBABGFUFEDACIACAC@AAGAE@KFI@@BK@CAG@CF@FEDGEMHI@EDIAGBWEG@CAIBECKEMBGEEAICcAACECCCBEAAC@ECIAKCEACBE@uDIFEBABBDABIDILMJC@EC]EMHCH]LADM@EFC@EBKAGDOACDAAAEGAOLC@EBCCC@CCKBGDMCG@EDE@GDG@E@IAAD@BEDAFABEAE@EAMAAAOEIBIEGDKAEBK@ECUBECIAAEIEEFO@ABKCMBEDYJEDOACBADOBADEBDJGHEB@DGBADG@QLAD@JAFIBABGFI@@DEL@BF@DFKZ@BFD@BGBaFK@GHE@AFD@DC@BBHAHBBBJABMBCBAFGBCBDJAHBBCFGD@DCBI@EDKDBD@BGJCDG@EBAFO@EFCAGBGAC@CB@DCDADO@CACEEEC@CBAFBLEBAD@BCBBHAFKFAFGBIJAFEBI@EJMEEBAB@HBHGBI@GFE@GFCACDK@GF@FCB@DMHG@@HDDDJJLIDE@EFBFIAIDAJIFGLGBBDAJCB@JGDKLBJDDBFHDEFBHAJB@@LBBDBJJBDCFDBFBHNEL@HADGJBFEHEAECC@GBCFCBCAMBOJ@DCFGDC@CBGBCCGFAAKBKKQCDA@ECGAAAG@E@CHAFGBA@A@IAADCAC@EEE@CCC@CCI@CFCCO@GAC@CSIECGAMDE@EFEBGHGDABIHKDC@CIGAO@IFMCCEKGEAIBAGEEG@GBG@ODE@OJECC@ECEAABCDGBABEDECKC@GCC@ECCDKCCCICGNGBGNQAILABKJKBKFMACDCCECC@CS@CFCBSBCAWAKJMCIBKEQLK@CFAFIFKPALEDCFBFCBCFKHKAQRMLONEV@HILQBg@MBGDKJCDBJANAFILML@LCHIBCLDHNDBHFDNNXJEH@DCDKFCJKJBRQJAD@HKFQLQFONITV\\DNANBF@FEHIBM@GFGFCH@L@DFJXZ@NABQTYXSbIT@JK\\AVDJJDBNJDJF@DCLDH@DHFSDCF@FEDAFKJK@EB@LOPIDGFIDKH[NOB{@WBKBKLIFMDkFMDEFCFIRCTGLEFWDML@FCH@DCZKLIHSFEHBJFLBFAdK^AZ_jq`SF@LLNAHEDFRg VL`Pj^bR`XtpNF^HNH\\PRVFLBNXh"],"encodeOffsets":[[118867,42780]]},"properties":{"cp":[117.939152,40.976204],"name":"承德市","childNum":1}},{"id":"130900","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@RBBAFAL@ACH@BBF@@JB@@DD@@CA@B@@A@BDA@F`CdA@CD@BBF@pADFNBDOAOD@EOA@ACD@AELAAEHAEMBACEDABGACAA@AF@@SDA@ATABBNAB@@CD@@FJBNFPFHAGOTB@NDBDC^@BDHBGBJ@LCGVCV@BLB@@JvLFAGGBCEIAMNJAK@ARBDAACRA@EJ@MMIg@QICBCFB@EL@AGH@LeDS^A@GB@@CT@@IGA@CDB@ED@BGXC@JT@ADDJD@ADDABFXADBAFBBTF@FFAANA@DDL@@CD@@FD@DA@AFB@EB@THBABBL@AFD@BIFB@HR@BFD@@EDF@DB@@FNBFTBBDDD@DBJ@JA@A@MGAAGXBAA@AIKH@BGBB@ATA@AD@NEBAC@BA@ADGD@@IGABGUEOUA@DGnLBEgIE@JWD@NUTLDIPB@BhFATH@J@HMBQFAPFRL@BPB@C\\BBGF@BJNJET\\D@cxT\\VI@GFRLLGNJTLTF@BCFDFABDELbCRDDAAED@DAFBJGFB@FD@DEAGH@@A@AEC@CF@^FELHDDJFBFAH@HErJ´PJgBYMq@sDaPgQRGLMFQFo¦©rMBrJzNR\\GPOA]Q_mimuGKCKOQoeaQAE@MCAQYAEDI@CEQGGLILA@CICCGIDIAGBCAAEAAE@CDGGAGFMDO@IAICCOC]IECY_C[CESKQOGCO@cHKAECGGEAeBsGE@WHcAGAMKWACCBGAAEAGBDICA@CA@@AFA@AA@@ED@@CBAIKQOCIAOckCMGkQmEG_UWY[oy_MQCOCKDeTcAKDULGBK@iCcSYEaOMC±JMDaJQEMKGAWASB¡RM@]@UCICQGABMCDECACFEA@AAAAA@CQAcBPuCNE}OKAMBSLM@@FMAAJMB@BC@CEM@BAAAAACBACC@CEB@EAF@@CD@EKA@@CBAAABAg_OQC@CCCDAAA@EAA@@HA@AIA@@AD@AEHCH@AIFACaA@CMEIECABCAA@C@CB@BK@DDGBBFMDAEEB@AF@ACC@AGH@EEBEL@@AI@@AB@ACBCDC]SABC@ABBB@DE@@D@@CEAB@AC@@CD@BAGCDESE@DMCG@BEAAADACCABAAAG[QkEGKICDKEBHG@@DC@ACC@CGDA@EH@GIFAU[oqHEGCCDMIcOKEIKABOGCEABCCHABDFCMMYOACAKAEECYIKGEEQ[SMKIOQGC_CQIGGKSMkCEGEMJONILQ^GJYLKPECBBEAGBDBI@@DEBBDABDDEDFH@@HHJFADC@@VC@@@ABD@@FHAABB@@DWFDFKDGKGBEICBDFSBDJE@BDA@ADGD@HCBE@DJ@^BRhHXBTJFNANDTI@ONDRfvTl`bJN\\ZHTPNVJLVFFPAB@BBCLFHCJFFENCBG@ABJHHBADEHV^AHGBDNEFJLABIBCFBVFBVMB@@HBBREHFREFB@BONDBHDFDCNFP@FDDNFFDEF@DLBHDCNBBJFBBAHBJBBHDDBANNPFXFHBLFLHLCHDH@XCZBBANa@GAIBAASAKAADI@CAACMBBDGAAEC@ACCBEDAFGBCBBHEBAACGBEAC@AC@AGKBABBHBB@DMHAMACA@@AoCoESBOF{Lg@MCWMIEIKMWQU_S[MQCSAKFMAEIcIK@KFUP_L_GYEGMKSGg@]E]@@JFNHJB@BBB@@AFBDFBFLJB@DNBBH@@B@BK@OBKACDURU^KLKVG^INOLIL@LJRDABBHC@CNALDABFJIFEAEBCDBFMFC@@FFADF@^OBABDHI@BFM@@DK@DH@FEFADBJHHPLLJJRDR@FABG@BHCNC@UIIBCAIISBIAOMOABDC@MIKDEDCFC@AHAEC@@FD@CB@BA@O@@DMB@BC@[DCF@HBB@HEXcAEFBCA@BGKAEC@AKAABANI@ADKFDNDFJDFHBbWBBJIB@JEBSBBVG@ELIBBJIBADDFD@DBFN@DIFCFG@@HGBEF@DQBABCJBBF@@DE@BPKB@HC@BDD@BFFA@DDDH@BJBDLB@JCJCAABADH^D@@BIBBFE@BHE@@DWBCCYBECOBSJGHMH}HAHBJABE@AAI@IAAICACIEAG@GDK@EDGB@DADABE@@DF@DPbHHLBLMlQpDVNLV\\HLLNVJ\\DPLRZJLLJXNNDZCBETARC@DDAJCRCDA@AD@@@B@@CRADBDF@BQLGDBDA@YFAAC@LF^AJNL@DCAALCAGBALCHFbABHFABFBAHA@FF@@AB@@BBCD@DFACDA@FDA@CD@@L@BB@@FA@CD@FIB@DD@AHFDABBDBBJB@DDFD@JNH@TDGNCJBD@VBBBNBFAJGLCAEDGRIA@F@CfFAFTBDJATCHC@@DFZOAHTI@ACA@@JE@ADB@BNIBAZN@BB@HHBEJAAAJACA@AB@DK@CDCNIJ@HNDABDF@JFDF@@HHBAFLADBFHAB@DJAHFDJFA@DFFFDFBFBGHFFF@ALJ@@JCBNFDFPNPHJBVCB@JLBDUTZDX@FQFFJABFHMFABFFHFFANH\\DLDB@@DFBNFxACL^JCNCCA@@BFHA@AJ^FHDBDFB@DPHBAFEHCjKJGrWE@@MEAGDAEHE@OFA@OECAABEHCDSACHABA@ANBBGXHJOF@DCFAHAAUDELE`GDBDC@AHA@CEMLADECEAAMDCIfIj@RA@CB@BDbGhOVElMXGPI\\UR]F[BQEMSWMISKQESCcKGO@WHUBYDOLeFGPOLGpQJGFGCGBAzKMYPS@CMBUEACI@AAAGFCCC@GJAAICE@CDABDB@DHTBH@AEC@@CNAGUE@@ID@@GHAAEDCDBNCAEBKJ@FAFDJGHAdAFAHA@B@BTA\\HLHZDPAJI@CEIHCB@@CEA@CNMDA@BH@@AD@H@ABAJD@BFD@@EB@D@@FH@AJNF@GJ@@EFB@CLBAEH@@GNB@FI@@LCBB@BFEDB@@DHADB@@DHBAFHDH[DDLF@FJR@CIT@BCF@JABHJ@@DFDAJJ@DNFDHDBF@LJD@FCFCAIAAFIBCBADG@AJCDA@CIEBDJIC@HD@@HXABDH@BDVABED@IRE@@HDFKDABFJHJLBLAPVOFRHDFBBDBBACCBCRRZSDBHFHB@ARBHJCFLBCF@FB@EFJ@BFXD@CJBFA@IDA@JAFHDDLBBFNBNALKTERB@AFHB@LMF@JIDBBGEA@@DQ@BFRABHNB@LFBBH@D@FGAAFBBEHBBHBADD@@FB@@F@@"],"encodeOffsets":[[119569,39672]]},"properties":{"cp":[116.857461,38.310582],"name":"沧州市","childNum":1}},{"id":"131000","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@ADC@@BSCABCABAA@CFLDCDDBGJA@EBDBAHA@BLADB@ADC@CDDDBFD@@DN@LB@BFBABTFJA@JG@@DC@@FHBEFDBCDA@@BA@@FC@@D@@@FKACFFBAHJDDDDIFA@BDBCDPHINJJZBJ@HEF@@AHBCNHBDA@DAFCBYDADA@@BB@CJP@ADEDQLCDBPE^INGJMHCA@AKAAA@GLQ@CAACAIBIFCBAFMLCBI@@EIB@AC@KD@FQDCLA@AHK@EDIJEAGJIPEBO@AFE@ARGA@GG@@ME@MFOLCH@VERBR@RBPAXCDcLIHAHBJJHFHBLPVBJ@LGJCFLV@F@BDB@LHDJ@H@ACVGFFPABD@CF@@CJ@@DDAAF@ND@@NRD@FdBBFPECCJANOF@@@JBJHFANBDC@DTBNL@AL@BGBBDIBB@BJBBHD@ADB@BCB@AHD@DEF@BCFB@CE@@AF@AABAFDB@BGB@@H@@@M`TD@@@D@BGHBDGB@@AC@@GAADEBBLDP@NCPG@EVB@DF@@CF@BBFBBEF@AHJ@CJLHLNJDBANB@BDBBDC@@JFA@DLABDF@ABNBAHD@RB@GD@BHD@@LX@BBFBFACEFDAAFCPBFCDDLGFENCH@HDJ@RHHLGFJCFA@BJCFABAD@@AJA@AHD@FDB@BGDADHF@B@BJEAA@ADGBGDCJAACBADDJB@FDDBDI@@FHFHADCDKJE@AFE@AGCIBEACDECE@ABSDAE@EEBAACBCBCGDGACFCFGCABAAQ@CBC@MBCF@DCAIFIACDBBAAC@GA@DG@OA@@CGABEE@@IA@@CC@@ASCBKAADAAGEKC@CHA@E@C@IFAAHC@ABA@GBECEKAIEEEGFACDCF@FCFGBCECEDC@GE@CDIDCMCMA@ALCFOF@P@FA@EACMECAACBETMEGAGCE@EJFJCDGF@DD@FB@HC@COIDCN@BB@DDBFCAEBCF@DFB@NKF@FBPCH@BGJBF@PGB@DHLAB@BHBBP@HEBEFIDCFIAAG@@CCCDC@AGCBAH@BEkHQCEEGA@FODGAAHMEADOAFOEAADoE@IIAGH@CA@@CA@JUI@BUHB@BB@FCDFHBBEF@BCF@BYDA@AFCPGHED@@CBALIGGG@@AEBCIK@CGW@KCEBCAAA@CJQAAID@CMAACB@BCCCFAEKL@AAF@@AHABCBB@FDABGG@@ACABGDB@BF@BIC@@GDB@AC@@AFCAEAABQA@BCE@F[G@@GC@@EI@@EA@@CDA@CB@@BD@AGBC@@@CFB@AF@@GDALABEG@@CA@AGSAI@EIGAACHCCABCMABAAAK@GEUHAABEH@@AC@KBAHBCGA@DIB@FGB@E@@AFI@@DEBBBYHSJkNaFOFaF@CIA@EEBAEE@@C]EDCC@ABWGEBADD@@LCFEBKKCBEHCFCPDPWH@LJBBBMNADBHCHDBHNB@DEB@CNY@CEA@ADAAAD_@@E@@@GFC@CGFEABCC@BMMA"],["@@FICAFGGADIK@AFDBC@@BHBAFGC@AKC@ABBBAF@BAC@AADA@AA@F@BCEAADAA@AABCAADA@BEA@@ADKCBDEB@DEDADEDBFGG@BEA@@CWGDAAADAC@C@BACAB@GEBGE@ACA@@CA@BGFB@ED@BAD@BGB@BIH@BKHCRB@AH@AHFDBCFKEBH]A@@ASCD@G@DSCD@CE@@AJ@@EB@BABMFCA@@IE@FAEACDE@@CC@@CYEBCM@@AG@BEE@@ADAE@AALABIFBBEBB@CD@@MKFHMD@ADFBNG@BHBAH@ALBZK@ACBBKA@@AHCDCPJ@CFB@@BBFA@BB@ABRDDEJELD@CNEIMKFCADGGA@CEACA@CC@AAAABAA@@COAADEABEE@BKICAGDCDBBEC@@CFB@CAA@CBA@AA@FKA@DKA@AFEA@E[C@BK@BEB@BCA@BCD@@AD@DCPDBAB@@AGABCIA@CK@@EBCBBH[BA@A\\DHHDIPNABD@@DH@ADA@AJBB@ELBJFBCF@DEG@@CA@BEEAB@DKB@@DDGLBJEFBBGA@BCE@DS@GCII@DQA@@AEAADWEAA@EGA@IHB@ELBDQDYIAN[ECBYF@DCHD@EB@@ILCCGF@@EI@ACEAAJA@AB@AA@AHEBCADIAA@OG@@B_CBSH@DG@@@_B@BGCMFCAEDGAQBAEEFDFCrBdIAEFA@EB@@CBEH@H]I@BGN@E@GUKDGF@@FEC@AOEBG[KBEME@IME@CKGBOEHSG@DKWABEeA@HC@@GQ@ICIABDA@CAAA@JI@AAA@@BE@AAKB@DE@EBGA@AI@@CA@@CC@@DA@@BD@AB@AA@ADD@@FFBHABBHABJSDAGIAACACDAEGGBCEWFI@IW@C@A@AF@BCHA@WAAE@@KB@CSC@CSCDAICBCMEGK@@EIEA@GQC@ASG[A@AGK@@MC@@\\@BnACWAIB@@EHADBD@CME@CSKOJCEKLAAEGBGWJA@ERAMwB@BDJB@CPBBCA@@AB@BAD@@GF@@I@@@EA@@EC@BCGAAAFGAABEHB@E@CAGEA@KMAAGQBAER@@CB@HFAAJC@INE@KGABEA@FQLSBKAMEMAACKGCBE@ICB@JEBIA@DWCAEI@FEA@@EDEKADEGIQA@BGAGECAYTQQADDDABCAAACEQGPEOUKBKAGIEIBALCCE@GF@JQC@AFUBACG@ACWB@GC@@GJDCIFADJB@DCBIH@BCDAJABEJBDBDE@EIC@KAEGCECCMI@BIEC@CI@AGIBE@ADS@DJQ@EIE@CK\\CCGEGABCG@@CAGB@CA@FCAEA@DA@KJ@@EMA@HG@BFKA@DEA@FI@@HMEBIG@@EC@A@@FC@AEC@BIBAG@C@@BG@@ACBMN@DFB@DA@GDFJ@DIJOBYCKG[GSB@A@AGBEBcBGBIHECEBI@ALBFMDCACDBFGB@HC@@JF@HVMB@DD@BFG@SACGA@ACCB@DDFBJIB@HDDEDBHBBJ@BDVFNA@DOTNZyLABDHEHIHoRKHOPEHKfCPAZGV@XHPdLTDRFTLNJTXFNARE\\Q^[VOJWHkNUFgPaHACA@@DQBi@eJDJNCBBDFCFKBFN@DGB@BCDCA_HKFCFBVGBEBCDE@IPWGAHMA@BABGBBDCTGDAFBBFD@PEB@PGFBFHCFB@NpFDD@FI@BZNBBLPB@GD@@WQEBE`H@DFDH@ZNN@LFLF@bLRBBFALGCCBATIBFJFHJDJFADBFLGHDFWPGGA@ABDFABEAAEECGBACKBFJE@BFGD@FEBLXF@NE@BEB@BBBFABDSBBHHL\\@BHF@BEB@JNE@OCA@C\\D`AVENS\\KJoVGHGLIHAVKBRIJKJGVARBZDVENQJKAIJALFLPZNdBJA\\@bBPHZ@bCLO^KLEBI@@GECCAIB@DABK@AAWBQAIBCEG@CFGDADAICBAB@BDD@DC@@DCD@@CA@HG@ARDFFD@BFDDFFPDHDNAp@DRA@FE@DFIBR\\DF@LJXVBDJBBDBJ@@LF@BDJ@@PDDP@BJ@@ZD@HB@@DDFBAJBRA@CFAAKNFHPJJDAH@BCPIDCDEBIFALERAHIF@BHD@AABANATCF@DE@CLGBGLG@EBCHCBEFEPGJAF@BCJABFVABB@EJ@@AL@^AHDHAHCRBJCVCTGFFJ@@BF@@BLB@HDBD@DF@DEAIPAJB@@LCFE@DAC@@HG@ABE@@AA@@AA@BCC@BAIA@AA@AFC@@B@BDB@AF@ENIGSCAFB@ABDB@DDADPDBH@ITGAAFI@@DC@BDC@@BEB@VAFH@BACAN@@AT@BCD@@IB@@ACABMPBBEVFAF@FE@AFDBAFC@AFHBZ@@DL@@CJB@HH@@DBBF@@BB@@@H@@ABBCFFBAHCDA@@DBBABC@CJD@@AR@@APB@EH@@AD@@BJBFAJBAJB@@HD@@FD@AFPBAFF@ADPBCJK@@HDBBB@FA@AHD@AFFB@DFB@DF@@CJA@AJABA@HB@AF@@ABFBABDBBE@CC@BEB@H@@BJBABHB@BJB@BJBABB@AFD@CFHBAB@BA@@DC@@HF@@BVA@HL@E@LCBCFDBCADBED@@ADBA@HBAFF@@DL@@IHABIH@@MH@@IF@@AJA@ANB@JF@@CHB@BBEF@BEFBAHB@@GH@BAFDADB@HBBBF@J@@CTC@AB@@BB@BEDB@BH@@CJHFMD@DGB@BCFAL@@@HB@BFBDAB@ABFB@BBAAFB@BEDB@DAF@@@ECFBEAFC@@BGBF@@@EB@DA@CB@AA@AFGDE@GF@@D@AFA@CNJB@EFBDCJDBDL@@DFBDCF@BED@@CJ@@CLB@DBBFABBFAFAPGFEJE@CHABKFE@ED@J@@BBB@BJ@@BA@@LFACJB@ADADZBADRBDB"]],"encodeOffsets":[[[119712,40641]],[[119616,40567]]]},"properties":{"cp":[116.704441,39.523927],"name":"廊坊市","childNum":2}},{"id":"131100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@J@BCAC@@VBRFHLND@FAFC@@BARL@@HD@BDD@BHBDH@BC\\BJBDD@L@BG@ANE@EAChG@@FHH@FTBDGA@LGJAHHBVZHDE\\GVA`EBDBBLBZGBFAHIBEAFNJA@ABABBL@HH@JDLCB@NBBLAACbE@MCMBEASBAF@BEEAAIBCD@@AE@BAFA`@DBAFB@B@BCP@BB@ND@BNBBB@DBD@ACLABCBEX@BB@XE@@B@DB@D@@ADA@FNEBAJA@AAINADAD@BEF@BFFAHDHA@FD@FA@CpIBB@FF@FDADANP@BDLABBBHFBHAd@LHF@BLF@@LF@@@@FAFF@BABC@CHAFCL@HCH@FBDJDBBJJBJ@BBF@BAAIBG~GNGHGTIPAFDZADDXA@CF@AGF@AEJA@AC@G]BCBADBDI@IKAACAIG@CC@CEBAEC@ACD@@GLAAOF@@CE@AADIBARA@CFEHA@GH@DEJE@CEMCAC@CEBCJAAIJAFKH@AUTAFA@IJAAIXAAaEGICCECMLEBCJ@BMBALB@BFDLBAHB@ADFEdBFW@GAA@GDE\\CD@@ANA@CP@B@@ADAC@@ED@BFBGD@DEFCLCNJD@ACPBPNJBTAJJDBJAVJD@DMAGH@BA@ECQIQKIOKGGAIBCFE@ECGL@@CN@AEJ@CGBAPA@]CEEB@ED@NEAEDCFAFBJEEIBAKCMB@DGDAACBIQ@KJKPKJMH]LULKV]VQDCLBPAL@@A@AG@AACMA@KIAECEEA@BA@AAA@GIEM@I^@^Fh@THNLFHZ`H`KVOLEL@dJFJNBLETBRD\\N`TRVNXJLJFXNNDh@|KPETApFpD@BB@BDBNNG@CAAAGBALABHD@@BBDAFDHBBFAAGDAHABEFCDABDD@BFHBACNABDDBJ@BCLBTBBBJAHBb@BMAADY@WCGDGGKEKAKEGEWMOBMCAGCAAAIBGAAIEAADMGCKA@CFEECMECC@EEODMECGCCAPM@AEAQFGEQFAA@GA@UNEAAUDEJABAIKFECMHABGU]FGBCGAIGBAH@DAFMEEDIEGDKAAA@OBEEKUUIOMGS[YIM_aSkeuCQPMJ@CSBMEMSIWAgGAQ@]CII@QCBADAXABCKIC@KDOIMECBCHEBAGDG@CAAKBAA@CFGKACA@CHGCUGCBEHIBCKDK@A@EEDCJABACGAE@ARANDDCA@MEIGACDEJBBA@CAEKCCCB@JABESCSGLKBABGC@@AMDABCB@BUNDHULA@EE@DA@BFCBAG@DA@GKA@@ADACCU@@IFA@EDAAAD@CIDA@GL@@CPC@AAAB@AA@IB@@AE@@CEB@CA@@CEA@GE@AA@D@@AGC@@K@C@CDDF@@CTA@CD@HB@DFDJA@DDADDDCJHD@FC@CECICAAFEJDJA@AIKH@FKPCBA@AECSC@OACUBDG@EC@CDAAACICAGCEMKOMUFY@OFOAIBKFa^CBIEeKO@IE]BECECECKBaHIAOIO@IDKACA@ADA@ADACE@CAAO@AF@BA@CDAA@C@EI@GCGFCBCC@CCAAABACAKEYDVKCCYCS@EEK@CA@ENIDEKEM@BGFCPDBEEIAIGGCGE@AGDAIK@CJIFKAMM@AC@AB@BCHE@GECEAEGBAD@FEBGCEIEGEA@ABB@CBAA@EBAGMCAGBCDID[QMH@QKGEGCB@DICBECEHA@CEUDEHEIA@ABAL@@CCEWSHCBBBAACKFICDEEAGDAAMM@KAI@ELS@GCQHCBCEB@AGACIHC@AA@@CB@@CIBBDA@MUMEBEFCAQEGOBCA@CFE@GGE_ILKNeRmRYTGPG\\@RIjHPEHK\\LP]@]RMJYZELWPUAYF@NETMD[Ae@QFNPANMHM@aHOJCJLJPNDTMAQOKIMGK@aDgLKFGL@TCLGLORKL[NcLKBaD_DQDOJORIRW\\IHVWRAFFHJJLDPB^ApBRBLFZFFHCDIBBHAFCFC@AUWBAHBBJB@DDDH@@@@DI@CEC@@DIBDHND@HE@A@@CEAM@@FI@BJB@BHA@@BDFNARGRB@KEAAAAEFED@FFDAJ@IFBFHA@EF@NADBBHNA@D]FBHKB@FAAAICCGA@HB@DA@HCBEAAB@FE@@FIA@HEBBDK@ATEFUDcHIFINEPI@CmHQAGGCGFIPIHYPILUROJgRHWGc]MEKCSCOBGJVj@FCBCGA@ABCJDHEJCBEAAHABIDC@ABFDH@@FH@BDPDBDBVFRLN`RTFVCNCTBFMTEJDDAFCHIPAJBFABJ@BGB@FDLD@BBBFCDDRBBF@ZAN`DD@F@DKLGB@HBFHA@HBBFBNFBDBPLFLCBA|KL@LDHFF@@NE@GFAJODADIBE@ACWFCFBDMD@DBHADG@ABBVDAHHHABBJE@DFBBLD@BFHA@JKLADYBAPA@DXCFFRBFHADFD\\CJDF@LBFH@@DB@HB@GBAF@@JZ@DBCHF@BH@JEJBF[BCB@DWB@@EBBPD@@B@NF@@R@DLCJBNDFFCBDLF@BBBNFKVAH@HJBJ@DCA@ND@ANTBTI@CTEBDLBBBDLDAHPFAHJA@EBGD@TDJEDUHBNC@BHHFXDHACFBFG@ABG@@FQBACIBACAB@DC@@BD@ANH@BFL@HFAPGBBJHALBBBDLCJFNBH@@D@DVG@BDLDJ@HNH@DPEFMBBFCBCBE@@HE@@CEBCACCG@@EC@@CE@ACACGAGBUFCDADK@EDAB@FO@AIODOAAA@GG@EBAFBNCB@DE@@F@BMDBL@@DB@JCFI@@LE@AX_BCB@NCBDTC@BBC@CNBZC^BFFFLDBD@JAFGFGBMBBDGBBDU@@VBd"],"encodeOffsets":[[118093,39167]]},"properties":{"cp":[115.665993,37.735097],"name":"衡水市","childNum":1}}],"UTF8Encoding":true});
}));