(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('甘肃', {"type":"FeatureCollection","features":[{"id":"620100","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@GG@IEEEKE@IMFQRGFEBEFA@CFCBDFEDABKDEAGH@HKBGAEACDGLMBGLIBAFAJGD@JCVAEGECCGC@AAEA@CEEC@ACAEFGD@BID@DCJOPGBCTCBCDCDBBBB@PABGBAJBFDD@B@HCDCL[BMEEL@FFD@TELINBJAP\\HFFFD@DDHEF@FEN@RCRBREBBDCB@@FFEBBJCRABAH@@FEJAJIJIAADGDCHE@GD@HABE@EHGDAHFB@BAB@DGD@FADLJDFHBD@@CFAFBDGAA@AHOLGBGJBPIJBBEJADB@EHMBCGMBERGB@BFFDDLAFNFHCFGD@DGL@HAB@HDDADBJAPFFEL@BE@@JBDCHHFCDM@IQCKCACAGHG@EBCDCDAFDDAFBBBHBFGJED@HG@CEC@CDEAA@ATIRBDC@AAKICEE@EAAAIFCCEEBBCIBEAE@EHSISEIKDCFAAEFADCFCJKH@DAGKG@ACBGAGGGGCTEEMfKDA@KRG@EJEDEhUACC@CICGC@AGPCAEFE@AACBA@EJC@GJCFGTCNEJ@FHDAFBFADCJBF@BCEELGZBFAJBDACIEC@CEACIECACAGDCEEAC@CDELA@CEIACC@CGCACCAUCA@GACDGGKHKRIPAHCDC@EHEFMFCACACKEC@@CDCAIBAGKFABCH@AODCACDGDGAECCDALBLEEGJIAAFEAAFEH@BGNCBEHIHBJ@@ADAAOFINOFIB@AEFBJEBA@CFEPCDE@EAAcOAE@AHC@CAC@@HC@GEEBCLCJ@JCIKISDCAAEICIAGBC@EFGCCI@DAFAZOJJBDCBAH@D@HHR@NHN@FLD`PBHDbDDRDHLHRDBD@JAFKB@NBRAN@DBDHADGH@FBDLHPHJ@JCdHJA\\IdCdTBFFVFDJ@XAVEJFT@LDPBJFhFHFDAFBDA@BBBL@FABEH@D@BADDHLLFBBCVZLH@@FHDBB@F@FF@HDTFDFBHJJH@LIHCLIDCCEFSDMCEAADEEOBAFAACACDG@CCCDCBCACCADA@AGK@KEKBAEI@CBCDUDICEBECCAE@MDGHE@EDCBGLK@G@CB@BEAGBCACBEHIAGDAHBHABC@GFGJBDE@AICDA@EDCDECEAKEAOOE@EEKAKEAEDGAELOLQBIHMDO^JDANAFDDAFER@HBFAMOBQCI@OAAKGGGBIDC@EHEDIGGAGDGBEIKE@EEI@KGMCCIBGACQMGIGACABCBCHY[ECCGQEEBEAEIDGBKCCACE@ECG@AFA@GAADG@KCCCCGGMBEFCAGCIOC@EFSM@Q@ECE@EACEBCGAIBKAGBGAIKYFE@EBCLABELOBIEGBIFCDMKMEBCCG@ABE@EDCCCA@IOI@CCEG@BIDG@CAE@ECGCAAEAOEOCCBG@OBIGK@CQUCMCAEFE@QEEKKGACAI@GCKGCOAAEACCCIDIAEA@EBG@GSUEGACBGJKAEGOBMAKBEB@N@HCFE@EAAGICACAGIMBKEACFIBEGE@CFOBADIBMGIBEMESKGG@IDIAEKIEAOFWAGBOHG@GAcDCD@B@DHFBFEBICEAUNOACDBHJLLFDD@FOBGPY^@LQNGBGKCAE@ADCDIQOESaE@ofCBKEGBCDCLEFCVGBM@UFEFADBJMLCJKH]HILKHAD@JMNODS@IBUXCLCDG@SAK@IHGFEJGDYFWHGDGNURGDSFGDINWPEBEAACEGMKEOAAABBXCH@LDNEFCFAHADKBAD@HHL@DIJBFBD@DMFWD]CIEA@BNEHOCKICD@bADCD@D@PHVCHGHG@EGCCA@_JOLKAGHQJGAKD@JBHAHWJGGIEIFGDKEOAEAEIECCBEJUVEBiH@NCHALGP@DHJTXFHINKLADDF@F@HLD@DBDFD@FGHID@DEBCNKLAHEFCRGHCNIHI@ECKAKEE@@DDH@HADANEDAF@LA@I@UJKBSNaEQDEAI@QJC@ACDKGCGBIAILAHCHA@QEACEG@UCICCGEAEGCEGMIKFKAMBA@@DCDOD@DBDADEHHLAVBBDFDNALADEFEBK@GFEEEAMEOBUGIFY@IFS\\GBKEC@ADALAFADIFCAMEMGQHG@MFKGKCG@EBDLAFCHEBEAGEG@KFMBANABW@ODCA@CE@IFAHEHGDE@GCI@KGQBABALAFMJKCK@A@ELIFOCIBANEDEBCDBJAHCFGFAAECAEAIMEC@MDE@QGI@AB@HEJEFGBGCEBEFCHOFSJMCC@@FFLDR@FEJSBEHU@OBCDCHGHSFAJEFOAQJWBQLUFADM`EFQHELGHU@IFKBCA@ECAGDIACAC@GHKBAAAEA@GLGDCJFDLE@HEHF@FHABIADNAHIBEDCACCC@@BHF@BMJINAFOFNJDLFJDHa@ABADBFAFBJCB]LAHEJBJCLIHQFAJCFGFFNFFNHLBFDFJCNHJORIIC@AZILWFG@GDENKLCJ@DBBHFKFADALCBEBDJBHHCFAFBDCPDH@FNCDIFEFEAM@OLQHOJKDHFHTDFG@EBGB[@M@QDIHADGFADIDEFSFSLGBEHQFELCFAFILAJOFCDCHBFAFAFCDBHFJGLED@PJHDRJJBHHDFCZILAJBFF@DDFDLL@DBRRRFPVPHJ@fOJB@@BDF@DADIHC@ACKIA@ANBBFTNL@HDPAVBH@FGF@D@JJNFL@BBDFFBBADGDCBGHEJAHDNADBLLFJBHANOPKCIDAB@DDFLJD@BJJ@FCDDD@BDEHAHEHIBGFE@IFGHKJEJBBHB@BFBPADDHELDFCFDNQJ@DB@BFAFBBBF@HFADBDJBBD@HBBBFNHJBJ@HDFB@DILDFHF@BEF@DOJBFADMLCB@BBDBFbVBHDF@DLFDFNFRCN@HCFBFCN@FALFJJBLFBNHZALBTAhHPFL@FDJCJANHJAFBFFFABCAIFKBAXBNFTCJDFFJAHBR@RCRGBDBFBBVAJEVBJCGUBEDEJC\\BHBDBBDAVHEPADAF@FEFADDF@AHDDCFN@FBJFTNHDF@VEHADCGAACS[YSCOACDAFAPILCBBFFHBHAHHBALCBGLBLFNALIB@FHFBDALHF@BFH@HCDBBCHDDKA]JE@CJBFADBHGFBBABED@CEBCPADCAEAE@]EC@CHEBGJI@IDETOL@FBFDVANBRDLAPDDFBJDDFHNLLPBF@LEHHFDAFEFADCDCBBDF@@FC@CD@BANI@AF@HADCBAHABEHAHLHBDDHFDFDDAHLPAHABC@CFEB@HMFKREAC@ACC@SIA@CfABCEEBAD@RADAFGFCFEBCJE@EEEBCDG@GEE@EAOFAF@JADGDGAEEE@@EECBGOEAAAEI@KDIEACHIgICBEBECACGECICCEBCFOJ@HEFCDC@GDBF@HDBCH@VBH@FCFIBC@QAIO@IACGFG@SFCRF@DDFL@JDP@PTpDlBlA^ELKDMBATCPOLBFGPEPALCFABCB@@FDCBBD@BBF@BCDBBDFBDB@DBAHBFDD@FBNAHDRDP@J@"],["@@@OHEBCJAACE@DGECALGJCJBFAFD@"]],"encodeOffsets":[[[106051,37862]],[[105300,37239]]]},"properties":{"cp":[103.823557,36.058039],"name":"兰州市","childNum":2}},{"id":"620200","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@F@JAJGHGPOJEBAEGDGBGEKAGDQDGZCTG@EKOJKmgWQDGCC@CFEDGFI@EECQKSC]Q÷UIEC@EFQHQTMPG`ITMJIBWB@F@BA@M@AIEGIMIMKCICQK[IIKISPsLQEKBEBYPe\\KFOBQFGDGJUJCBAF@DHLABIACB[LOD[@_AWGSQKOEQĹDÇSPerEDMDQ@OFS@cHMHm@CBĲÐdzhCH¦@BRTZNLHtXADA@[HM@UDBBHDAF@BTFJH@JDHDBN@NDJ@HHDBLBRAFBBDITLZ@DKRKL@DFDĎyļOd@BAAEBA`@VEdD\\@FDPCnRLCLANIPEjAPFbPBBBH"],["@@KKKFZHAA"]],"encodeOffsets":[[[100831,40930]],[[100209,40671]]]},"properties":{"cp":[98.277304,39.786529],"name":"嘉峪关市","childNum":2}},{"id":"620300","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@BQAWSAM@_HIHGPIhUJGRKFEDC@GHIDUDUBEdOHGN]FSJWPK`iVOJE@M@AÆq\\IDA­nCPDhBºEfEJQY¯DEBQI_AK@OEc@GDEPAHGDIBGHK@ACCPAFCFUFGDIAO@KAY@OAGGKEEKGU@EFIEE@EHQEBE@MBGAEFABUCC[@OBMAEB_NIBE@IHGBCDMAUBCBCAIAKDIASFCDCAABBDGBADIBEDGCEBCAIBG@CIE@EE@CCAAEAAE@@AMGCBCAI@@CICAEKKaW]MWeSGKAYBG@EDCD@HADAJDF@BGBGJEDSJKBQAeFWBKCMEeIOEeC_GaGUEEEWCGACCFCLEO]KKCEAOCGI]CGCAGBAHIEC@EHCDCBEEBA@@E@AB@@CCFAAAKIABAFCDGDCFC@SOUEEAEICAGAMDGEI@ACIFACGAACEAAAEAIEAABEKGKB@BJBBBEBABE@ABKEKDUESBOD@DILMJ@LBFAB@HEHCDCFCBAFAHDFAJKDMXOCQFEAEAKQOAEECACB]ASHeLILQDKAEDGBEFC@SGIBMCE@MBICIEGKKYCAGAOMEAMAYBEH]FCHG@UHGLED]BA@ENMAAGAAGDMESFG@OSIICK@E@CA@uf[JGEKSGK[OUGiE_@wDIBOAKD]@_OC@QHQA_MOKUGKBEBedMF_JWABJdANfTZn`fdDH`LRXJRGTgZuTIFEF_NABAD@NAB[BELAZGXCB]D}AG\\CP@PC^EJ@DBDJB\\KJHTBBB@DCDCPFLD@RALFPCTDFDPDLBJANCTIJBNJJFPJjX~pLRBPDDFPCFEBG@SEM@CFAH@ZBHPLfERBHBHFDHE^KXUVURAHt`pTDDDFAPGd@HX\\XdHFNDLBHFJPRNZNJNJFNLJFPCF@HFDDN@^IrKZKRHJBHATIVMJIFAj\\ªrjÌÚ°FJTNÆEDËÄUPkhSNCFBDGzI¸MPi¦iľu^XCPBMvQ\\IvCKesIOZO^ÑY[_eAWCS@I"],["@@KDKJF@JLFAFCHABAACKK"]],"encodeOffsets":[[[104867,39678]],[[104560,38939]]]},"properties":{"cp":[102.187888,38.514238],"name":"金昌市","childNum":2}},{"id":"620400","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@DCHC\\ARGAEOIACASCICEGGAEBGN[JCPCTEJENAVJH@BWEGAGCCODCA[UM@G@MEKIAWMEIKG@G@YROAGEAGLK@IEEGBIAECBCCGKOGS@OBCTgHCHILGDMJENAHBFDVAJDBDBBB@JIJBJ@JCHFLAZHX@XNDHNFJJJDFLNFPBTPVIHKBEDABEFBLDDDDBJIP@PCLK`KLEDCBCACFEAeBCJGBC@KBAZKJG@CJADGHM@EFGHBAC@GCCDECA@ABAAANCPKFGFKGU@ADCJGTKbEFCFGBM@}BATOHAFB\\DDHBBFGZBTGE]bMDCFCL@BBFLNNH@LFPIRIPAPEHE`KNAHAPCT@PAVBPC@YF]DCJCFGAEDQHCACHCAIBC@GCA@AFESFJYD[AGGDACHAEKZK@BADD@AFFDFBBFHCHDVIFCHFBKDCPPF@FFFCDAEEBCD@FFXU^UHABC@GBKAGAAfSAGE@AA@EDAHC@KJKr_JB@ADI@IDM@KJ]@EGCGAGUKKGEQAG@QNIBSBMDAA@CGI@IEA]F]@AA@CBIACO@IDOGECOaECGMBG@IP]ZWHGDGEIASEIBGEEBCDAHBDCF@BEDAP@@A@U@AF@LWVDRQ@AGEAAHOJGBECKFKCAG@IGE@SIGMRCFUFBB@FEDAFBBEDEB@FBDGLFHBNAFCD@DBJLFDPFD@JMRMDGNGJIZUHODMBICEAKFKDCAE@IKWAEBEJIBABB@J^HFCBEHEJEDA@GEW@KJmB@XAJMEG@CECW@A@FK@CBEFABAAADCBEFCD@BCH@CEBCDCFABA@ONCFEV@REBABODEDEPIJIFIBI@EEQAAIAEAGGCGBEFGFMGOECCI@ADUFGFCJAJEBCFAFG@EAIBAFB@KHIBEAEHOFMAELE@KHERKDEMOCKAIODFM@EAAOeEBACAAGBCAEFA@ACCBCAEDAAEFADCBG@IGACCBADEAG@AGEJA@AACBG@AA@AKQEAGEEGACMQC@EHCBEEI@AC@QACCFCKCDCAG@KIAGEBIIEG@GDAFKI@CBMECBEAEBAGCCBECCBAAAAEFEAC@OG@@ABAC@EEDiCMBME]EEAECCACBERMDEBYFMCAEBE@ECEEBGLYPQRGLBDFNKLCHAJDNGLGLO@C@ECIAAGBKN]SBCHMFU@CCEAEDAF@LF@AUWACDEJOFAFFP^HHTRJBD@BCBMBAB@JJFBDABKDsJOFANDTKBECWCI@OJ@LJFBHCBABCH_BEHEHAKEeKGCKQ@EJ]\\aXeVYZUJKFEFEHKBIKCK@KCCHA@AAAGAAE@GFGBUIBI@IDKEO@KGGBGBE@MAAIAW@IACECUEEQGQCYCGCGGAMRUBG@CGCkIKAWFEDIDO@AAUUONCDEAAEWMIDAHEHEBCJEDIAECMQMGUSQBIL]DSAEE[KKIEGi]GIGEGAK@ODOHWFMCEEAIODG@CABEDGHEBECEAOMAG@QA[BKBGTE^AFGJ@DADiFACBEAC@AEAGBGFC@KC}LIHBVQFE@SDAFGFAJADIFODUCGFINEP@HFZDVAPHFHBJAFBBLBHAHDVJJPrCNHHFNRNBFDDDHAD@JDRC`@`BJ@HEbGRSLEBgTIFKDKL[PQLIBWRGL@RCJ@FCHEBGDIBONALFTAR@HETQZKBG@mDSFGFADFNBJIBGDEACD]LGAKBG@CBCF@NDFD@BDBJDB@DAJED[HGDEHIDABID@RKPGFIAQHCAEGCFOXUXWVTADBPFJFADBDDF@@FDBFJDBFBJAF@DFFB@NIBOJG@ADaCCCKAABGCIDGCIFCLE@C@C@ACICGBMGEEMI@CAA]EGBBB@BIBQGSEME@AIEEDECEDM@CBE@CCC@EBCFCBBFAFFFHRDD\\FGZADADDBHBHJRNBDAHDJNDLHJ@FFF@JLAFCHBHHHCJGF@FCDAJHHLHBB@PDJARNPEBGAQ@EFCBECMBCB]ICPGNAJKRKNBHCHBFLFLBFFF@PPFBBLDFCFCD@FCBJD@BCFIAEH@HADGBGACBBHGJAFBDADBHAFA@@D@HKLAHCD@FGFCH@NBFDDAFDFCJCVAD@DFJABFL@LHL@BCBDBBDADCDDD@DCHBDBDEBABFPCFBBDFCNETDFCDMLEBKJG@IIAGCESEGCE@@E@EAAGC@EG@YKDUAAKEGKCCABC@G@AFEBK@AA@ACBEACBGEgEIEOAKCS@IEUFWBI@ECEUAEcScD[JIBcGIDI@OGKGAC@EHGBCCGCAM@QBMAA@ELIBC@CAGQGKQCCCCaAG_OKC@EGM@MGQ@G@CBGDAACIIABWNIDJ@DDEH@FADBHDJFJBBCDJTJLIDI@KDADFF@HGD@@BD@DGD@BBFdPBB@FCFODEF@DABIFEABFA@EJMPEJBPCB@BI@GAGJAFMDAHG@EFBBEFBBIJFHKFKACBDDBFCHCHBDCDBPG@ADEBHLABBJCD@DD@LFBDBDEDENGF@FCDGDOBQJGLHLCHBD@HDBBVDDDBDHD@BDFJ@DKBCF@DBDFFCDBHBDFDDJFB@DFDDJCBIAEBYAKHFFADE@IACDEBEACBEGI@MFSDEHID@HID@FABBD@BEFBFODBHD@DHDJD@BDgVCFIF@FQH@LCBeLFNSFHDHHBHAHBDH@HLCBG@ILEDCDEBBFEBCDJLTFTJFGF@FBJAADFADFEDBJBB@FFFJDBL@BCDQASJ@BBBCF@DFD@DGHC@IFEHGAAAEACBECCBCDAD@FGHBHBDLDRD@JCNEDGGCDIA@@AFK@EFOEIBCACBGCA@GBK@CHC@EHGDMEBECKECAEA@QHAFHNADGN@FCAIBAFIAOJIAAHKHGP@BBBCHEAEB@DC@GACEKIBC@EHC@CBA@AEABGHCFGF@BA@GHCF@DGHCBCJBJIBIFI@EG@ABQBIDAAEF@EA@CDAAQFQAQDM@EFE@GFCCC@EEGEO[IBMAKJSFC@EEK@FFANK\\CDGDA@C@ECIAABAHOBA@AACACDADQBABCDMHIPCDC@AJC@EHBFBDD@FF@DFBBBD@DHFDFHUBIDC@IHEBABKJAHKNCHBDBFAHGLG@BHCFALCBEFACED@DEBAFEFQHERJNF@FLFFAHBDJHFA@DFDFLHD@TFJAD]hKBAB@DBBNJHJPNFHJ`HLFBLBTGREB@DLTLHJBHETDR@TINOJBBRJRALHT`HXJ^LdJdRRBNFTDDF@RENID@RDLEHBLHLLLF@DADWFEDGHEDAD@DDDPLJVFFFBHAJKFAD@@B@NBJCLCHKJAD@DJHF@F@DQBAFADJLbJH@DADKLKHABFTHJAHEF_V]LCDBNEJBFLPPfDFNHH@LEF@DH@DAJITRzCXD\\ANMFKZ@THTP^N`Z^\\X^Tt\\ePQ¾`QŒăĎ¿°J¢fDC@MVOZBLjCLDHJVDJJRFJFtLLDD@PSHURINAhFNCPBPHFHJ@DBHJTCBCFCHALIHDLBVH`ErAFALMXCH@RF\\E"],"encodeOffsets":[[107164,38315]]},"properties":{"cp":[104.173606,36.54568],"name":"白银市","childNum":1}},{"id":"620500","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@@KAEASFWNIbEFC`YRILCRIDE@WAQDMHID@FABMFGJ@HDFHBLDHHHHABEFEFGDMFKJCPCPHBFDHH^BNBVHLHFLDL@XILAF@JDZDFAJULCNAFCLE^ADBFLHDF@BE@GBAD@BJEH@DBDLDFCNBDAHEPCDFFABBBDADEJDLBfPBLANDN@FLRNJHHBRJL@HCNQDKAEIUBEF@VDHFxl`THBH@LEdChFTJJHbZLABABIAQFMFCFBDDALBLLLLXDFHFDDLFF@NGJ@JKDAHDF@HDRBTHJHDHR@FCDDHHHCJDFEBGLMTETKDK@IBIBAHBLBBGCCBEEKDGD@JFBGLELBRF^VFHFDJ@FG@GCKEO@EDGLQVUXCOSKGEM@GFADCDGFAH@@KFADGHGBAJAFC`LF@NALEHANHPFJGJCDCFCFMPEJGH@BAGSBEACBEDAJCAAAGGEQAEECGHMFCBKDEBOA[HIFEVOHUHmFMFEHKHCHE`MJGDEDMAGEIAKBKG@AADMDG@ECAFCJAHEBKAIBCHCFADCHEBQGMAEUKC@EDKCIEJI@IQKw@WBIEACIcCEKKSIG@[IWUKUACBMHKJEBA\\OJGDCDEECBCCAC@AEBED@BA@EA@KFKDSEE@@FI@CH[XEBGQBGIIGCKDECEGCACIE@CCKDCAGCU[ECcOUIIAQGSOBGF@JCNAHCDELCBABIDE@EEECKBCDABC@QGMAGGG@CHAH@LDhMHDPND@JCAEBIJCL@FBDDBJJLRDRALFJBXIDBHPF@HCEGBCDADB@HBBDBF@DAAEBCRCFBDDFABABKDAFADCH@HCJ@FDF@@GCAAGBCDIDAJ@JGPBJCFI@AEG@CBAFABBDF@DJJHBFADABKBAJ@LFDA@AACGAAC@CHENDLEBCECBCFCDBVDFCBCAACACBEAGG@CBAJ@HKDBFJHBDCDMD@BDF@@CGEAEHSHABACOFI@IHGDILDHE@AGIBEPCNBNMJED@HDHALDHECIBAH@JFDAB@DKHCF@FHHDD@FKF@@aEMECQCKEG@CCAEDIRYHOBSIQQWOeIOKISIUBEBGFILONC@IBIA[OKCCBMBGBEHIbINQDKBCBUBWJUBIEWa[aCGAGBKCA@CAA@EAQBODK@KBIAGGMGICAIBAA@CEEBI@QGWKMSQEGmY]M[K}OSAcBQPQp@P`BJCJI\\MJ@NBNCDG@ABAH@POCMDIAGBEAQCME@GCEIGAGEC@EHEBACIFE@ECGIM@KEGASGAACIIEAGDIAAGDODEAKUOEGIGK@IBE@IGSEQAEBCBGFK@GDCDOBMFCFA@GAGMKIEBKEQDGAKLG@GDELEBUBEACCABAFEFATILK@MBGHK@EHMHYCQBYGG@GAWAIESGMFCAK@OEGAGAGEGKOEA@MDE@EKQQQFGAQDI@MDG@ADBPDJERGJKBIAI@MAGBEGEAE@EEIFE@EG@OACQDACIMQCAEIEGFGJCHBPLRILCTQDGHIDIAGHID]CGAEE@EFIGGMHG@EASKK@UGUMACCMBGAIECKCGG@WEEC@CEESDKAEEESDIESDCDBFDDJFDF@DGDECA@SROBEAAC@GFCFGBAIIAWEA@@AVG@CCEAYHK@ADDFIFCFEB@JCFALBRFNNTKFIHIRFJLHCL@nBPC\\KJAD@FDDNGF@FDCHEH[HC`RFHHDFCFURWFGJAFDHHFNFJ@HBTZBFGPEDIFGGKEIIQEEBGLKLU^IRGZKLSZKTQTYR[PGFOJ[JeUKCMHMFMLQLGH_DIFSDGFG@CDGEDEBEH@LEBCOBUEI@KB@HBH@DCBMBEFGDC@ECGHKBADAFBPBZELAJCHATMREDADGDBDJ@DDAJCNCB[AABAHC@EA@A@CAAIIICEAEAED@JA@WI_HEEA@CBCFEDGACECDE@QAAIAAFGACI@G@GEGCCI@Q@AEAAGECCGCG@IIIBICCECGAKDI@EEIDC@CC@EGCEGAECCEGGDGIUMUOGAWCK@WDQ@CFK@CFE@KJWH_Bi@OBG@UGMIKIQCWFYLGDKJ[NS@WIOIUIG@EBALBPCPBPF`@JCHCDGBqaI@OBCNARFLDFDDDN@VCLDB@FCFKLBLEF@DBJADKDE@KMEAKCIGKCOBQLGNIDGJS`FLFRHHDJBLCFBHLHDD@JGFAB@DLN@HELFPLXFTQCaKSIQECAQCE@ADUAOBCAAEIA_@IBAFBPJJ@HBDBHIbABI@CHBDJBNNIB]NIB@D@DHDVBLLPV@FGNMNCHKDGF@PBXHNNLDHFV@HEL@F@LBDBHF@BBDHFDTbFDRJRFh@JCVCFCRGZENBH@NFR@JCLKLEH@\\RHDfHN@P@V@JARAj@LAHBHCJ@TELGHARDRJNdDPBTCTLfFNNHBDNBDCPGLAJDLNRDN@DCAELAJ@NHD@PITFFGBEAECABCLCHDFB@ABINAD@HHjTHBVPBDDL@HGJGBGFGLCJ@HDFJATANEZOVALCNA^A^@pJH@JCF@BCJCPQ@GCEAMBCBAVAHERCB@HFF@PHTbRPHBHPDPU|FNTXLHPDHAFIBE@EH[FCHFFJDLCnADFHDDJELGDEPCPNNHTCPBPNX\\LFHCJIF@LT@L@RHAFAHKFCDFFVAJ@LDLHJbPNJFFJBJAFCTWJEHKJWDEJGVGJ@biDCPAHFLPJZDT@NDHVRFLGNOHODQL@JBJFHPHPDFFAPCH@FFL^AFCTOHKXOHAHG\\IPKPE"],"encodeOffsets":[[108174,35983]]},"properties":{"cp":[105.724998,34.578529],"name":"天水市","childNum":1}},{"id":"620600","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@MM`EfG`C¬WÎY`ITEM¦MRAJBFB`\\NJPJPLRVRNDFTNrbVFJBBpDx^Ð¢ðÌZJxNjFrPHdHZNZFì^¸fÚtĢ~^BfAACvMĎyPEBAcÇGUIUEIEKWm¢­ÊÕ\\abN_FKJW@AQiIQEWH[DcBKCMBUqII·o}UU}Å÷±ãύȩVSPaTaV[^sJ_HydãEEqWI@OE±gcyYE[GDKFMJiES@YDSHEJMFQBMDGF_F[BKDG@EFIAIBMHW@MBE@IÊejMZEłULEƒŗR[s]S[WY]M_O]GS@SLYNEBMC[DWQyJSBI@CCGE@KFG@MGCEOeKOAEFIAMDC^K`UFEBGGIESBALGLKBC@CIGKaCIEBABCRE@E@IG@CBCLIDGDKAI@M@AC@EBILGBEAEEIUOKCC@CBCFCHGFCXEBC@CKEKKKGGAKFQCC@MJQFE@CCESAMQQIcKcI]GWS_KGQBQIAAPIJM@SCQFSAGGISKCKA@QFSHKAEAGKI_EGOMGIMIAA@CBALA^gBCEI@SGCEKEC@CEBAAI@O@QCGCMBEAC@ECGAAB@CCAEAACCAADE@AAC@AACD@EA@ADEBKDOBOFEHKAOPSDCDALEDAFMFSBkBkAoCS@OCO@IEKCCE@DQTEH@HEBD@JJPRBD@JADE@EAG@UDGCA@GAEHCD@DCFE@GBALEFGB@DADDDJHFBDFDFADAhJGJBDJFLCJ@BFBBPFAHFD@FPHF@FCBC@IBEPEFBF@HFH@DCFAFFF@DIFADEHEBEBC@QBCFADFBADeB@TJD@BDD@FBLQNE@GFADED@BABGKOBGCCCEGECCGAGKGBAFGBABCDGBE@@BMJABC@@DED@@CEAACDCDEBEFCBGEFG@KAEKOMKEGCCAICEOCKBQCMAUBECEAK@URANIJAHGH@BFD@^BFBFCDOBADDFC@AFABEAGHCAEBIA@DIFB^CLGCADCAGDG@AEE@KGCBEAEGA@KJMBKEKAAHKDABGGGBGAEEAAKDOJEBCBBDDPZTT\\BDHBCD]HE@eWEAM@DECC@GC@ACC@EBCFE@CBOBGFBUACCAcCIDCFAFBFFN@BABGBUAIFUBAAAEACQHQDQ@GAIBEEICSDMEWAABELBJADEBEEEAIBMGIBIDECK@OEgGSBKAYBMGEAAKIIKEEBM@EDEAGDM@ODOECEKE@CCEAGaUAEACJIFADEAGPI@CFE@AGECEJK@CEAGCI@IAMGAEAA@GACIAACBCGEE@AAEAEB@ACAI@MRECEDKCGFCCOBEA@AGAAAFILIHGJEF@HEJAFGBGFGACC@CCEDI@AIC@KICE@CBAJCLDPOBMAGEIIICAO@GCE@IFABAHCDCHABEACEAAK@MEIIC@E@EHG@UAOBGCK@SMAEMA@BJBDL@BGDCJODELOLCFCFBFOLGHIDAJADA@GEG@CLMJAD@DDD@@EBMCABABBHGFMDAFFB@BIHKTEDIEEACD@JADQDGHYDEDCFC@EEC@CFCHCFMDINCRCDGDCD@HHNENI@IFODKFO@IBCJ@LABGBGCG@EDODCFBPCFEBCESAQHGEE@KHEJOJFDVHFFBNAJJNZPBDPPDBD@RJAJGJAJINAFFNDPKFCDANBJGHJLHFBFNAHFF@jILFH@DBTDT@BHPAFBHDJLRED@NFVANAFBLC^CAFAD@TCDAJKHE@AFDDAHMFAJKJ@D@BQDFL@BAHINBFGDYEQBEHMHCFKRGBOLILABBFMHIJICSJOCGAKFMFE@CBGLCLCFADQHSDGD@LEJCLBLGBEHIBOLOHKLAHRXKDGHEBKDI@CDIDIHSCEBEFQBADMD@FODAFUHAJKHI@SLIBGDEDBHKFIBBJCHDJBNGBsBaVADEDCHMBMDKBMFO@IDEAG@IBUPFNCHADCHIJ@JADKJ]PiTOFIHQEKAGAEDAD@PHJFBF@@JBJFHLHADCBBFCH@LFJJFDFFFADEJEBG@GLSJ@FCFAFEDDJAFYGGBCDI@IDCJCBGB@HHNC@GFCF@HIFIAG@AJEFIBAJEBFBDB@FRNHNDPMP@DJX@N@DPBBB@HDDVEHHBBCHDHCF@FDDF@JDADCJLHLNHNPXFLLNLVLFJDJBFBRPBDBRDTDLHPRN`RHDTHJJFHAFCDgI]KKBEBKFIJIZEHGHSLIJ@FBFFFFTCNGHSHM@KDKCIBEBOPIBHKFADDHPF^FnH\\HLFVRNFXHXRHDJ@NH\\LHJAJCB_DgCKBMFOBCDCPDJABLL@FE@GFEBIKE@EDRHBDHBBDJEBDJ@HFNCHBDBFJFBVFTPD@DEHCDCBEBALJBBEBDD@@BAF@@@ABFFDADCFGD@JFBGHADBDHJ^DHBPDFLLP^KFEDDDHBXDFFVFbH`HfDPFfJNFLDXAfERBLATIFCHIHA@ACEBIBC@GDCFCH@ZALBTHXf^NbXLLBFJD@DJ@DBDANH@BF@BBBFDB@DFFF@DJH@JADBFAHDFCJABCHAACBADBDCTEJBLCJBDBDAVANBDCHAJGF@JA`MFANBPA\\@DDAVEBBFAH@NAFRFFGF@JFFEV@LHFFHLBH@PBZ@LBPCJEHEVEDOBDD@BGLAHCJGHOBCF@HFd@PBLJ`ARCFZ°IReF¹FgAOCmD®CB[JÅr@B@NIFUP_jOLIXETM^GHcPAFCVCVGJ@HCDEFQLIHw`GHGJ@RB\\TBXA\\DTBX`fZ\\]ÒYPJPftLuD[JuRNOAWD]Ľv¥jOj·NyJHACDETMlgVOÌÃuX£]T[JWZµ°EDihEHFDH@¼`Ģ^`nLRTN|N|JhJTHZNn\\~d¶\\VVIjUibSl[VITORIbMX@dE"],"encodeOffsets":[[105098,40109]]},"properties":{"cp":[102.634697,37.929996],"name":"武威市","childNum":1}},{"id":"620700","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@\\CfBâLèHpDdCnQI~MKê×®aèWâ©PEļcÂßYtÁĮo¶IAãCTARCV@O`AJlJTHdHT@LAĴD@ǝBGJOE[P]@WLYLUBGCK@CFG@CACACBaAmFMFEoFAH@NLPZDNFFB@TE¤iJGFKF]BcCQEKBEP@TPvHNôXNTFDAWwe§DDIlM^@NAIJBDABAHUFSAIIOKKKEcEA@DOHMJGLCHEJCTDHALEHA`AZE\\FRGNIvMrSHINIbCVG~Q|SHEjboHCFBHDIOGEKAMCGEWcW[@GHcBOCECCoSs_BGVQVULWF]CGGEGAQAeFOKAG@YBGDEN@TFH@FADEEOCCAOKQ}oiWOIIEMIIASJMDIBKAOCECSCODKEQBC@EKDODC@CAASAIG[LIAAC@CFID]@ODOH[~B^CDAHWBYFK\\ABA@MBCBA`MFEJEvShYHSIQQW_KCGecm_SYMeBcAIXB`INEfcFAHAZHPL`NRBRGD@`P^@LCPBJAxC`@jFVH\\PHLLTHF\\IveB@@D@FDLJJPTH@TENFHCBBBHNBFMB@^AFCHKVGH@DG^EFGZANBFBPNHBDBLZHLTJNAF@HBP@THD@FEHAFCLBRCJKfKTG^BDADBFFPBLRFBFBREF@HDB@NWLCBICEBGBEDADEDCFG@GBAAE@KNIJK@CPCTAVFLCLFBAF@BAFAAAIA@ALALHAFHFRMHAFCCIDODCPANELArDNALCBIGI[KMGI@GCWQWGMEUQKE[GmG]EOECGBCLE|E\\CPOFAJALDLCN@TGHGDMESEEAE@EJITKHGFGJYJILEFALA^LhJDCBEEGIISGGC_QQMGOCKCSAQACQOEAIAICKEKUKMEKOWGMKMKGDIBCICE@CC@EDECGDGAAGGUFCC@GAAOA@C@MIW@CNOCOEKIGIE@GCAEAFNPPDRAHKDGFEPAJFP@JGH]LCFAD@FBH@BCDCDCFK@EDCH@JG@]FOAIAUFUAKESEGICAEG[QG@ECIBCAACECMKEAGGCAE@@GGMBEOMAKIJC@OCGE[G[AAB@FEJAPDNDFAB]LMPV£\\oPSBQHAPNPJL@DAFOJGJIFWH[bOZAJ_PITKDMBUJWBEBA@ECI@QHaPEDIDCBMFOFA@EEC@ODEEC@ODIAKDEDCFAJGBKAKBE@EE@IGEYSUGGCAACQGCQCOKCKEECKDIAAQIECCEQBGFGJGBGFQDSJG@EACFCFIF@JABQBUFCNEB_EIAgVEBQAQF_BCBONMDEFKBI@AJCHA@OCA@ALOHDPALELSJILAFGHEDMAEDCF@PENEHKPKCKIKDQ@ABQNEHGDCJIDMDGDEHCFEHC@ICI@aTQHEFENMBINMBQHMCAEC@EBOGEBGFOBGACCEIAASNGAGDADKHAJFN@HCFC@EHAJBDENDH@FFDHLDBBDRNBHNLH@FDDJAHCDBHIP@FAHBF@HBF@JFF@JDBBDBRPJJNGH@DGFIDWNWDIEACCIECOECGGAQGEEEIIAYBGFKBIJIBGFENIJIRGFG@IJMFCJBJMDAHAJKPOH]\\EBICCBMLgRGACEA@MAYBE@YNEBMAGDODWBMHMDGAG@aWAMGIC@SFIDEFEBMAGEO@GDGACCGHCHIFGJMFGLGBU@QBABCJODGLODA@AEIIBOECIIU@KFI@EAEFCD@DHPCHFP@JCDA@O@@FCFI@CAIGUIIG[LAF@FABOF[AIHIAOJeRIFABBBLFDHJBBDADGHELEPKTWVCPADGAGCMOKAIDEAOSGCE@MJEHHJBHEPCVENFRAFINCXADEDMHQ@CBEHUH_BSBOBOBQRIRED]FEBGBYXE@KEIAS@G@GNGFKFQ\\GBCAQOQESDEACACSEIMKCIU_NKFGLEBACEBABALFFABA@AAEHAMKCK@AJAHBH@BA@CHAD@@FL@@GDEAELAFGD@DHD@LCFGJ@@CDEHGB@@BH@FDDAFMAGJMDCBCHCBCHG@EBILK@EHIACIAACDCPC@@KE@AN@FEF@@CBAHGLCVCNEJ@BGFC@ACCBCCAKECCDMHE@EEIAEBCHA@EDCAIBCACBC@CDGBGDEBEHEBKJGDGBGC[UKK@E@EBSNGDQHUBEHGRCLCHABK@IBGFIHCH@DJFIDUPKFKBSCMAIDWNEH_NURUNWBYAOBMFKLQTOJY@]DZeHsRkVwbKLOJSHoDGDKFSPTWLWPEHMPGRGHKFSDKD]PYTOBABORGFaRGJAJEJiZKLCJKVBTGRBHABFLEHCNABGDQB]ESEICKAS@EBMLMPCJKpIRMPURIDcLCDIHEJAVAHOZ£~mdEDODmXYHmFOHWTtOPidOJmT[VyfEJGJ@JJLXRr^LLCJSF[AMDKFIHIRIJ]H]FO@IDCAMIWCEDML_@aFCBMJMBKHAFQBOLSHGXOLGTEFIBGHIDWCC@CLKDG@ECCBCFeNCB@DLH@DOPADDFGDGAGDEAKBIAGDM@YGEBKHA@GCUCAUUaGEMCCK[IEEACGIKY[SICIKIQaEMI[CWGCC@CJKJQDE@GCCGAGIa@CCKYCCKAK@GDILIHYP]DQH}CcC]@MBSNUNEDEFEJ@NJVAFABKFUCM@EBGDELATKLMNgDMFC@KDcB_FYA]EEAGICGHkDGBQGUESCIQYKK]UMOMUBGFARCDCBE@]AGACMMGC[GEGEAKEQSOCCAGGECUCQKMKS]EAWCQKQECE@GAEWCMOECE@GFUVGNIRMHE@OAIHILODEDEFAD@LAF[XKDUDYAIBKDUHKLEBGAIHKB{LYLiPQL]Zo\\MF[H]LWDU@WFSD[RKDIBY@UDQLCJ@DHT@FIXEJCDSJeJ]PWFSHoX_RuRWLMDiJ_JKFGF[hCDIHWPSFQ@ILC@EZG[rcN¬@VKPBLZRhjFFHBdBplFD´CP@DDHHJBFRXFLNRDLBJDLVVZPJTNH^NVJ^r^RZXEVF^DBBVpHNHZBFLDRDHRLLNG^CNC`EH@LDNAZENGN@LBBDF@HAPEHFTBLBLNPJ\\\\DAl@FAJEdGT@PER@NCFCfqTOÊĸCFRLPTRXH`B\\@PC\\KDAJBBAGK@CBEDAVIHIHCREPALEf[`QLAD@LFJAlITO@EQYIOu»rgPOpGT@BE@KC[CEUO@ADAD@RHLJBDBJBLAJBPL\\FFJJbfĬËemLAFE@CEGOAYJIMBA^KrDjTHHH@@AGE@GGIQACC@ARKXEPGRCJ@RMH@`EJ@rKjWnMNEd_HCjMNGh[HAdUdOCKVFXKzg^JbKJOBBFL@TrEjDrATc`GHCFAZ@FKVIXSHUTaHCJBTTDBHGPENAlBdSFKDk@UBIZWXOPIFEa_AGECAGDAXJFJDNRRNT``JRBHAHBJCTALIjMZBJPFDHZVXFrm{i«bQNlcJMFIFILCJCLCFKNQNOPaDRN\\ANUNaJWBaEMGaAMCqGKKW½`EBOEYB@@LIFCHIn@JHXRdHXBDFBJ@PEfGXALCPArDXE\\D`CF@@FtFZFDdDHDDPjJNJJFJbLHJlXfATE\\@DABEXQJFL@PBD@FENExNARJHRdLHFLHABBFJHDFJPCLKHKzHX@zHRFfR`RND`DJA\\FtDh@VF"],"encodeOffsets":[[101843,40835]]},"properties":{"cp":[100.455472,38.932897],"name":"张掖市","childNum":1}},{"id":"620800","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@CBCCACA@A@I@AD@@FDNBJ@CC"],["@@H@BC@AGEABABBH"],["@@HA@A@EFI@GCILOUAAJFLMJJX"],["@@L@@DB@DBFADAF@BB@FBBDADUBAD@DDBHBHAHFHJDRADCJK@EQGCIG@AAG@GBMCAGJ]AME@MCOMEJFHEJBNJNDHCFQ@AT"],["@@ECMDGAKIMCKDCAEEEAC@I@EAE@AACCQGEDIAGGMEK@EEOAI@SOIACAG@EHA@_CKGAEAIB[FKBMDCLHP@DDNDFBF@HHDDRAJEB@B@@JBDP@FHD@BAFKBADBDBLDADBDFBLDRBBDBPCHBBPIBEAGBAD@NJ@DEJ@FPL@FBBNBDFHDFBDABELM@E@EFAJ@DGBABBBF@F@@PNNDF@EOBEFI@@IWCFA@AABKCIDCNIB@@@VBBEACCELWZ@BEEI@ENCBAACEE@EHMBM@CHED@F@BFGNBDFDF@DCD@BFADFHBLDFBFCHL@TL\\\\RHFNDPFDF@DCBC@OBCDBDB@DD@FWDGFCLAN@PBDDD@RET@DQBM@EH[LG@EAGKGCGBGJGHGDOBGPIL@NAJSPSAGAC@EHEJEFCBEDCJAJBHKNI@GCMBCHAFCLQHCVBHCBABMFEDAL@LJBDJFBDALKRCLBFFDJ@VKLHXDHHD@JGD@HFDLHFFLLFBBDBF@BCFBBDRLDB@DL@RFDDFFFDJNJHBBEPFHDRBDJALLH@BBONABDFAFIJ@LDHCJEBABFVLTDD@BABGFAPQ^GHAHBHJJIBFTDTAFC@KCG@MCIDBVCHALEFUJ@FDHCDKBEN@BNPNFAFCBDLELBDDJFRJXB@H@NGLCFBB@ADIFCDBHI^CDEDAB@PBJADIJKHCFBHHFDJSHAFEHARA@KCAD@DDD@BEHAH@ZNHF@FBJNFFV^ND\\FDB@FCDLHJ@@E@AJ@BDBJDDPAJFL@FUDGBB@RAJBDL@DANALBLCT@DAHGL@FGP@LCD@HHBB@DEF@F@FDBH@BABGF@BC@OBADB@JDLFFD@DA@GDWBCDCLOPEDCDAJ@BB@JDAFKDAJ@FHFA@HLE@BEL@BFHBJJDFABAGGBAF@DDB@BIJIjUZSHCB@BEDABFFEJFF@JCHBÎ{JKH@PGD@LEDCHARKFAJE@AB@FED@@CJCFEHCHIF@NK@CD@BE@ILCDIC@FA@CHGBCAAD@@CBCH@DED@DAHAHKFA@AH@ACD@@CD@@CF@BCDBABB@JGDBD@FIBAAADABABBBAAABAFBBEDA@AD@@AD@BCLGAAH@BMHBBCCAF@@CDAAAFA@CDBBGLC@DBBDGFC@CDD@EHABAF@BABBBCBABAD@BCDADELED@BCF@@EB@BADAHO@KCMBEBCFBBFHRBBNBLCVSFCL@HRFHPJLLRFH@FCHAXSPC^GJBDFA`@FJVNVDBHEHMJ@^DFDZ@DCCGHCBELDFADA@EHAFBDJ@DEBBVAF@DD@LGPCTFTCTOVUJCFC\\MRAF@PFTCXKVCD@FFFBNLFJBFFDHFJBJAHAjWDELCTARBF@T@FCBGEKIKAEBCFAPELAJDRJHPHbDFVJZCJKRSNQLIDE@KHBFDXHHFABADMJAJDFRHXDBKLCJGDGACGEBEJIXGDEBKLKLGNB@CACAIJAHBJCDJB@FCF@@HBBFCBGBAT@JGLA@CEIMU@IJKHSP]NOVSRQPUIODMLGBGG@KGcICAMM@CDAHBFB@FFFRBJEFI@uC@C@GHEBGAECQWDGFCDG@EAAECEBGFGRGDOI[BUJICMQEAAKPBFC@EEGFKDCDIBADEBAVHDBFCHMJKDKDAHIZqHCAEC@CGHMFEDIBADS@ER_XgPAPU@EIIDKFEJADEB@DA@CB@DC@CBAHAJEDGROHKRIHGDAN@HCFATHVCAEMIBGFKAC@CJETDLC@GAAGOKEMEEHE@DKCAA@CDEBMCKIS@IAMKDGFMQHcHMA[IQAOGKBI@GCEAOA@NABAFCDAACICCEIKBGAGBE@ACGDCAGECB@BADEEE@AIEBACC@CCACAEA@CEG@EAGFI@AC@CBI@GBGEDG@OAC@FDDJHX@HDPAHCFKLKDE@ICCCGCUFEDKDUJGBE@MIGMG[EKSGGGAG@YCEUEOBKFY@WJMBG@UEQ@MDQFIFQJkFGBOAOEMIGIEAO@IDIPAFEFGBaFCIAGEAECEAM@OAEKCKFAAE@GABEEIKS@GCIG@IFA@@F@BSBCFGSECACK@EAEDAFA@EAK@UXGTCTG`INEDOHCFYFIAKBACC@CJCCYFaTAFADGFEDINDRLZBNCJOVKFKDGAIDgBDPDHABGCC@EFC@CEAEMMC@MHC@IEI@CBFL@BITMREFSAGD@BLJDFCBM@cKSBIDCFCPAFUFCAAG@GMBGDODCBAPABIDCF[KIJQC]BEAOMUISBuLqPqJgDUAECAFIJCACIFEBG@CKCCE@ICAC@MCW@ECEBKCIBEA@GECCDCB@DC@@DEAGFE@EA@ABGGA]DAA@CC@GDECCDAFYFGDOJYHCACA@EDGAACAEDOTGAKEMAAC@ADIBQACC@GMEKACAEEE@EGK@MAAC@ECGFM@EDGBGEEI@C@@GAGA@AOFENEDCDIDIHOEMGGBKFMBE@_KEDIBABGHCHEB@LG@EBCHCDEB@HFNLHPTWDUVKRCH@FFPDL@HEHI@ECEGUOGEICSCKFAHIEC@CHFLAFDDAHKAGAABAJ@JCLSLSFKNAHEFICGDGGCCEDQ@CGIGSGQAGCE@GCCBILI@OHC@KECCKKKWKKAKBKCCEAEDENBRAJABEBE@aYIGSIgEcDKFG@OEMKICwkGEUCE@AFJVBFCLMRGDK@QIGAIGQMEKM@MCKBOAAeCKFIBCACAAEBCEODGFCBMAEDKCAC@CFGAIC@AB@HAFE@GCEKCA]BKFEDMBKDIVEBYCICE@KBWJK@KCGEGKAUAMCWCECGAEEAIEODIDELCNEHEFAFGBGGCGAKEGGCI@EHANEBC@GJCNBR@XCFQJKDQJ_ZEDaFMJEXBTBF@LH@HHDFBLCFCNEPEHIBOBKDCDCF@JALDJAVEJBFCFKH_SGCCCGCIAEBEHAJKLKVEFERGLAJCFAVFXDFNPFD@DADMHaHCNFVDTFTAHEDeJULMPCJILENAFIFEAGEFY@KCOCESCEBCBQREBGMCCECKDA^BJAPAHEDIL]LMJWdCRAbKNGFs\\ECCBCDETVVBBP@JCFCXELBVD^J@DAHQVBNHHHDZDRDRHFFDVDFJBX@JBBB@NAFAHHH@LFPCL@JAJVJHAHEF@BBBHBBB@DGB@JDL@LDAJGLEFEFILYVUZWf[bI^@FLRHDfLLFL@DADEJBF@HGD@LHXHF@LID@RLXCFAFEDEDIAIMUDODED@FHHDDL@HCHEN@DJ@NCJDTABDAD@DDDNFbFPHFB@DH@BDFDNBDDH@DFFAJFJB@BBBHCBEBIBCFAD@BB@LBDD@LA@OBAXGHHFBJ@FGDAL@FANOFADBBJHFD@FELDFE@KCIACCAEIKIGKEAKDG@AFAVELBBBHADE@IIEGCMGGAECAIDGCIGBI@CAOBAZFJINAHCFI@CACCAACBG@AGGEOBC@ADAF@BALMF@FFJBH@FCBEEO@EREHFBHDFDBHCBCGM@GCCI@GAACDEJBDAAGLIHAJ@PCHEBACAHE@CCCI@A@@CFE@ANGFGPQDAFFNDNJFKBIFGEIBCDIH@@CEEEGBCTJDCBM@MBCBCEIBKBcLID@FBJPHZHDDDDNBPHTJGVABJAHHDN@PDDCHENERA\\EV@^IVBFAD@JCRAHCPKD@DFDBH@DCBSCEG@AABCLI@IBCFATBbHBSKA"]],"encodeOffsets":[[[109061,36594]],[[108620,36306]],[[108619,36299]],[[108593,36351]],[[108588,36340]]]},"properties":{"cp":[106.684691,35.54279],"name":"平凉市","childNum":5}},{"id":"620900","type":"Feature","geometry":{"type":"MultiPolygon","coordinates":[["@@KGADHHFC"],["@@ĘRĚNŦ\\RBPCĊAâ@B^BúbĊlÚŃ·àŏŠȝƎɱƸʿƑŁÉ«AAFEBECCBIFCJADGJEFA@EC@CABECI@Aʀɽ¾¿ö¥æ[Æ£MYV̍ʆĠ·ÌpNÚhhÛDIHGHOLMNIJMNGZGfQXM\\Yl_DE@PGPALAD@DHPDLADBNJHMPAFGHEBGJ@PDLBJAPǎÞ´õ¼cp¢BĢĞEäEǠIĜðžUƂYÒC¨İůXSLĉÕÝ@ɛQGŹ×KEYSOOSQGIKIIQ{ó£_O]KMCgCÏGKQk_SUgUuSSMeMeS_IaSEiWOGgI[BWJML[FOAKCEECKRGLIUEg@sC[EIB_CMC_QeQQEsG]@yGGLKLODEIGCEIAAGBEKKGQcIGQMBwMFEFC@OAK@IEWRAFCB[@SFeBkWGIaKEIIIIMOiCCCGCcEEYEs@E@_D[CWFqCOBKD_B]HOFI@EAACGWQcG]JqDGJE@K@ZAPFFA¾_LXHLvlNHJBbBNHbFXAbIVMBMM[CQbPORMLMDEDKDIJKJENEdIkRM¬aj|nEqWYUGCOEAINYJiBKDSAIBGCIGO__MSQQCMEIWICBBHFDBHb`EFOJWPYXAJ@VClELcTkAMBOFGHCASSIAGDSbGVWTUJELY@EBGD_HSdqBiCqF@SEKAAIPaL]IyhWLUEDLcPcVGBg\\MHiNGDc`MFmNiXqLI@_FG@QNI@QDOHWFQL@BDDRBHJ@HHF@BG@GGiSqC]LABJNZIPBFH@DEFKBfnīÌaeIIEEK[AOBIAKAIACKIMEGACB@BVPDFD\\@LAFS@oHOPqhv¼JPRZ@FLJJJL\\BRDFPPNJHJJF@BANEBA@CZ[V_JaTGPGZFFVJøZPFDRBTLDF@DEJCHEF@DDDCHXRnhILHJDJADkLCFCRBHFLAHCHFH[XMLGFI@A@AGAAaOOEiBOFMJKBKDmQODEC[@cCUF_@ABBFABc@ĻPčzEC@CLKLQ@CKYJSACEAQBKACAGGI@MCM@CACG@IIGSE@ABEGCAAVCN@\\GB@BCsWKGYMQS@A¥DEACecyECĝÁED@BWGJEFDBCKIQSOIKMKASAGEOFGBE@CCMAMBIFYFMBKCG@_FMD]DKFA@KIGQQCKCAEGYGMUoAA]CUEWFQYq]I]MUG]SMOIYUUCKAICKMQEKQWAEGICG@CDOC³EokcAGAEEgiUMCC@CAGLO@UM«d\\qHFYEEKFSNQTIHOCcIGBKDILIZCDMHIBiGM@KDQAsP\\eLyD]@]@UHWB·G]@ODYTIBs@¯U@E@AH@HEBIAGFCJCDCFDD@DEACFADCEEBANCBGAADI@EDAH@BAAGJ@HIGIKG[_ee@SASMCGCJUI]AOT_CQaqQyAQHMHEFMQi@UJCJ@JUVOLBFCJBJAJ@FCEKIIAGFGBEDCBIAKDG@GDKCIAQEEDM@[COHSBMFOFCDGVAXIA]@SSUBGDECEBCAEGEJOHMBCN@HKLAJBHLPI@IJGIICKEI@EGCM@CAJGTAHA@ICGAILsUcSK_CLOJMNWJWAUB{fW@mTEA_@BA@CBC@CDC@MBETODG@IBGFGSLS@YGUOIMJQXGXMJI@QIQ]KAmF]@KAGGCIiDOGKI@Kr[NELGJGCMIM@WGWQQE@CAGAGIQQGM@EGC@AKIMECCBACEEEACCEAAKECAACCACIAKDCAGNUAIFEBIDEFIJEFENGDCECC@CCBCBEBCLEDECELcD{şR{NqFy@UBkI}q¡FOOKGCFKJCAMHM@AOGS@AAAEC@U@CAIKOAEDOPADBH@FAFCBW@IFOAC]GKYBsVMJOFS@ILQDQ@IDQ@KBED@FIFKB_GGBKFI@IWCECA]JKF]TCDEJCDCBMAIBEPC@EAQFOBAJCBUD@B@JAFI@KAC@EFEJ[HCFALGF@BFPUROJMPUTGBMAKC[EICE@GDEFEJAFBHAHEVGPCXEJ@HCFQRGBC@KEG@EEGDMDIFa@MHKDAHEBEBM@EDGFO@ULCH@HMFAD@FMBGLC@CEGAOBCCEGCAM@CEAC@EDC@CU[KAQFOCCC@GUUECMCEGEAEAGDK@QFMCKIIC@CECBGCCMCKAMOYAIK@CSKEGAACAIDI@@VAFGFMFMCIGACGCCIICIAECQIEBEHGD@HBHGJKGE@G@IJCAEEGAEKEAE@IDEHKCIEIFM@GJG@MHWAIESACDELQHCBGCEECGC@EBE@cKEACKECEAM@OJERIJEDKBIFGBAHGHE@MAECG@G@IHALMJGXEJCHBDFB@LEFGJC@ECGBKJ@FEDMBS@CDCBGBCAEFCJED@HONGJKEOBWGUKM@KEUJCFIFEBMHA@EGMEEBIJEDCHIFOEO@GDMCIBGBOJE@QAK@OCI@QAEAAGAASBMCWBIGYCEC@KEGACIEQ@CGIAeCQBCGGBK@MGIDGAIBOBMAECC@I@EDMAM@GAOBO@IAABAFA@K@E@ECS@KAEAG@CBIAQDM@KCKBKCKAEAOAIGIACAS@KGK@MFCAEAACSCAA@GAASCGGGACGGBE@CE[JQLCJ@ BL@HCHSTGHCJéǄµň_EKE]CeBUD[@SDƍeūaMI[I]AEB]DWHOBOBSE_HYJQDh[^IFMDEFCH@LELAHAHGNGBADNZNDĪL@¥@WN×aXȇK½EīW}Sg@QD[VmTWCgBaHUJNpPÂDRDvIJ@JGJEHUHANMRCLKHKFCFEDQBQJBJGFCH@FJFDD@JAJ@DBBDD@JFTHF@BWXUNG@[CKOSEYK@EOMUBWK_HDGAUMCAEBOJCHCJAFCFKFaFGEY@_I_AUQQKCKECKBM@EFGCC@OFKBKMGCKAIBGFEBKAQDQ@MEO@GE@E_CKEK@IGCAKDMFE@KAOMKAICWFEASMIAGDSPEEEAYGM@QEQ@QHEAIEY@@CCCMJS@QBIGBEBAGCC@MDE@ICIFGAEAK@ICKDCAKKIKAKOMIGMMAC@EFICGAM@ECAE@KFECMDCAIDQBEA@GECMAQLCBENGDEJGBWCI@MHQP@JERBDLFPP@BALKPDHAFIDAD@PEPCFEBCF@`AJCdBTHP@HMv@Np^VJPH|rvZXdXVTrdZNĪŪ¢Ŧ¶ǰrŐvŸĢƂ\\æPƲӠÜɊ`ºňUðĈĔĀĸTVƢżĈÈɄƞƠrPºæª¤Ĝ¨NČtJB@HUDGlobM`MFC@CCCAIGMBQfcFULEDGHUpD@FELJDHHRBR^Pjrrtx^pVrbRD`VbPrfjLLHLJJNRfNrZpLXAR@`J®DRDtRhFR@FCJA^BHBzfFDTDdFtX\\DdRtR\\LNJTFZL`V``|lFFZRDFDTJJDNFHJDFJAFBJEFJp½ĄĎÌŗĞBvp¾ñnN¼¤x~VZBDD`JBBDPjFZNZFDDBDÄ~bL~\\xVpZNN"]],"encodeOffsets":[[[100212,40669]],[[98700,43754]]]},"properties":{"cp":[98.510795,39.744023],"name":"酒泉市","childNum":2}},{"id":"621000","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@DBTCFEFBLA^NTDD`@BH@@DCLGLDPGPARBDVJFBDAHDDABBDCB@DEHB@BBDLCD@KXADAFCDC@@BILFFLBHFJF@HBDJGFABJDBBAFBH@BBBJB@ZIH@DDCJFF@F@BD@NCFABBFLH@DA@EJKH@DGLMBJDBBD@@b]B@FDLEFBBBABADIBCFCBEF@HC@DLIPBBL@BHDF@LDD@FAH@D@BBBCDDDCBBB@FFA@DFFBH@HED@DDBF@AJBBB@FEFDF@BFCD@DBDD@AFOJADADBDIAMBHF@HBF@HBDEHDB@B[LIFBBDAHFFB@BCFLEDB@FGFADEFBBFDHABB@BKHCFIFC@MEAGGAGKAFCBBDGFEH@DADBBJEDA@DELDFFDAJEFGLMDMBEJKJMBCCODGJEAKHAFDJBFFDEFGNMP@HEHBJBDD@HEHOROHEHADCDAACVUGCEDG@AADEHKJCHBHDHDHBCHANCF@F@LHHBDDCTIPAFAFBDC\\HNAELALHNCLFPDFBFGJ@B@DCFJBF@RIFDLPADGDGF@LMJAHBDEHAPCF@DADBF@F@DGPEFEJABKBENCBEHERIN@FENILFFHBFECJDDD@PELGL@HSTJVFDAFCBGBKDEHBFDJTLLBBHMHGHCRHLCRBJBBACI@MNIDBBDAGDELBJADECEDIHILGB@BTFJMHCFHJJHDHLL@DCFAFEHAHDDAFFBDRFB@BDKD@FF@BEFCDC@FBCBB@D@FBFEDBFADCBCVMT@HCFEDEJIFAJIDDHE^WH@XDVOLKJGHBAHBDHFDBL@F@BBAFGD@D@LVBCDCNMBCAA@YN@DDBLF@HBBLDTIN@BALCBCHCFCLCXSJM@GBCPCLAVEN@JCDBDDIDAHGDCBJHREJIJDREF@HEBCD@BRCHAHCDAJ@BJRDCHAROHBFETGD@DDHDJBH@JEF@HKHCDEFBPL@DRFDAHBFDFBBBHDDBLDJ@LDF@VDL@VHPQHCFELEBCHADEHE@ADCDCD@BCHABCDAHID@@CB@DE@CNFJLFBhMFGFAAIDC@CBA@EFG@EIGFEHEDMFECA@GIQGBCADAHCBGFCECDCCA@ADCD@@CACD@BCAEDCAGDCACFCACA@@CDEE@@ABEB@CCFG@AAABGDAAA@CDCBCBAAABABB@CDA@ECA@ADA@EB@@BDACADCAABAD@@EBAECFCCEDEC@AACIC@ACBAD@@@CCECRCDABEBSBAJBbVFBHBPIZSDENEEdBLCNGTDfNZDVGTWsBGAGIKG@DEJEBEPaDAFAT@ZTPB^ANEFEHIVE^GBIBFBBPBLDDDF@HFJBPJHBD@HG`MLKLEJONBB@HGHHH@B@@ND@DAHBLADABKB@BDB@BCFBBEFAHGJEBCBAFLH@BABIDGLAJCDBBA@DB@FC@ADEF@HEPBLCDABBJPH@FABCFED@@BD@FGBGFCD@BCB@@BJBBCH@FCD@@ICABABID@BBD@BBFAD@FODAD@BBRDDEF@HFF@BDBCCK@GFEJMBO@CHAJEBIBAD@FCFDJQFOB[CEAIDGCEBGEGDEJHFKFHBFD@DFB@DEJHFGB@RLDE@IDCDEJC@HDLEJDDAF@HF@BDFAJFDAB@@FB@FDF@JCFC@KRGDI@GICDG@E@GAAMEEBAACBGFEEAKBERCFGAEGAGADE@GBEDDHCDBDHDBJCJADAAMBGH@FCDDD@BCACFEBGJBJ@JIB@HL@FFLF@FIF@BHDD@LDDDADKLADCBAEMBUZBTCVIXEBCD[VCXFDBTZNZRtHTFJNHNBNCJCCC@CCCCECACCBCC@@EEGIGDAEGDEAEFIF[LKNC`DNAFIAIDCTSDABBB^HFFBLGLCHIDGDAHBFFBDHDJBCPEXQJMDMCWBCHENCNSNBDADYJOAGNCBADeIKCIBCL@HDP@ZYVERAHA@EJILAJBJHTDRMD@BBVZNTAHINCL@NDHBBj]DITGXEHKJEZ@PATMV@PDNBHODCFAFKBMDEEG@CBEF@DDDAFE@EFEJGDE@@IWG[AcFSCiDWNeHMEGISAKRmLQHQtZgLUHUGEMQGSRKBCakMgAMAMH]FgIMMI__CEAM@aASAIIGMEWAYDMF[BW@OEKEKIEMEW}YSCGAIOYYCCAMBGXYPULSF_@OEGCAGBIDIRQDGGG@MIMGIGAACBIPICMII@C@CHKLEDEBGEI@CEICMFS@KHSDK@ELMD]RKX@DADAFKBMPCHGH@FCTUJERAFGLCBCDGAOJM@EGOWWEKAKBKFQNUBK@aDWP[HUCYGIIMD[CIMWEMBkHG@CIEO]EEECOAEAEKAIEEWAEBKJINIAAFA@GAGEEIOGIGUGO@UIACIEGAKBCBEBK@MCCBUCsFEAG@KDGAGB@@AHCBg@AB@FIEM@IGA@QLJTKBAB@HCBGCWSSIGGQESKEIE@K@CCKAOAIJI@MCEKCAMAECCAEDEPOVBJJF@FI@CBEFCJwTEEOAE@GFEACAKC_SEIAAA@GHCBI@OGAECC_@CACAQ@EE[K@CCEMCACK@CCACC@CAEBIIC@EBMEEBIAG@AAIACAEBEAE@EAABECE@CACBCCCBICMDAAGAICCDKAWFHLJHDL@DIHKBYACEACDOCEEAEBENEAGEKAEDAHKFICGBIAW@UGABIJ@HABYB@JGJCAEEMAEBAHMAEBCDGLGDG@ECG@CFGNCBECAFA@IAILIBCCI@IJMACBGLAFGFCFANHNOVQRUTMPO^GTIL@JNVFJ@DKBIHS@ABAHEDAA@GE@EDA@CIIDGAIBBJBD@DMAKHKLALCFWHIJAFHFBDCHIHKDALWCQGCEBINIBCBAGEWGECGA@LCFKJMRQTILYDUICEGaGOQIICKBOFEBADBFJLFLAHEDS@E@QASBKDCFiXGBIBIAGEECAEEIMKEAEEC@UDWLSDOEE@QB[NEDIDUVSPSDSEODKHC@@CBEAUFA@CCIEAGB@FCBEBKCAFGDDHCDY@EC]CI@GNGFCAMUIU@EB_CEIA]HODWTGBEDG@QEKKOIEGGQK@EDUTKDMAAAGQAEEAADAFDN@LGPCBABA@@FE@ADC@KFCFCBADC@ABABADAAABE@ABGB@FCC@DEDCHAA@CKDAHCA@DEBBBCB@DE@DBADGAANG@BBKHADC@@BC@@BCBAFEAABBBABAAABCBBBABEJC@CAIHA@BACAADE@@DC@@DC@BDG@@BEBGLGBCBC@CFG@AD@DC@BBADGH@DEBD@CJKD@JAFC@@DMLE@GJGDEFID@DC@ADEB@B]PCDGBCDKFC@OHG@ILÍ|BFCLC@ICCFBBLHCFDXAJBBF@BED@NJFBDA@I@AJFFEB@BBHBDGB@BBD@@CFCDBFDBABKFEJAJFLLFL@FEDFFFCBBKR@FBDFBL@FCDIDADLNANDHANIJABBDLA\\DTAH@DFFD@F@RIDC@GCIB@XA@BAFDPBDDBNMFBBFAL@BHAGLFD@LABGAABFBABGACBATC@EACDBFHBFCHALBDAFEB@JDDD@FADQBAB@DFFITCDABSICBCFIH@DSVADBPCDC@AIBAAA@BI\\ADE@@DHHF@DEDAFCBFCF@FCFGFAAAGA@SDKBIDEH@DBBF@RJ@FCJCDFDADB@FCJBDCB@TTNFF@JCJGH@@JAPFABB@DHJHCDCNCNHDFFBHEHR@DCDAHGLEEG@GBEACCEOSDCAIDEDEHALGVBBBADCDDB@BCAGB@HDFABDFCDC@ECC@IBEFCD@BD@^FLJFBLB@FCBBHLRFHHDHAPDBBHMAEFQBCDED@HBNBF@HRDFD@XBL@@@DF@DFI@AAEBADBD@HDDDBNDBFABAABFCHN@@ACA@@HAFBCB@JCDDH@HADCB@ECD@E@ACVO@ONF@BBB@B@BAANBB@HJHGFCBGGGOGCGFFT@BBHBN@BEAGKCAAI@ICHCE@DDLEAABCHACC@EHBDDJCFFHDJEBGDELGH@DABIACCE@IN@DEFCBCCC@CFEDEFAREJIJ@DBDCAGBE@ACACBC@@EDCACFC@@DBAC\\KRECEWIH@DEACDCCKCBCCCAGCBGDADCBAFEHIDABGAAOOLC@ACAQCDC@CFC@@ACACDAAABABQJINEB@CEDEJ@BMISJCCAEKHCD@DIACBAFC@@JAHMRETGHGCBABCGB@BAAMACGGCKHC@AQCAKDCHBJCN@HBDFBGFA@GGCSAKC@GDC@KHC@ELE@AEEACFA^ABCHA@C@EE@CCE@IDGAC@CE@CIAFCDADCBC@@BCJ@JE@GEADCAOFE@IF@CCGDGAEFK@ECCBEEIGECAC@GDAACGCAABILSHKLGDKACGEACJCBCHGBEJG@EDAD@FKTMPALBBPDBBHCDDDGJELODMJCJMDB@DCJBHALMJCBGJB@BBFAALCFB@@BBAFD@DDDBAVDDDAPCNGJ@DBBFCFKFAFBDDFADIBEDEGA@KRGDWEGDABHH@JBDALBJLABKF@DCDJHD@HCHGFGB@BFL@DBDLLLDHJBLDH@DEHDJADIF[FOTA@AAEODEE@ACG@KNANEDE@CBECGHIEGBWVQTA@IEKAGFMD@BJFBFDBCJIFID@FINIDM@MEWH@RSZ@D@DF@AFB@DAD@FGLEJMD@JIFCFHCHFJBHBDCD@BXITOBCDATERBLEFFP@BJDBBFGJIDAB@BN@RFN@MF@DGDAFADEBEFK@CDCF@LB@@FDD@FCT"],"encodeOffsets":[[109000,37504]]},"properties":{"cp":[107.638372,35.734218],"name":"庆阳市","childNum":1}},{"id":"621100","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@DADEFAD@DDF@DAN@FCFDFCJF@BNFTFRHJA@AAAHA^FBB@DNJFFNHHAJDBDD@D@F@DKJEHDJCHDBALBDDbDBCH@PIJA@MEACEE@IBEACAEICA@EE@CCCAEBEIAOBCSXUVWPWDEFHDBRGJBHELO@QJCBAJCFGHC\\GFCBI@CCAAIACC@CE@MDEDAH@LAHB^KDCFBHCJAAIEMBCHETEnCH@LARYFS@GBQESBKPMJAHCFADG@EDI@QHKXQJARK\\OLKLCJEhSFATKHQFa@GAI@_D_CQ@IBCCGCCAEQMEMGGDMOqIICUBGAGAKEAIBGAGEBOCUEY@GFOJMHEVDPCJEBCBIHEBETCF@REAUJG~KLDD@HEHAFB@BBDAFBDjEBC@CHIBEF]HSLA\\ARBH@NBBPDFAFGFCHAFDBH@PCBJFFNDXEPGPCL@HBHFHJj^FHLJ\\LFFTB^CJKRAVTNHNRFDJBFCDIFAFGBGJCXNBFFBDCPMFSDCDAFDt[HELMBaDQXcNI^KJKFCBGBOAIB]LCFDDDHNFARQDAFATDDFDP@LEZHFFBJEBEFMJKDINOVKfIFCBGESCSEUDMbGNGBC@CECMOCEEWBUDEBIHKFQFELULKBIFGFAJBHDDDHD`THEHGAEFIBUCIBK@IDEDCLCPAJAFGFODMDEAKCEGGQDUN[JGHOHOJGLSPED]BEK@EDGBOEEOCOGEGAI@IRKPCPGHMEKUQCG@MCSIYKOGEOBCDajI@UHIHCFIXGLIFSXEDIBIAEEMIaOGICK@KBIEUCEEDGLEBGB@Q@KKSE@IJGDKEW[OMOASDMGOMODCFKHIFCCEGBCDmCKEIGEEDG\\@FAFEJGBOCKGSWEMV{COGOGAQOSaOGE@GEA@QDGFUBABADBNDF@HORIDADE@IDG@oI]@]BMBKDUBYPMFSBIBCE@GDIHKHEHAHI@GCKACUOGAiSGGC@MBAJ@BEAGCKDADDBBFAFEHSEOJC@MGI@KBBFCDM@QCKMICKBOHCDMAACMGEMKeDSASCOMcQIQCGBKHSFI@GDGAKBi@QBIBU@O@M@eGGC[QG@KFKLIDQ@MEG@MAYFQHEDUDIDU@Q@MCOGKGSaECCGAAE@AGAC@K@EFK@GEUCGOMEIAKBEAG@OHELCDGNMHM@EOUKKUAGC@C@CJA^MJAMMIAACDGJ@BAJaAGAC@GIIAOBEJA`@JBBFDBPAVBBCF@RDDBRFTJbLRDESKWEOFK@GKM@CBAHE@ICCKGAGDEAKCIGGEQEKT_HIJCHMRKPALDJHLDFBLNF@LCBCAI@CFEAKLKDE@ECADK@UCMCCCEEKBQDMPAJ@rbHADCDG@IE_AODOAOBKFAH@VJPJXJT@\\MLIHCZKXERDLJNJVHH@PAj@`AXGLIF@DEASGQDGFCH@@EACEEQE@EDE_CcHU@MAYGK@aEMAoDI@G@QGEGAGBEVk@SAGAEAKBIT]@GMMMKKEmKGACCCIDM@ECEQCEBKAGBECKSGE[IU@ICK@EBGDQTGFCDEFMCCDKCKAIDGAAA@EFEBKCAOCKBIAKGAECESNC@AGAAOAMDM@KLIGIAOMC@CHGAGBCADM@AOEOQOIEACBAJC@ICK@EBCBCLGHIFG@@@FEAIBK@CGQKGABCJKJEJABQBIHM@EDAHEDS@AAEAKJIBE@GDEFBLCLCBGBABAFGDDFKNBFJFHNCPEF@DCFFFBHCFEDGREHKXILURCDG@UCKGOAMBIFCJADK\\@JGPIFiHG@SCwDECISCYCAKEKDYTaDUFGDIJSFEBWEKE_WiMAMBIEAC@GACBECGEBGEGK@ECIA@CASJMRSHKDG@GFWPOZOJK@UJW@GCUKWKKGD_CyBaGGCUEECECCE@MMgWSYYMCONYXGHGDIHILsbcPMJGFCHEFOZGHILMLEJMLCHEFEHIVMLOJGDIBaCQBIHUHKAUKECIAIAQ@[HQHaRGBQAiMS@EHCFGZBRJLHDHDZDTNHHPZHNJ\\JNJJXNFHJDHDd`FDJLFT@jETCTANJZ@D]JADAJIHBDQLAFCFGFEHCBCXDHDBJCJARHRBTFHIHAJHHBHDFLDJBRHNBH@XINAFDHAHLbAFDPBFJFFFDLBLHL@HCHBFFFHTAJUHCLKJCRGHGFBDNJJBFDDPDHPFTHVDjGJ@DB^IPEfIJCRATBHBJDNJL@NED@B@HRDBHCDB@HAHBDHFNBMJCDBHJL@DMPADGDWAABCNBHATABEBGJIFO\\WJAFBDTJDFFBJFZHNHbXJLDDBPCJ_d@DBBZHBNCF@JGHCBQCOAIDOBIB@DDFADGDY@GBIHABKEECMWEAWN@BHLELGJQLCF_HE@MF[TEDGBSASI]GCHAB_TC@GCC@GDIJC@@EKBIHCDAJBHDHADYHQPIFCDGBGHKNAHBDFJ@BKLCF@F@BHFHLGLBBJHMPMHJRNDDHCHGDGHIDIHEAKMCFCP@NJ|AJDZAFID[@UHGN@PBJHVNZTV`fNTFfHXBJFDPJFHDHLLfzBFDNCH@XHHPBHDLJFMRH@PBDDDANGPORGHDJJFXDH@FDBF@NBD\\VLFFBHHBH@LBNCJQJQBGDEVDHIFAHEFCHEBMCADAFIPAFS^O]fSNIDMNCBILIFcbw^]TIJQNIVg\\ETSVKZSHa@IXBXQ\\eZSGK@OZEL]bM\\IHIDpDH@TCPBPBFHHNDDAPHJJNVHFRDHDPDJ@PEJIJODM@GJQTGxDVJHFLRDPJBjGFAVUFIDAFDFJVDLFHCJEJFHHXIBGAG@ILCHBRIHGLBPK`IB@DDFHH@FABEDGGU@SDC@cDCNHPDFGAMB@JF^DXCNE@CACAEJI@CGK@GBCLABCBGDEFECM@KDGAWBABBFPNLFHBDFBFAXOJMHCTEHCVQHMHCXGZEHCFIHEJGL@TBH@DCDKVWJAT@PCNM@IBCLGJK^GLGDINKAIBCFEVEN@HADUFEDKDCHALFDApeF@TbPFJRDCBCF@DBHLHARM@KZ]HOPA@ECCKEIKAGDCPBVMFBJDFAAEGE@C@ADCdCLBJANGL@PBPEFBLJBFCJ@FDHXPNFAFHJ@BEVABEP@DHFAFEJBDLFNAHJDBDBHJBB@FEFGDM@A@AFBLANHPBFILAHBDFHTV@HAH@FFBJBJCDDBDBFPBHDDL@HBJBDLHFLRFF@FEDBDNRV@DHLAJ@PAHDDFPBPBFDBDH@FBF@DCHAJH@DF@DPJ@JDBDDFCF@BAH@DDFALNCNEDAJFHAJKPAFKBAD@FEFLZBJAHBHALBJDHFABD@FDF@F@RTNFED@JPHDDBFENAPP@LCHBB@FEFDPHFJDJAJC"],"encodeOffsets":[[107009,36885]]},"properties":{"cp":[104.626294,35.579578],"name":"定西市","childNum":1}},{"id":"621200","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@FLFHBFFB@B@RDLHBHFH@J@BDEHBBBJRBF@DCDFHBFCDEDAB@FF`GXJB@@IFCFBFBJDJJBB@D@BFBD@BGBA\\BDADMBICCI@ACHCBCFCNQBSDGBIFKAYAOBEBCLAHGFDD@HCFENADA@CAG@GLAJ@VFPAADKFG@AFCFHFDCH@HETCJE`CHGRKNKNENGLDfV\\IPIHE\\OZQRSLSTYLKHYJQV]LKHKFARFJJLFHHJEFCHOAESYGAI@MEGECGBEHIXEVQDECEGGQED_\\GFGDGECE@MHCC@EBCLID[AO@mDKKGEIJQJGLEMSEMAQBKDE@IFADEJECEBCL@ZGFBDDH@BU@@FBBXJJABEHED@HBDFBPATQB@FDHC@CCEIECCAEDCTCJFTCFFBFCLFTDFD@FF@XHHLDFDBJAHDNBDVNVHL@TLFBH@NGHHEJ@FFFHB^DJCHGJBJCHGRCDSJKKQAODGHIHEJFBFRDJNBDRCBD@PFHF@JEFFF@FBFHHANBJ@JBLAHIFQCIAOBCH@NCJ@RCHBRERRFLF@NCB@PFHLHFHBHBPFL@DBNETHJFXBHBH@ZHRAZDNGFGL@HGNAL@JKBSFEBEBADDFBVAFAFKHCH@LKHBRCLFFALJHNHBB@DENEPADCHCL@HEDAFARBTFJHF@JAL@JHFHVPBLCFCPBHJBHCFBJJBDHBBTFH@LJNDH@FEFDJABGF@FFDBHJHDF@HNFRDFBHAJBNCPD@OBGBAH@DCAM@MNIJ[DIAI_@ORoROdATB~PzZnZFHTRLNHX@RAJFF@FP@HJHNBHAJ@LCJALBX@DBD@DDBBENCHBND^ZHDHAHAHEPMDIJOBODIDKHgFM@GFUDMPUDECK@CGCEKKM@CC@@ACGIO@C@AGBEACBKCs@IB]I@GD_FOBSCW[[IGOGKMCGBSPg@UGSUYCGGEGCCGKKGOQKCGQMCEOEGIDEFEFMBA@a@ELMFA`@ZJABE@AD@BFANHBBABGB@BHDD@HOF@H@BABMBCBCNGJMHOBOEGaQMKCYISAGBGHEPGF@HCFEFMDYCeBOESGMBEDIVIJC^@XATIJGFG@EPUXmHGT_LkCABGAMDOCAACEG@CJC@GM@[ICOJgIYCEACI@CEIKCGC@CDGBI@MDC@CGEAEB@BCDALGHAAA@ADOFEAIISKGBYTEFCJ@tEZBLAVEZEPCBIFQDG@UAG@K@KEO@OE[YOKICOGWAGBGDKDYVGBKBICUASGYQUUa[_GOAKEIKGCYC_JE@GHGBEBIAABCJKD@BBNGHNHH@DD@BEB@BIEK@QCDOYAQAE@GHN\\CFBDVCJFJHCNSCCBEBGJSBABADE@CBGBGDMGGAIIMEEBGFIBIBGAMOICEGMBEF@P@FA@G@ACOAMEMDGJEBYBQACDIALKCG@GAEKQIEQ[_[ICS@EBG@ECEICOCCQGCSIOQQ[QGAMKCGBSAGAEGIGKEKDWFKBODiCQKaACCEQCGBOAeFQFU@a@GBI@ULSASGGEAEtNKJETQBGCG@CAEKECC@IDMLMJIRIdAJCDABGCC@GBGBCHELEXE^@NEHEJMVMPAhFHDjBVCHCHEFGXU`MNGFEDIBO@SAGBqAEIIEACBEHOHAB@PCFEDJL@DCBOCE@CB@FPL@BJADB@B@DKDEFBDEFIDGCAG@IFEMEIIDGLMSOOEOMCEAGDEDCJANFFHNFDBFAJIMIEEACBGDEBGTBHE@CAGECEBG@OKACBGAMBGJGFKLG@AEA@EAAEAO@CCACCS@EFGLKHADA@ODMMM@[EGAICGYUQUa_MSMKGCG@EFGB_NQB_UmWqQ[O]KSAIAOB[AcGG@WEK@GCGEEIIIMES@KCK@UC_BONEFEPUZEBM@KDQEIBEDKREDUA]OC@CDCFC@IJOHG@OJUFUAUBSCQMCECEAQIeBIMEG@GBKIIAABACBCD@BEF@BCB@BEJECC@CGA@AHEH@AEDAACCBE@BCC@AABAF@@CFCCGDCD@BAAAA@G@ABCADGNEJG@EPQHSDAHSDMFA@GCKLCR@FABCAIDID@DF@FDDHAFKDQIG@QBC@AICCCGAYDM@QQWIUKI@[IGHEAECMQEACE@CGKCC@EACMGI@SCCK]@OQAEEEICI@QDUGI@KHQRKFQCM@IBEAGQ@c@ECCICKAAADE@AC@O@MCCOAAOBCGAA[GGCMACACEAAwIKCEDGJMJGTEFGPCBITEBK@GDKJMBO@QFODGAIKOIMAEBGAGBEAMICAIBM@OIUKMC[IAAGKEAM@OGKAY@EAEBICEHIJ@FBPADINCDUNMRENKDUNIBGACECIGGcOOBUAUDI@MGSIIAEDIJULQZSVKDKCKGQEOCWBOCG@OJORGDKLUNYFEDEHKVBLCLOHADEDaJEA]MMAGFIV@JKACBEL@HCB]DkO_@ELMPEBSDMFK@@BHLAFEDeLGHAHUJGHMHM@BH@HIFAJC@GDS@SDQAOFOBOHOCCJG@ADBHCF@NCTAPINCNIJCRBJFLJXDjBFNBBB@DDDLHF@LGNCD@LFJALCPKlHHDPPDVAnHP`JPJHBVFJFBFAHILQJUHUFWCSGSASDIDOLCF@JDFFFNF@DHHNPBLFHFFLB@DEDGBEAABAFDRbP@DEV[jIVIPC`CFCLUhKlAVDDAR@PAFIJBPIXEFOLBJAHIHBDPD`RL@FARSHGt@XCPETSJEHADFCHEDC@SN@PCB@FEDHFLB^NTDTC@BpRFDH@DCTERBBFFDHDHHD@DI\\aPaHGBG@QDCNGBCBGIMBGEOAGBG@MDSHGFCNAT@RE\\D^CTFXBTDPHFJBFHjFTPVJLDRBDRJJBfAPBV@^ELDJAFDP@PFFFGPCDEDUHYNOTGLANNPGHINAL@DHJCLANBHDB`NCB]LBHAFGBINKJCJFT@LADMFCDGDEHIFGDMFWN[L[HMBWJKHW`EDC@IGCBIPAJGLBBB@JADCBDFAALBPFD@DALEHBNADCABDCHEBO@ORE@CC@CCEABABFNLJBD@BKFE@IEEGCAC@BJKT@@CAU@ABBBNDAHS@AF@BNBAHNTRB@BADBFD@DDH@AHEDEFGFAAACI@CGIGCB]AEDADADDDGJANBBTIFF@DAFELALADCBG@CBIHEBKN@DJNED@BBFbXDLNLNNHDFHDDBFHLDJAFQH]DcJaASBYNIJCFBHEX@FCFUVKDWZQPOHODODUAK@IDI@IDI@MFMNINEFg\\MHEFEDaRgZUP{`OFaPrhe^IFK@QJGAKEAD@DFD@HEHGFIP@JADcPWNMTAPCH@F@HJrEZ@JNDZZXTNh@NDFFDFDVFHDbHzA`DHCLLLXDV@HIX@VILYPOPEX@HCHGLQTINBT@DJBFDL@FHAHHFFDDAHBD@FBAJBNjN`XLFXFFATEJIHCVEbCZSLCLFDBDZJTFDxCTDH@jGJEHO@IL[BCDIJENAPBLHVDH@DCVQJKLWFGHQFCDEAGEEDE@CFEDOGMIEAELMCEHCBEBAHADADKAKFEHCF@JALIFBBBT@FCBGFCN@JGRABAFILIDIBALHHR@DALBJEF@@H@JEHGDKDAFAL@JDD@BIDAFBPJPRPF@BCNDBHAHBDGD@PNJBJHLKN@NCPBBBBHD@TMDFBFLHJBLAPDDBALEF@FBBHBJCLBLDDCNDFEDCHERSHCFAL@JDV@\\JHFLTFDHALBFARDDF@FCNDJDDHBnLLFNLNN@HS^AJBLBFBH@TUlAFBHFHRHH@J@pCNBbFL@ZHNBV@dG`DCF@FRFFFBD@FG@EDCHHRBTL@DER@XC^BNDVPVNHJHCFHDDBFFHHD@FDDD@JCFFJ@LCHBFDDDAJJJBL"],"encodeOffsets":[[107640,35308]]},"properties":{"cp":[104.929379,33.388598],"name":"陇南市","childNum":1}},{"id":"622900","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@JEH@RG\\NDBJEBCBEBKBCD@LFHAT[JEZ@JEVHPANFFBFFHEL@FAFEBCBKCMCEAABUGKFGBCAC@CPCDC@CB@NALBLENJFHHDBFHFDDDJ@VFHBDTFDGBEBEHGJBHAHDCJDFF@FEHCJ@FBRCbFTMLAVIJ@B@@KBEFCBMBC@GCG@CF@LFLBFDHBFCFEDMFCDG@IBCFEBGLKDMFA@CJCHG@EECAC@CKC@G@ECEBCLKJMEGSWGI@CHOBKDG@MIACOKQGEUIwCSHIR@HCNCFAFMNOFI@OCGCQCGEMUIIOGCBMCGGCQDS@SCGoJCJGN[^aFKPYL@THfYR[AWJWb@TGLYTUFSh[JURMJI^Sx]daJEJKDANMJCTM^ePT]BEJOBEBCNDFADGFEBGJECGFUHCRARIDIAM@KAGGGEAKE[UAC@MAEECG@WCIECIHGPQHOBMCCAC@OQGENKIGCOAGG@WDGCMAEeyKKCGEGOIECAIGWEeMS_eSUMYGUAI@OHMVG\\@JCBECYBII{@MDODELNFBJGJCHGHCDGCGMCIQNGNOGCCCHMGKGE@GDELK@AEIACBGLMHGHADCJEMABAE[CGBGCCKGEI@EEAAGFIEEGBEA@FCHCNDTEFIAMGAACBGASGSGGCEDAHDFVT\\DL@XDDF@LSZaZ]PKL]LWPGFaPIJGLGDEBgV[FYJaTi`UJYFUHUACK@YKGQEaDIBIFMDGDeFUHKCK@GBQAgDSHYRSJ[VgXCJGHKTWl@FINOHWAoBWAGBsIiIc@MDWL]DOHEFIDEHIREN@HEFIHiCKBSFOBcTYBaMEMAOCOYMG@MFIHCHEV@JBJBPAXD\\BZJvCzCLIRCP]ZEJGFSDSGMKGIOGWEK@KFYRIJsCHKJIDoH]HWJYNIPFAPNFPFDJDDDHHPD@FFDDDAF@FC@@DC@C@CAmIGAGKEAG@OD@B@FCF@B^PDHFDLBT@^HJADBNPDBD@VCFBBDCPKNkZKNEH@PCDKH@DFF@BEFAFDFJ\\APAHEDaFGBCDGLAJGJK`UNONKRGTEtQ`APDHNHBFCRBJRDRNFVFBLBNFR@HLDFPJDHRJFHHFDLVNJATIVCPIJBLJVBVEDCBGBAT@XCNHJ@`IF@PBHCLSDAF@HDF@NGFAFDDHD@EXBHLPDFCLEHEVAD@LFLCPDFCHABBRMNFV@PBDFFDFATBFJJHNLLHNDDBFGBABAJELIDILCLBDTVFBNCFBBDKJAF_BKDCH[EEHCHEJG@CJO@AH@BKAAGO@@LCD@HO@EJDNDBPDFAJEHAHBJDFJDBTFFDF@LHDRDLDNANJFFF@DIP@DDBFAZBHPAHDJDBFBDB@HLLCF@DLFAFBDR@F@TRTDTEL@HCHBNAPFT@HHL@PHH@PCNFBNDFDBHAFGBIAIDCFAFCBMJAPDJEFKB@L@LDNIBEBKBARALHJ@HDF@HCFGBGJEF@@DDBPCX@BABMNALEH@HFFBFADEBGCIDCJ@LDLHD@"],"encodeOffsets":[[105759,37020]]},"properties":{"cp":[103.212006,35.599446],"name":"临夏回族自治州","childNum":1}},{"id":"623000","type":"Feature","geometry":{"type":"Polygon","coordinates":["@@SJMASJGBWLUHUFK@WEyQIASBSCE@IBEHQnK\\EHEPBBANEDMBEFGLKFEBGAWKGDG@CD@NET@DHLEHALIPEFOFMDMLOZCLAHG^AHCNCJINGR@JADGL@FBHJLLHBZDDTFBDBBAFEDEB@DDVAFGHENEFCBYTi\\EHEDkhqZYJQBKFKBG@iAQCOGaKG@IE[@KBPQ@]ASBWBUDS@McCOEQMICQEQ@UFENCBOBIFIBEFKFQ@IFKHMDABQHC@@G@CCCE@ABIJABEA@EKEA@EJ@BDB@NG@ECGDCAEEA@@B@HJDJJRFBDEFBFABMGE@A@ELA@GEBKEGE@ENA@CA@GACA@EDE@ADBFHN@DC@KFIACCDQQCGFQDBT@BEBKCAAFUGAMGACAKEAO@ICAAGIAKMc_@CBCFWFA@BFNPAHFNRTFJHJ@NDJDTOFE@MLAFL@@BAXJDIPCFEFCVGPMPEBQDiCYCQGMOIWGGIGEUMWCC_GKAIBgBIAQ@cEI@aH[JEFGBSN[LEFOD@HDJBDHDBD@NCNKHMFMDCBM@MDKGGEMIGGAGA@W@YBaP]BQDIFGH@LNfDRHN@FAFBHHZDLJNHZCLOdEFGDKBQ@KASBIHKPEN@HF`FFRDFDDFDR\\TBDFPCHGHCFET@NCFIBQBSIGBADFVHFBFDPDLfGlFHFFPDD@B_V[ZKBIAGEYVADBPHJLHBBGBEHATCJBXGLWTQJ[D]BULCDMDC@UQGAQFI@SEM@[HIFIHCHEACBCLDbJhAPCFEFWPKLC\\AHGJSRKFQF[NE@CAYBOAM@MIOCGGACBAHEBCCGBKMMAKc@QFOCG@IBMDMCC@ISCCOE@GBIACCCCQCAOBBCAEGCKQMEIECQAEC@ABMDKMDSCIEG@C@AEODGACEAIACC@KAECHU@E@@QHCCSBIAYIICSYBEhS^IF@JEPQNIJyEGOCKLKBKHG@IFONOBm@UCIAGQQDC@KEcC]BKAIGYGYCKEGAGBKJGCABAJCBSDIDA@GOKMIaGOCKCEIEGEAKKSCcGOAgCCEBI@EDG@AFCBCA@EEEEAKDCLABE@GCACAECEE@CBGJQA@DHDBDABEFC@CCEOS@AA@AFEACAAABCJFXDBREBD@DIBEJADOBECAIEEECCACBAGCAEAABSXEDQECEKS@EHIACE@E@MN@BHBDDBDEJGFKEACDMAEGECAKDA@ACBATA@CCA[@ABKJA@CABAFIACCCKDABBDHD@FUAMN@DHB@BA@U@IBAA@IACECEAA@ADHFDD@HCBGAIHC@KE]GMIEKBGDCFCRGJMFA@CDCLAFANKJEBMJEHKJEHILEDEJGPYRQFIDATCTMPaBcAKKOWQMMCGBCFGJCZA^BPAR@ZENIACDGNOPMDECQECME]AEAOKCEAMBKXIHED@JHFFLPHPJFHBLALMBEAGOOIMIS@GMW@KEMFKbiFQDS@SBCJILCVE`BTGHIHCZUHCTEhCJCHGL[DCFA\\IJG@KAIEEEAI@SLI@EAEE@AHSDENIFKBCAEKOCI@IXSbUDC@EECMDCBOTIFC@GCEE@CBCFCNCNE@GACIAKFQDKACGEKEIYESQMCCCAMGCCQAACAQBCHIJG@GAEGLO@EAEECGBMFIJELEDMAOQICOAM@GDGNGJIFG@QIIAGBQPEBCACGAIFWCAI@OGQEAACEEUEOIIAGEKGEUE[OII@KFB@BHA@CFENED@EM@WFIBEFCDECMDGDOAIJaEKBGBIMQG@CCE@EFEHCBO@CFC@K@YNSZADBHIREF@FI@CBKBIDEDCDKDBHKF@BB@@DF@@FIAA@CFAEFCAGHC@AQI@ABC@AGACCBAH@BACABCF@AGFC@ACAC@AABAHBBCCCIA@GKI@AFC@GDCEADE@CYK@AFABACC@CLABCAAKC@ADEAAE@@ABGA@EBCA@ABE@C@EAACAC@AB@DCBOI[E@WD[NQDMCGGeOE@CFMGUBCEAIGWO[IGIEMAG@CACGKGKEGQCEAKCGEGOKGBGH_FKJSFCDEXBDPDHFHT@RDF@BCRH^AHGJEHCLCH@JCF_JWTEFMEEG@FCDAFUTGHADDL@FAFEDDLH@VFLP^@HFBBAJHIVYLVBPDDNDXNNXDBRARFBJGJAFFXAL@HNV@L@NHTJLLJLDDDBJFDF@FDH\\ELLLJHH@HCHHNBBDBFaDIHAFHVBJAHEFUFKDCFGLCL@LHRKLAJDJJPDP@FENAHGJ[JEH@DDFBHADCDWFQJIDMPKJCICCIEAKEIAEDGCGFGBCEK@GSCQGCEKDGNCBCAS@EBC@QQGCAC@IMAEC@SAGIKEOCEMACGGGIBKCKAODUJUEKFKGEASH[DECCGCEGAKAGBABAFGDCDEP@FIXBHDDBFAFGHFJALFPCHIFAHAPHRENBFJLCLGL@HELEPCDOHKDEDCLFP@JBNGREDI@GAEGGEEAIDABCJ@RAFCDEHKFG@]GKHMAEBINGBSEOEQOMEWAWGAAGBGFEBEEEG@GDO@GAEGGUKmIM@IFaLMBIFCAGGULOCG@WPEIGCA@GLEAGEMBIBEJKBKBMBKHGBGLQLIAIIIEEEAIWAKBIAQIIGBIAAK@IDIHBRFFLHCJHHABIDOLCvDFFHVNBRB@L@DBBD@FCNCLAJL^DPCLE@_VCFMLCLKFEFCH@DDFFFBDAHADEBI@KACBULOAIBGDBJADEDEASEOASBsNGH@XCFEDKBEAEEMXEFE@IEMAOGGDIRENCHSRG^GLCLWLIHELCBGBABBHA@KDMJ@F@DPVIDGHGJEFADEDECEBAHMR@JGF@LADUCIFCF@HAJ@JDJURCHFV@DSHKJGEC@GN@JABEBCBAJBLCFOVQLIJAHILCJCDK@CFCBO@CLCDYJKHCF@BFHDNHDHBLH@DCHBDLFDDBD@JJRADED@FRHFDNRSPCF@DBDNLDF@LCJAJFFJDFDBDCJBFN`DBP@LN\\@HHZDFH@HLHDLJFJFFN@PFJX@VCNDH@LDJAXNNKFC^KHBLHD@NKNCNKHKRGHO\\OBDFFH@HCDADEBS@CRJRBJAHEFATFJFLGJ@XHLERBJEDD@DBDJBPCVQHCNDFDJFHLJJB@@AFCREjAHAHEBCCGBGEGCMBCCGDEFCNAPJNEVEBEGC@CHIFCNEJETBDEFER@NCF@NFHADC@CIG@CBCF@HABEAEIBCA@A@CBAFAHBTFL@NALDHALAJAHCHGHELAT@JAJEDEDCh@VIRAXA`EHAHGBEGM@EBCJEN@LJD@JCF@NLRLPBD@FCBGBAN@FCBCAI@CFEJ@JBJDHFF@FA@GDGLGPEDCnAFADI@MBALATGDCFMFC@AEIIEAAFIDCDKJKPIVIPADBP@BBFNDDH@FATUBG@CGW@EBCBANCD@FD@DCLFJFDFC@CASBCJGNLJBBDRTDRDF@FDF@LPDN@DFPHL@LMLFNDLCZDLINDJHHPBFMVBBD@ZCLC@A@IFIDIDEFAVAJJFBDAJETGLIH@WD@DHB^FNF\\DJ@DABMF@BBFFDDDH@ZAPETCH@FHF@BLHRAJFHDBZBEPBLADCFYR@DDD@DFBPAJHJD^APCF@DDDH@TAFGHAFJTBHAFEDABBDAJBBD@AFBFHDBFADBBFAbAPI\\E^KJAJGNAPADDDLCL@LFFTLBDJLBHBNAF@HBFNHDFNbBDFDDADC@EB@FCJADBDCDBFAB@@AB@@ADAFC@BBCBBBADBFA@BH@BBFAFFD@@BBADDDA@BRHHFBDD@@BCB@FABAAEH@BCBBBCBAJIDBBCBBBC@C@@DAAILCA@@@BCB@CIBEB@DBBA@ADA@AFCBAAADBDE@BDIDFBEDBBCBAFC@AFDBAFBFGBCJC@CFBDADBA@DCBAFE@BDABEBC@ADC@@BGDCFEBBDCB@FGDAFFLEHAHFBBFILGPKNCVUEKACDCFMHAHKNC@KCK@MNKF@FCFW@KAGDKASDKCGBMEADQ@YD]@EBMH]FGFDPCDWHGTETGBKAQFEDERAJC@CHCRGJANFF@DEPBVCN@VPTHL@HKLEJBJIJBJCDAHFLBLCP@HDB@VFN@DInHdBBJBBBA`BNAFEHADDFLFBDBFAFCDOHAJCBCL@RBBTDJLHHNBV@JCZPD@FADBNJH@JEHBFBNCF@HBL@XGLE^ENBRCAFKNMJGLEF@NLLPhJBJDHFBH@FEJVNHPHJFNFBNBHB@LNHPDBD@HBFLHD@FCBCFCNJH@HCF@DFBLRLHLBBZ@L@XHNCBBDB@LAH@FHFBLBBJ@LGL@LIVCRJLALFJBHDNJNPBP@LHLAJFVLFHZCJBFDDPANDRLFFD`DJHDFDD@NGRFHED@\\JNHHJLF@B@FCRCJEDcdAXADABKBEDCF@FJN@FCJDPAFUJaXEFG@MIC@IFSBUNQHA@AHCDQJBFDJFDHDRBZGNv@HA@SNATED[FGFBRCHEJBPLLANLJ@JAH@FJFLBFHJFHBFAJGFAbBJAPCLEzOXKLADBAJBFL@FADBHDBFJFHD@BHDBBHDB@JHFJ@H@HK@EDAA@FEDFTBFLBANFFB@BCFAFCFJJlCHCBBDXHFDHADBJPLlBBHD@BAHBHAHBD@FBBCF@DBBADBBH@RGFB@JILKH@DDBJBJKJERBF@BMPCFCBILIDAD@BFD@LGPSVELGRCPBTCVFRAAGBADAIH@JBRCJGZUTITMJCTYZMXI^GpGJCLIDGNQLOdiZQLEL@XFPHHJNLTHTCHEFI^YDOJQDKDyIuAYC[BWAOAI@IFUDGJGNEH@JFPJDNBPFNbNR@HAdSPA`GjDJGFE@GFMJQFGJCFEPG^CXKNCd@jJtJHAXBpAXBPGJM@EXkLSHGDIhW\\UTIZQTGhCRBHAL@LDVGfEHCNCJEJAbCRFLH@ZDLVBVGZEVIj_bSZI\\EhUFAHCHKJIbOHEXO^KLKbS^UPSDE@E@ECEWCK@[CQMGKBGFCHDTHTHHBDABBNHJBFECSDMDG@EFBHAFFEJBHFB@FFJLHDDAHDHF\\ABNBROXGDA@ACGAGBIJGHEF@B@BFB@JIHCD@HDD@`SBADG^HTJTBNE\\SNEF@`GDERKHIFKGK@ARKFAFBNXFDLFBAJGHAZ@HCBCCE@CJAPAJCPBRDDAFCBC@IDEAMYGAA@C`cDIAOCCIKaWMGYGIEEACESIACBEXIP[JEHIFABABSAGDMBAXBHCBCNO@CIKAGDCNIMAGEACBG@GCAGDCAGQA@C@MFK@MIICGASAQBIDeJOF]JCAI@iHUCSGOECGCOECIAMIACHEHGDQLIDKVGBIGSEEAEDG@GGKAKCKEEIEAECOBEKaBGCGBEJM@WAGGMAQCIEKGCGAIGGBGJSEQAQGIBIDCACGDWDAFGHEDEBERKACJGBIBC^I@CIYBMDSFS@iESIKECc_GCICEGWMIIIMI[GMOYGGSMYCGCGCIKAQHYDEFGT@jNRBHAbQRG\\GR@JBJBFDVLLBVGJGRAbDJAXMNKJUFGFEDGNKFINKJKHGPYFEDGHENIdOtaJKJGHCHGZWPM@IFYIq@G@EDGBONSXMdOBC@IJOHEFG@GEC@CBCLFHBRIL@JEf]gqbOPE|_VOhYbQFCFENGh[FEJMNMNEJ@JCJ@JCL@VBPCPCPGROXYLCVUDE@EFWAGDEJIZMTAbBdI^CRGBECIGKAECCEGGCMMMKCKaWAE@AFCIM@CLMFAJGDAH@DABCBKFKBE@CEESJAABMHICCBCBCFC^BDAJHDHJ@BDBBHEFEFCBGG@CCC@AEBC@AQAMSBGMA@ABET@BGMCAABAV@DB@@LSAID@DBFHJFF@LE@AACKIEMBABADF@DDDF@PQP@FADGACDBBCAMFGBK@CECAOBKEBACCDIBA@AAHKBIJODAJHD@FCX_LGXINA\\G\\KXMNEHCJEFGHCDCNEBC@KESDILIJMHABEAG^KDA_MCAAGBMDKGI@CBKJMHGMOBMHKPSZMVGFCDCHOEEOEO@ECIBKC]FU@OAeBIAQIACCQIKOUESGiAEEIOGSCWASE]D[CQFS@MBEDGHCT@NAHBHFPAHJNAHADMHCD@RAHGHOb[bCJC@GGGCECAEQASFCDC@C@ECOE_K"],"encodeOffsets":[[106944,34123]]},"properties":{"cp":[102.911008,34.986354],"name":"甘南藏族自治州","childNum":1}}],"UTF8Encoding":true});
}));